<?php

namespace HCM\BTL\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use HCM\Util\DateUtil;

class DashboardController extends Crud {

    protected $dataSourceGetTotalCurriculos         = 'desParticipaProcesso_getTotalCurriculos';
    protected $dataSourceGetCurriculosProcesso      = 'desParticipaProcesso_getCurriculosProcesso';
    protected $dataSourceGetProcessosEmpresa        = 'desParticipaProcesso_getProcessosEmpresa';
    protected $dataSourceGetProcessosMes            = 'desParticipaProcesso_getProcessosMes';
    protected $dataSourceGetProcessosCancelados     = 'desParticipaProcesso_getProcessosCancelados';
    protected $dataSourceGetAdmissoesPeriodo        = 'desParticipaProcesso_getAdmissoesPeriodo';
    protected $dataSourceGetAdmissoesTipoVinculo    = 'desParticipaProcesso_getAdmissoesTipoVinculo';
    protected $dataSourceGetTotalProcessos          = 'desParticipaProcesso_getTotalProcessos';
    protected $dataSourceGetCurriculoProcesso       = 'getCurriculoProcesso';
    protected $dataSourceGetAprovadosReprovadosFase = 'getAprovadosReprovadosFase';
    protected $dataSourceGetProcessosSuspensos      = 'desParticipaProcesso_getProcessosSuspensos';
    protected $dataSourceGetTurnOver                = 'gpeVinculom_getTurnOver';
    protected $dataSourceGetIndiceRetencao          = 'gpeVinculom_getIndiceRetencao';
    protected $dataSourceGetPerdaConhecimento       = 'gpeVinculom_getPerdaConhecimento';
    protected $dataSourceGetFluxoVagasMeta          = 'gpeVinculom_getFluxoVagasMeta';
    protected $dataSourceGetFluxoVagas              = 'gpeVinculom_getFluxoVagas';
    protected $dataSourceGetResponsaveisProcesso    = 'desProcesso_getResponsaveisProcesso';
    protected $dataSourceGetAprovadosReprovados     = 'desParticipaFase_getAprovadosReprovados';

    protected $parameterBagColumns = array('NRORG', 'DTINICIOMES', 'DTFIMMES', 'IDSTATUS', 'NRORG_PADRAO', 
        'IDSTATUS_APROVADO', 'IDSTATUS_REPROVADO', 'DTMESCOMPETENC', 'P_NRORG_PADRAO', 'P_NRORG');

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag){
        $this->parameterBag = $parameterBag;
        parent::__construct($dataSourceManager);
    }


    public function getTotalCurriculos (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetTotalCurriculos);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getCurriculosProcesso (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetCurriculosProcesso);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getProcessosEmpresa (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetProcessosEmpresa);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getProcessosMes (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetProcessosMes);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getProcessosCancelados (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetProcessosCancelados);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getAdmissoesPeriodo (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetAdmissoesPeriodo);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getAdmissoesTipoVinculo (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetAdmissoesTipoVinculo);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getTotalProcessos (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetTotalProcessos);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getCurriculoProcesso (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $dtFimMes = null;
            $conditions = array();
            $filterData = $request->getFilterCriteria();
            foreach ($filterData->getConditions() as &$condition) {
                if($condition['columnName'] == 'DTINICIOMES'){
                    if(is_array($condition['value'])){
                        $dtFimMes = $condition['value'][1];
                        $condition['value'] = $condition['value'][0];
                        $condition['operator'] = '=';
                    }
                } else if(!is_null($dtFimMes)){
                    if($condition['columnName'] == 'DTFIMMES'){
                        $condition['value'] = $dtFimMes;
                    }
                }
                $conditions[] = $condition;
            }
            $filterCriteria = new FilterCriteria($this->dataSourceGetCurriculoProcesso, $conditions);
            $newFilterData = $this->populateParameterBag($filterCriteria);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getAprovadosReprovadosFase (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetAprovadosReprovadosFase);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getProcessosSuspensos (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetProcessosSuspensos);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getTurnOver (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetTurnOver);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            if(!empty($dataSet->getRows())){
                $rows = $dataSet->getRows();
                $i = count($rows);
                $rows[$i] = $rows[0];
                $rows[$i]['PERCENTUAL'] = $rows[0]['MEDIA'];
                $rows[$i]['DTDATA'] = 'Média';
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('gpeVinculom_getTurnOver', $rows));

            } else {
                $response->addDataSet($dataSet);                
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getIndiceRetencao (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetIndiceRetencao);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            if(!empty($dataSet->getRows())){
                $rows = $dataSet->getRows();
                $i = count($rows);
                $rows[$i] = $rows[0];
                $rows[$i]['PERCENTUAL'] = $rows[0]['MEDIA'];
                $rows[$i]['DTDATA'] = 'Média';
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('gpeVinculom_getIndiceRetencao', $rows));

            } else {
                $response->addDataSet($dataSet);                
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getPerdaConhecimento (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetPerdaConhecimento);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            if(!empty($dataSet->getRows())){
                $rows = $dataSet->getRows();
                $i = count($rows);
                $rows[$i] = $rows[0];
                $rows[$i]['CONHECIMENTO'] = $rows[0]['MEDIA'];
                $rows[$i]['DTDATA'] = 'Média';
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('gpeVinculom_getPerdaConhecimento', $rows));

            } else {
                $response->addDataSet($dataSet);                
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getFluxoVagasMeta (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetFluxoVagasMeta);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getFluxoVagas (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetFluxoVagas);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getResponsaveisProcesso (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetResponsaveisProcesso);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getAprovadosReprovados (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetAprovadosReprovados);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );


        return $newFilterCriteria;
    }
}