<?php

namespace HCM\FPA\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria; 
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;

class ResumoDespesasController extends Crud { 

    protected $dataSourceName = 'getResumoDespesas';
    protected $dataSourceName_Set = 'fpa_resumoDespesas_set';

    protected $parameterBagColumns = array('P_NRORG', 'P_NRTIPOESTRUTLEGAL', 'P_NRTIPOESTRUTGEREN', 'P_DTMESCOMPETENC', 'P_NRORG_PADRAO');

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        parent::__construct($dataSourceManager);
    }

    public function getResumoDespesas (DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName);
        $filterData->addCondition('P_NRTIPOESTRUTLEGAL', $this->hcmParameters->getTipoEstruturaLegalOrg());
        $filterData->addCondition('P_NRTIPOESTRUTGEREN', $this->hcmParameters->getTipoEstruturaGerencialOrg());
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData); 
        $response->addDataSet($dataSet);
    }

    public function setResumoDespesas (DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NRRESUMODRO', $row)) {
                    if ($row['NRRESUMODRO'] === '') {
                        $row['NRRESUMODRO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'FPA_RESUMODRO', 1, 12, true); 
                    } 
                } else {
                    $row['NRRESUMODRO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'FPA_RESUMODRO', 1, 12, true); 
                }
            } 
            
            $row["NRTIPOMOVIMENT"] = isset($row["NRTIPOMOVIMENT"])?$row["NRTIPOMOVIMENT"]:null;
            $this->dataSourceName = $this->dataSourceName_Set;
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
 
    public function delete(DTO\Request\DataSet $request, DTO\Response $response){
        $this->dataSourceName = $this->dataSourceName_Set;
        parent::delete($request, $response);
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }

    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
}