<?php

namespace HCM\FPA\ObrigacaoLegal\CNAB\Mentore;

use HCM\Util\Messages;
use HCM\Util\Repositories;
use HCM\Util\DateUtil;
use HCM\Util\FPA;
use HCM\Util\TkDI;
use HCM\Util\MsgCalculo;
use HCM\Geral\Entity\GpepessoaEntity;
use HCM\Geral\Entity\GpevinculomEntity;
use HCM\Geral\Entity\GpevinculoempregEntity;
use HCM\Geral\Entity\GpeOcupacaomEntity;
use HCM\Geral\Entity\GpemovimentacaoEntity;
use HCM\Geral\Entity\GpetpmovtransfmEntity;
use HCM\Geral\Entity\GpetpmovtransfhEntity;
use HCM\Geral\Entity\GpeGrauinstrEntity;
use HCM\Geral\Entity\GpeescalatrabmEntity;
use HCM\Geral\Entity\GpeRacapessoaEntity;
use HCM\Geral\Entity\GpeCondfispesEntity;
use HCM\Geral\Entity\GpeCboEntity;
use HCM\Geral\Entity\EnderecoparcEntity;
use HCM\FPA\Calculos\Geral\Estruturacao;
use HCM\Geral\Entity\EstruturamEntity;
use HCM\FPA\Entity\FpaitecalcfolhaEntity;
use HCM\FPA\Entity\FpaTpdemissaoEntity;
use HCM\FPA\Entity\FpaeventomEntity;
use HCM\FPA\Entity\FpaFormcnabEntity;
use HCM\FPA\ObrigacaoLegal\CNAB\Mentore\registro\Registro11CNABMentore;
use HCM\FPA\ObrigacaoLegal\CNAB\Mentore\registro\Registro21CNABMentore;
use HCM\FPA\ObrigacaoLegal\CNAB\Mentore\registro\Registro31CNABMentore;
use HCM\FPA\Registro\RegistroCNAB;
use HCM\FPA\Registro\FPARegistro;

class CNABMentore{

    private $_nrOrg;
    private $_nrOrgPadrao;
    private $_mesCompetencia;
    private $_dtInicio;
    private $_dtFim;
    private $_dtAux;
    private $_estrutura;
    private $_movimentacao;
    private $_estruturacao;
    private $_tpMovTransfM;
    private $_tpMovTransfH;
    private $_itemGrupo;
    private $_listaCalculoFolha;
    private $_evento;
    private $_registro11;
    private $_registro21;
    private $_registro31;
    private $_cnabMagnetico;
    private $_totalVinculos;
    private $_dadoVinculo = array();
    private $_cnabTeste;
    private $_codConvenio;
    private $_itemCalculo;
    private $_pessoa;
    private $_vinculo;
    private $_vinculoEmpreg;
    private $_ocupacao;
    private $_tpDemissao;
    private $_grauInstrucao;
    private $_escalaTrabalho;
    private $_raca;
    private $_condicaoFisica;
    private $_cbo;
    private $_enderecoParc;

    private $_nrTpMovimentoFormulario;

    private $_cdOperador;

    const CODIGO_BANCO_MENTORE = '997';

    public function __construct(
        $nrOrg, $nrOrgPadrao, $mesCompetencia, $cnabMagnetico, $dataSet, $entityManager, $hcmParameters
    ){


        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->_nrOrg = $nrOrg;
        $this->_nrOrgPadrao = $nrOrgPadrao;
        
        $this->_mesCompetencia = $mesCompetencia;

        $this->_dtInicio = $this->_mesCompetencia;
        $this->_dtFim = DateUtil::getUltimoDiaDoMes($this->_mesCompetencia);
        
        $this->_itemCalculo = new FpaitecalcfolhaEntity($entityManager, $hcmParameters);
        $this->_pessoa = new GpepessoaEntity($entityManager, $hcmParameters);
        $this->_vinculo = new GpevinculomEntity($entityManager, $hcmParameters);
        $this->_vinculoEmpreg = new GpevinculoempregEntity($entityManager, $hcmParameters);
        $this->_ocupacao = new GpeOcupacaomEntity($entityManager, $hcmParameters);
        $this->_tpDemissao = new FpaTpdemissaoEntity($entityManager, $hcmParameters);
        $this->_movimentacao = new GpemovimentacaoEntity($entityManager, $hcmParameters);
        $this->_tpMovTransfM = new GpetpmovtransfmEntity(
            $entityManager, $hcmParameters
        );
        $this->_tpMovTransfH = new GpetpmovtransfhEntity(
            $entityManager, $hcmParameters
        );
        $this->_grauInstrucao = new GpeGrauinstrEntity($entityManager, $hcmParameters);
        $this->_escalaTrabalho = new GpeescalatrabmEntity($entityManager, $hcmParameters);
        $this->_raca = new GpeRacapessoaEntity($entityManager, $hcmParameters);
        $this->_condicaoFisica = new GpeCondfispesEntity($entityManager, $hcmParameters);
        $this->_cbo = new GpeCboEntity($entityManager, $hcmParameters);
        $this->_enderecoParc = new EnderecoparcEntity($entityManager, $hcmParameters);
        $this->_evento = new FpaeventomEntity($entityManager, $hcmParameters);
        $this->_estruturacao = new Estruturacao($entityManager, $hcmParameters);
        $this->_estrutura = new EstruturamEntity($entityManager, $hcmParameters);

        $this->_cnabMagnetico = $cnabMagnetico;

        $this->_registro11 = new Registro11CNABMentore();
        $this->_registro21 = new Registro21CNABMentore();
        $this->_registro31 = new Registro31CNABMentore();

        $this->_cdOperador = $hcmParameters->getCdOperador();

        $this->_inicializaVariaveis($dataSet);
    }

    private function _inicializaVariaveis($dataSet){

        $this->_totalVinculos = array();
        $this->_nrTpMovimentoFormulario = $dataSet['NRTIPOMOVIMENT'];
        $this->_cnabTeste = $dataSet['IDTESTE'];
        $this->_codConvenio = $dataSet['CODCONVENIO'];
        $this->_eventom = $dataSet['NREVENTOM'];
    }

    public function geraCNAB($estrutura, $pessoa, $vinculo){
        $this->_estrutura = $estrutura;
        $this->_pessoa = $pessoa;
        $this->_vinculo = $vinculo;
        $this->_preparaRegistro11();
        $this->_preparaRegistro21();
        $this->_preparaRegistro31();
    }

    private function _preparaRegistro11() {

        $posicao = $this->_cnabMagnetico->procuraRegistroLista(
            $this->_estrutura->nrInscricao, Registro11CNABMentore::REGISTRO_11, self::CODIGO_BANCO_MENTORE,
            $this->_nrTpMovimentoFormulario, $this->_cdOperador, $this->_nrOrg
        );

        if ($posicao === false) {
            if ($this->_cnabTeste === FpaFormcnabEntity::IDTESTE_NAO) {
                $ultimoSequencial = $this->_cnabMagnetico->retornaUltimoSequencialRegistro0(
                    $this->_mesCompetencia, $this->_nrOrg, self::CODIGO_BANCO_MENTORE, $this->_cdOperador
                );

                if ($ultimoSequencial) {
                    $sequencia = $ultimoSequencial;
                    $sequencia++;
                } else {
                    $sequencia = FPARegistro::CARACTER_UM;
                }
            } else {
                $sequencia = FPARegistro::CARACTER_UM;
            }
            
            $this->_registro11->setSequencia((string)$sequencia);
            $this->_registro11->setEstrutura($this->_estrutura);
            $this->_registro11->setCodConvenioBanco($this->_codConvenio);

            $this->_registro11->geraRegistro11($this->_nrTpMovimentoFormulario, $this->_eventom);
            
            $this->_cnabMagnetico->insereRegistroLista(
                $this->_nrOrg, $this->_cdOperador, $this->_mesCompetencia, Registro11CNABMentore::REGISTRO_11, $this->_estrutura->nrTpInscricao,
                $this->_estrutura->nrInscricao, $this->_registro11->getLinhaRegistro(), self::CODIGO_BANCO_MENTORE,
                $this->_nrTpMovimentoFormulario, $sequencia
            );

            $this->_registro11->setLinhaRegistro();
        }
    }

    private function _preparaRegistro21() {

        $this->_registro21->setPessoa($this->_pessoa);
        $this->_registro21->setVinculo($this->_vinculo);
        $this->_registro21->setCnpjEmpresa($this->_estrutura->nrInscricao);

        $this->_registro21->geraRegistro21();
        
        $this->_cnabMagnetico->persisteRegistro(
            $this->_nrOrg, $this->_mesCompetencia, RegistroCNAB::REGISTRO_21, Registro21CNABMentore::SEGMENTO_A,
            $this->_estrutura->nrTpInscricao, $this->_estrutura->nrInscricao, $this->_registro21->getLinhaRegistro(),
            $this->_vinculo->getNrvinculom(), self::CODIGO_BANCO_MENTORE, $this->_nrTpMovimentoFormulario,
            $this->_vinculo->valorPagamento, $this->_pessoa->nrTpInscricao, $this->_pessoa->historico->getNrcpfpessoa(), $this->_cdOperador
        );

        $this->_registro21->setLinhaRegistro();
    }

    private function _preparaRegistro31() {

        $posicao = $this->_cnabMagnetico->procuraRegistroLista(
            $this->_estrutura->nrInscricao, Registro31CNABMentore::REGISTRO_31, self::CODIGO_BANCO_MENTORE
            , $this->_nrTpMovimentoFormulario, $this->_cdOperador, $this->_nrOrg
        );

        if ($posicao === false) {

            $this->_registro31->geraRegistro31();

            $this->_cnabMagnetico->insereRegistroLista(
                $this->_nrOrg, $this->_cdOperador, $this->_mesCompetencia, Registro31CNABMentore::REGISTRO_31, $this->_estrutura->nrTpInscricao,
                $this->_estrutura->nrInscricao, $this->_registro31->getLinhaRegistro(), self::CODIGO_BANCO_MENTORE,
                $this->_nrTpMovimentoFormulario
            );

            $this->_registro31->setLinhaRegistro();
        }
    }

    public function modificaLinhasConsolidacaoMentore($tipoRegistro, $linha, $valorTotalPagamento){

        if ($tipoRegistro === Registro31CNABMentore::REGISTRO_31) {
            // Quantidade de registros no arquivo.
            $qtdRegistrosArquivo = $this->_cnabMagnetico->totalRegistrosPorTipos(
                $this->_mesCompetencia, $this->_nrOrg, RegistroCNAB::LISTA_TIPO_REGISTROS_ARQUIVO_MENTORE,
                self::CODIGO_BANCO_MENTORE, $this->_nrTpMovimentoFormulario, $this->_cdOperador
            );
            
            // Bloco 2 | 03-10 | Quantidade de registros no arquivo (Registros Tipo 21).
            $linha = $this->_registro31->alteraDado(
                $linha, (string)$qtdRegistrosArquivo, (3 -1), 8, Registro31CNABMentore::CARACTER_ZERO, Registro31CNABMentore::PREENCHE_ESQUERDA
            );
            
            // Bloco 3 | 11-20 | Valor total de registros enviados para deposito
            $linha = $this->_registro31->alteraDado($linha, $valorTotalPagamento, (11 -1),10, Registro31CNABMentore::CARACTER_ZERO, Registro31CNABMentore::PREENCHE_ESQUERDA);
            
            // Bloco 4 | 21-28 | Numero da linha
            $linha = $this->_registro31->alteraDado($linha, '00000001', (21 -1),8, Registro31CNABMentore::CARACTER_ZERO, Registro31CNABMentore::PREENCHE_ESQUERDA);
        }
        return $linha;
    }
}