<?php

namespace HCM\FPA\ObrigacaoLegal\Demonstrativo_Eletronico;

class HoleriteUtil {
    /**
     * Verifica se os dados obrigatórios de resposta da query estão todos preenchidos
     * @param array $result
     * @param array $requireds
     * @return array
     */
    public function testMissingRequired($registros, $requireds) {
        $msg = array();

        /*Percorre os campos do $registros*/
        foreach($registros as $key => $val)
            if(array_key_exists($key, $requireds))
                if(!isset($val))
                    $msg[] = $requireds[$key];

        return $msg;
    }
    
    /**
     * Format uma string. Ideial para layouts de txt tais como CNAB e Holerites.
     * @param $string
     * @param string $type
     * @param integer $size
     * @return string
     */
    public function formatString($string, $type, $size) {
        $string = substr($string, 0, $size); //Trunca a string

        switch($type) {
            case 'X': //alfanumperico, alinha a esquerda e preenche com ' '
                return str_pad($string, $size, ' ', STR_PAD_RIGHT);
                break;
            case '9': //numerico, alinha a direita e preenche com '0'
                return str_pad($string, $size, '0', STR_PAD_LEFT);
                break;
            default: //Tipo não enontrado, retorna sem formatar
                return $string;
       }
    }
    
    /**
     * Usa o formatString para formatar um array de array de registros.
     * IMPORTANTE: o $registros é um array de array
     * @param array $registros
     * @param array $layout
     * @return array
     */
    public function formatStringArray($registros, $layout) {
        $out = array();

        foreach($registros as $i => $registro)
            foreach($registro as $key => $val)
                $out[$i][$key] = $this->formatString($val, $layout[$key][0], $layout[$key][2] - $layout[$key][1] + 1);
        return $out;
    }
    
    /**
     * Concatena dois array's de acordo com os índices de $arrayModel (ele
     * ignora os valores deste array). Os arrays que serão concatenados são o
     * '$array1' e '$array2', sendo o primeiro com prioridade no valor do índice
     * caso o índice se repita no próximo. Seus índices (óbvio) e seus valores
     * serão considerados para a concatenação. Se o modelo fizer referência a um
     * índice que não existe nos array's este colocará o valor null.
     * @param array $arrayModel
     * @param array $array1
     * @param array $array2
     * @return array
     */
    public function concatArrays($arrayModel, $array1, $array2) {
        $out = array();
        /*percorre o modelo para montar o array concatenado*/
        foreach($arrayModel as $key => $val) {
            if(isset($array1[$key])) //Array1 tem prioridade
                $out[$key] = $array1[$key];
            else if(isset($array2[$key]))
                $out[$key] = $array2[$key];
            else
                $out[$key] = null;
        }
        return $out;
    }
    
    /**
     * Idem ao 'concatArrays', porém o $arrayArray2 é um array de array, tal
     * como é retornado de uma consulta de uma query. Seu retorno é compatível
     * com o $arrayArray2. Os demais parâmetros são array's comuns.
     * @param array $arrayModel
     * @param array $arrayArray1
     * @param array $array2
     * @return array
     */
    public function concatArraysInArray($arrayModel, $array1, $arrayArray2) {
        $out = array();
        
        foreach($arrayArray2 as $i => $array2)
            $out[$i] = $this->concatArrays($arrayModel, $array1, $array2);
        
        return $out;
    }
    
    /**
     * 
     */
    public function setParamsDsordem($params, $dsordem, $dsinicio, $dsfim){
        $params['P_NMVINCULOM_INI']     = null;
        $params['P_NMVINCULOM_FIM']     = null;
        $params['P_CDMATRICULA_INI']    = null;
        $params['P_CDMATRICULA_FIM']    = null;
        $params['P_DTADMISSAOVINC_INI'] = null;
        $params['P_DTADMISSAOVINC_FIM'] = null;
        $params['P_NRESTRUTLEGAL']      = null;
        $params['P_NRESTRUTGEREN']      = null;
        $params['P_NRESTRUTSIND']       = null;
        $params['P_NRVINCULOM']         = null;

        switch($dsordem) {
            case 'ALFABETICA':
                $params['P_NMVINCULOM_INI'    ] = $dsinicio;
                $params['P_NMVINCULOM_FIM'    ] = $dsfim;
                break;
            case 'MATRICULA':
                $params['P_CDMATRICULA_INI'   ] = (string)$dsinicio;
                $params['P_CDMATRICULA_FIM'   ] = (string)$dsfim;
                break;
            case 'DATA_ADMISSAO':
                $params['P_DTADMISSAOVINC_INI'] = $dsinicio;
                $params['P_DTADMISSAOVINC_FIM'] = $dsfim;
                break;
            case 'ESTRUTURA':
                if(isset($dsinicio))
                   $params['P_NRESTRUTLEGAL'  ] = is_array($dsinicio) ? implode(',', $dsinicio) : $dsinicio;
                if(isset($dsfim))
                    $params['P_NRESTRUTGEREN' ] = is_array($dsfim   ) ? implode(',', $dsfim   ) : $dsfim;
                break;
            case 'LISTA_ESTRUTURA':
                if(isset($dsinicio))
                    $params['P_NRESTRUTLEGAL' ] = is_array($dsinicio) ? implode(',', $dsinicio) : $dsinicio;
                if(isset($dsfim))
                    $params['P_NRESTRUTGEREN' ] = is_array($dsfim   ) ? implode(',', $dsfim   ) : $dsfim;
                break;
            case 'LISTA_NRESTRUTSIND':
                if(isset($dsinicio))
                   $params['P_NRESTRUTLEGAL'  ] = is_array($dsinicio) ? implode(',', $dsinicio) : $dsinicio;
                if(isset($dsfim))
                    $params['P_NRESTRUTSIND'  ] = is_array($dsfim   ) ? implode(',', $dsfim   ) : $dsfim;
                break;
            case 'LISTA_VINCULO':
                $params['P_NRVINCULOM'] = is_array($dsinicio) ? implode(',', $dsinicio) : $dsinicio;
                break;
        }

        return $params;
    }
    
    /**
     * Convete um array de array para string, ou um array de string para string.
     * 
     * Para um array de array: o $separador determina as colunas. Pode ser uma
     * ',' ou nada (''). Retorna um array de string's.
     * 
     * Para um array de string: o $separador pode ser a quebra de linha (\r\n).
     * Retorna uma string.
     * 
     * @param array $array
     * @param string $separador
     */
    public function arrayToString($array, $separador){
        foreach($array as $row)
            if(is_array($row)) {
                if(!isset($buffer)) $buffer = array();
                $buffer[] = implode($separador, $row);
            } else {
                if(!isset($buffer)) $buffer = '';
                $buffer .= $row;
            }
        return $buffer;
    }
    
    /**
     * Concatena os parametros de ordenação junto aos parâmetros existentes
     */
    /*public function getWhereDsordem($dsordem, $dsinicio, $dsfim) {
        $where = '';
        switch($dsordem){
            case 'ALFABETICA':
                $where .= "\r\n  AND VM.NMVINCULOM BETWEEN '$dsinicio' AND '$dsfim'\r\nORDER BY VM.NMVINCULOM";
                break;
            case 'MATRICULA':
                $where .= "\r\n  AND VM.CDMATRICULA BETWEEN '$dsinicio' AND '$dsfim'\r\nORDER BY VM.CDMATRICULA";
                break;
            case 'DATA_ADMISSAO':
                $where .= "\r\n  AND VM.DTADMISSAOVINC BETWEEN '$dsinicio' AND '$dsfim'\r\nORDER BY VM.DTADMISSAOVINC";
                break;
            case 'ESTRUTURA':
                if(isset($dsinicio))
                    $where .= "\r\n  AND VH.NRESTRUTLEGAL = '$dsinicio'";
                if(isset($dsfim))
                    $where .= "\r\n  AND VH.NRESTRUTGEREN = '$dsfim'";
                break;
            case 'LISTA_ESTRUTURA':
                if($dsinicio)
                    $where .= "\r\n  AND VH.NRESTRUTLEGAL IN (" . $dsinicio . ")";
                break;
            case 'LISTA_VINCULO':
                if($dsinicio)
                    $where .= "\r\n  AND VM.NRVINCULOM IN (" . $dsinicio . ")";
                break;
            case 'ESTRUTURA_SIND':
                if($dsinicio)
                    $where .= "\r\n  AND VH.NRESTRUTSIND IN (" . $dsinicio . ")";
                break;
            case 'LISTA_NRESTRUTSIND':
                if($dsinicio)
                    $where .= "\r\n  AND VH.NRESTRUTLEGAL = '$dsinicio'";
                if(isset($dsfim))
                    $where .= "\r\n  AND VH.NRESTRUTSIND IN (" . $dsfim . ")";
                break;
        }
    }*/
}