<?php
namespace HCM\FPA\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;

class LancamentoEventoRepository {

    protected  $connection;
    protected  $entityManager;
    
    public function __construct(Connection $connection, EntityManager $entityManager) {
        $this->connection    = $connection;
        $this->entityManager = $entityManager;
    }
    
    public function getVinculosEstrutura($nrestrutlegal, $nrestrutgeren, $nrestrutsind, $nrorg, $dtCompetencia){
        
        $filter= '';
        
        if(!empty($nrestrutlegal)){
            $estrutlegal = implode(",", $nrestrutlegal);
          if(empty($filter)){
            $filter = "AND GPE_VINCULOH.NRESTRUTLEGAL IN ($estrutlegal)";
          } else {
            $filter .= " AND GPE_VINCULOH.NRESTRUTLEGAL IN ($estrutlegal)";
          }
        }

        if(!empty($nrestrutgeren)){
            $estrutgeren = implode(",", $nrestrutgeren);
          if(empty($filter)){
            $filter = "AND GPE_VINCULOH.NRESTRUTGEREN IN ($estrutgeren)";
          } else {
            $filter .= " AND GPE_VINCULOH.NRESTRUTGEREN IN ($estrutgeren)";
          }
        }

        if(!empty($nrestrutsind)){
            $estrutsind = implode(",", $nrestrutsind);
          if(empty($filter)){
            $filter = "AND GPE_VINCULOH.NRESTRUTSIND IN ($estrutsind)";
          } else {
            $filter .= " AND GPE_VINCULOH.NRESTRUTSIND IN ($estrutsind)";
          }
        }
        
        $params = array('P_NRORG'          => $nrorg,
                        'P_DTMESCOMPETENC' => $dtCompetencia);
        $query = "SELECT GPE_VINCULOH.NRVINCULOM
                FROM GPE_VINCULOH
                WHERE GPE_VINCULOH.NRORG = :P_NRORG
                ".$filter."
                AND GPE_VINCULOH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) 
                                         FROM GPE_VINCULOH H 
                                        WHERE H.NRORG = GPE_VINCULOH.NRORG
                                          AND H.NRVINCULOM = GPE_VINCULOH.NRVINCULOM
                                          AND H.DTMESCOMPETENC <= :P_DTMESCOMPETENC)";
        
        $result = $this->connection->fetchAll($query, $params);
        return $result;
    }
    
    
    public function getDadosEvento($nrvinculom, $evento, $nrorg, $dtcompetencia, $nrcalculofolha, $nrorg_padrao){
        
        
        $params = array(
            'P_NRORG'            => $nrorg,
            'P_NRCALCULOFOLHA'   => $nrcalculofolha,
            'P_DTMESCOMPETENC'   => $dtcompetencia,
            'P_NRVINCULOM'       => $nrvinculom,
            'P_NREVENTOM'        => $evento,
            'P_NRORG_PADRAO'     => $nrorg_padrao
        );
        
        $query = "
SELECT      
FPA_ITECALCFOLHA.NRITEMCALCFOLHA,
FPA_ITECALCFOLHA.NRCALCULOFOLHA,
FPA_ITECALCFOLHA.NRVINCULOM,
FPA_ITECALCFOLHA.NREVENTOM,
FPA_ITECALCFOLHA.NRORG,
FPA_ITECALCFOLHA.IDEVENDEMONCALC,
FPA_ITECALCFOLHA.VRREFFOLHA, 
FPA_ITECALCFOLHA.VREVENTOFOLHA, 
FPA_ITECALCFOLHA.QTOCORPROXPERI,
FPA_ITECALCFOLHA.IDREFEVALORCALC,
FPA_ITECALCFOLHA.DTINCLUSAO,
FPA_ITECALCFOLHA.DTULTATU,
FPA_ITECALCFOLHA.NRORGINCLUSAO,
FPA_ITECALCFOLHA.NRORGULTATU,
FPA_ITECALCFOLHA.CDOPERINCLUSAO,
FPA_ITECALCFOLHA.CDOPERULTATU,
FPA_ITECALCFOLHA.DTOCORRENCIA,
FPA_ITECALCFOLHA.VRVELHO,
FPA_ITECALCFOLHA.NRLOTELANCEVENTO,
FPA_ITECALCFOLHA.DTGERULTCNAB,
FPA_ITECALCFOLHA.DSITEMCALCFOLHA,
GPE_VINCULOM.NMVINCULOM,
ESTRUTGEREN.NMESTRUTURAM NMESTRUTGEREN,
GPE_VINCULOH.NRESTRUTGEREN,
ESTRUTLEGAL.NMESTRUTURAM NMESTRUTLEGAL,
GPE_VINCULOH.NRESTRUTLEGAL,
FPA_EVENTOH.NMEVENTOH,
FPA_EVENTOM.IDTIPOEVENTO
FROM FPA_ITECALCFOLHA
LEFT JOIN GPE_VINCULOM
    ON FPA_ITECALCFOLHA.NRVINCULOM = GPE_VINCULOM.NRVINCULOM
    AND FPA_ITECALCFOLHA.NRORG = GPE_VINCULOM.NRORG
LEFT JOIN GPE_VINCULOH
    ON GPE_VINCULOM.NRVINCULOM = GPE_VINCULOH.NRVINCULOM
    AND GPE_VINCULOM.NRORG = GPE_VINCULOH.NRORG
    AND GPE_VINCULOH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) 
                                         FROM GPE_VINCULOH H 
                                        WHERE H.NRORG = GPE_VINCULOH.NRORG
                                          AND H.NRVINCULOM = GPE_VINCULOH.NRVINCULOM
                                          AND H.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
LEFT JOIN ESTRUTURAM ESTRUTGEREN
    ON GPE_VINCULOH.NRESTRUTGEREN = ESTRUTGEREN.NRESTRUTURAM
    AND GPE_VINCULOH.NRORG = ESTRUTGEREN.NRORG
LEFT JOIN ESTRUTURAM ESTRUTLEGAL
    ON GPE_VINCULOH.NRESTRUTLEGAL = ESTRUTLEGAL.NRESTRUTURAM
    AND GPE_VINCULOH.NRORG = ESTRUTLEGAL.NRORG
LEFT JOIN FPA_EVENTOM ON FPA_ITECALCFOLHA.NREVENTOM = FPA_EVENTOM.NREVENTOM
                     AND (FPA_EVENTOM.NRORG = :P_NRORG OR FPA_EVENTOM.NRORG = :P_NRORG_PADRAO)    
LEFT JOIN FPA_EVENTOH ON FPA_EVENTOM.NREVENTOM = FPA_EVENTOH.NREVENTOM
                     AND FPA_EVENTOH.NRORG = FPA_EVENTOM.NRORG
                     AND FPA_EVENTOH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) 
                                                         FROM FPA_EVENTOH E 
                                                        WHERE E.NRORG = FPA_EVENTOH.NRORG
                                                          AND E.NREVENTOM = FPA_EVENTOH.NREVENTOM
                                                          AND E.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
LEFT JOIN FPA_CALCULOFOLHA 
    ON FPA_CALCULOFOLHA.NRCALCULOFOLHA = FPA_ITECALCFOLHA.NRCALCULOFOLHA
    AND FPA_CALCULOFOLHA.NRORG = FPA_ITECALCFOLHA.NRORG
WHERE FPA_ITECALCFOLHA.NRORG = :P_NRORG
    AND FPA_ITECALCFOLHA.NRCALCULOFOLHA = :P_NRCALCULOFOLHA
    AND FPA_ITECALCFOLHA.NREVENTOM = :P_NREVENTOM
    AND FPA_ITECALCFOLHA.NRVINCULOM = :P_NRVINCULOM
    ";
        $result = $this->connection->fetchAll($query, $params);
        
        return $result;
    }
}