<?php

namespace HCM\FPA\Services;

use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;
use HCM\FPA\Entity\FpaeventohEntity;
use HCM\Util\DateUtil;
use HCM\Util\Messages;
use HCM\Util\Repositories;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\Model\Gestaopessoas\Entities\FpaEventoh;
use \Datetime;

class EventoService {
    
    protected $entityManager;
    protected $hcmParameters;
    protected $fpaeventom;
    protected $fpaeventoh;
    protected $esorubrica;
    protected $fpaincidevento;
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->associacao = Repositories::FPA_EVENTOCTBL;
        $this->fpaeventom = Repositories::FPA_EVENTOM;
        $this->fpaeventoh = Repositories::FPA_EVENTOH;
        $this->esorubrica = Repositories::ESO_RUBRICA;
        $this->fpaincidevento = Repositories::FPA_INCIDEVENTO;
    }
    
     public function salvaAssocEventoOper($dataset) {
        //$this->entityManager->beginTransaction();
        try {
            $eventom = $this->entityManager->getRepository(Repositories::FPA_EVENTOH)->findOneBy(array("nreventoh" => $dataset['NREVENTOH'],"nrorg" => $dataset['NRORG']));
            $eventoctbloper = $this->entityManager->getRepository(Repositories::FPA_EVENTOCTBL)->findOneBy(array("nreventom" => $eventom->getNreventom(), "nrestruturam" => null,"nrorg" => $dataset['NRORG'],"nrtpeventoctbl" => null, "nrtpeventoctbl" => $dataset["NRTPEVENTOCTBLOPER"]));
            $dataset['CDOPERINCLUSAO'] = $dataset['CDOPERINCLUSAO'] ? $dataset['CDOPERINCLUSAO'] : $this->hcmParameters->getCdOperador();
            if(!$eventoctbloper){
                $eventoctbloper = new $this->associacao();
                $codigo = \HCM\Util\NovoCodigo::geraCodigo($dataset['NRORG'], 'FPA_EVENTOCTBL', 1, 12, true);
                $eventoctbloper->setNreventoctbl($codigo);
                $eventoctbloper->setCdoperinclusao($dataset['CDOPERINCLUSAO']);
                $eventoctbloper->setDtinclusao(DateUtil::getDataAtual());
                $eventoctbloper->setDtinivigencia(DateUtil::getDataDeString2($dataset['DTINIVIGENCIA'], "d/m/Y", true));
                $eventoctbloper->setNreventom($eventom->getNreventom());
                $eventoctbloper->setNrorg($dataset['NRORG']);
                $eventoctbloper->setNrorginclusao($dataset['NRORG']);
            }
                $eventoctbloper->setIdvincativo("S");
                $eventoctbloper->setDtultatu(DateUtil::getDataAtual());
                $eventoctbloper->setNrorgultatu($dataset['NRORG']);
                $eventoctbloper->setCdoperultatu($dataset['CDOPERULTATU']?$dataset['CDOPERULTATU']:$dataset['CDOPERINCLUSAO']);
                $eventoctbloper->setCdcontctbldeb(isset($dataset["CDCONTCTBLDEBOPER"])?$dataset["CDCONTCTBLDEBOPER"]:null);
                $eventoctbloper->setCdhistpadrdeb(isset($dataset["CDHISTPADRDEBOPER"])?$dataset["CDHISTPADRDEBOPER"]:null);
                $eventoctbloper->setCdcontctblcre(isset($dataset["CDCONTCTBLCREOPER"])?$dataset["CDCONTCTBLCREOPER"]:null);
                $eventoctbloper->setCdhistpadrcre(isset($dataset["CDHISTPADRCREOPER"])?$dataset["CDHISTPADRCREOPER"]:null);
                $eventoctbloper->setCddespadmfat(isset($dataset["CDDESPADMFATOPER"])?$dataset["CDDESPADMFATOPER"]:null);
                $eventoctbloper->setNrtpeventoctbl($dataset["NRTPEVENTOCTBLOPER"] ? $dataset["NRTPEVENTOCTBLOPER"] : null);
                
            $this->entityManager->persist($eventoctbloper);
            $this->entityManager->flush();
            return $eventoctbloper->getNreventoctbl();
        } catch (\Exception $e) {            
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function salvaAssocEventoAdm($dataset) {
        //$this->entityManager->beginTransaction();
        try {
            $eventom = $this->entityManager->getRepository(Repositories::FPA_EVENTOH)->findOneBy(array("nreventoh" => $dataset['NREVENTOH'],"nrorg" => $dataset['NRORG']));
            $eventoctbladm = $this->entityManager->getRepository(Repositories::FPA_EVENTOCTBL)->findOneBy(array("nreventom" => $eventom->getNreventom(), "nrestruturam" => null,"nrorg" => $dataset['NRORG'],"nrtpeventoctbl" => null, "nrtpeventoctbl" => $dataset["NRTPEVENTOCTBLADM"]));
            $dataset['CDOPERINCLUSAO'] = $dataset['CDOPERINCLUSAO'] ? $dataset['CDOPERINCLUSAO'] : $this->hcmParameters->getCdOperador();
            if(!$eventoctbladm){
                $eventoctbladm = new $this->associacao();
                $codigo = \HCM\Util\NovoCodigo::geraCodigo($dataset['NRORG'], 'FPA_EVENTOCTBL', 1, 12, true);
                $eventoctbladm->setNreventoctbl($codigo);
                $eventoctbladm->setCdoperinclusao($dataset['CDOPERINCLUSAO'] ? $dataset['CDOPERINCLUSAO'] : $this->hcmParameters->getCdOperador());
                $eventoctbladm->setDtinclusao(DateUtil::getDataAtual());
                $eventoctbladm->setDtinivigencia(DateUtil::getDataDeString2($dataset['DTINIVIGENCIA'], "d/m/Y", true));
                $eventoctbladm->setNreventom($eventom->getNreventom());
                $eventoctbladm->setNrorg($dataset['NRORG']);
                $eventoctbladm->setNrorginclusao($dataset['NRORG']);
            }
                $eventoctbladm->setIdvincativo("S");
                $eventoctbladm->setDtultatu(DateUtil::getDataAtual());
                $eventoctbladm->setNrorgultatu($dataset['NRORG']);
                $eventoctbladm->setCdoperultatu($dataset['CDOPERULTATU'])?$dataset['CDOPERULTATU']:$dataset['CDOPERINCLUSAO'];
                $eventoctbladm->setCdcontctbldeb(isset($dataset["CDCONTCTBLDEBADM"])?$dataset["CDCONTCTBLDEBADM"]:null);
                $eventoctbladm->setCdhistpadrdeb(isset($dataset["CDHISTPADRDEBADM"])?$dataset["CDHISTPADRDEBADM"]:null);
                $eventoctbladm->setCdcontctblcre(isset($dataset["CDCONTCTBLCREADM"])?$dataset["CDCONTCTBLCREADM"]:null);
                $eventoctbladm->setCdhistpadrcre(isset($dataset["CDHISTPADRCREADM"])?$dataset["CDHISTPADRCREADM"]:null);
                $eventoctbladm->setCddespadmfat(isset($dataset["CDDESPADMFATADM"])?$dataset["CDDESPADMFATADM"]:null);
                $eventoctbladm->setNrtpeventoctbl($dataset["NRTPEVENTOCTBLADM"] ? $dataset["NRTPEVENTOCTBLADM"] : null);
                
            $this->entityManager->persist($eventoctbladm);
            $this->entityManager->flush();
            return $eventoctbladm->getNreventoctbl();
        } catch (\Exception $e) {            
            $this->entityManager->rollback();
            throw $e;
        }
    }
     
    public function deleteEvento($dataset) {
        try {
            $this->entityManager->beginTransaction();
            $eventoh = $this->entityManager->getRepository(Repositories::FPA_EVENTOH)->findOneBy(array("nreventom" => $dataset['NREVENTOM'], "nreventoh" => $dataset['NREVENTOH'],"nrorg" => $dataset['NRORG']));
            $this->entityManager->remove($eventoh);
            $this->entityManager->flush();
            $eventohh = $this->entityManager->getRepository(Repositories::FPA_EVENTOH)->findOneBy(array("nreventom" => $dataset['NREVENTOM'],"nrorg" => $dataset['NRORG']));
            if(empty($eventohh)) {
                $eventom = $this->entityManager->getRepository(Repositories::FPA_EVENTOM)->findOneBy(array("nreventom" => $dataset['NREVENTOM'],"nrorg" => $dataset['NRORG']));
                $this->entityManager->remove($eventom);
                $this->entityManager->flush();
            }
            $this->entityManager->commit();
        } catch (\Exception $e) {            
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
        public function cadAutoEvento($row) {
        try {
            $this->entityManager->beginTransaction();
            $nrorg = $this->hcmParameters->getNrorgTrabalho();
            $nrorgpadrao = intval($this->hcmParameters->getNrorgPadrao());
            $dtmescompetenc = $this->hcmParameters->getDtCompetencia();
            $preparedDateCompetenc = DateUtil::getDatadeString($dtmescompetenc, DateUtil::FORMATO_BRASILEIRO, true);
            foreach($row['NREVENTOM'] as $key=>$nreventom) {
                $nreventoh = $row['NREVENTOH'][$key];
                $obj = $this->entityManager->getRepository(Repositories::FPA_EVENTOH)->findOneBy(array("nreventom" => $nreventom, "nreventoh" => $nreventoh, "nrorg" => array($nrorg, $nrorgpadrao), "dtmescompetenc" => $preparedDateCompetenc));
                if ($obj == null) 
                    $obj = $this->entityManager->getRepository(Repositories::FPA_EVENTOH)->findOneBy(array("nreventom" => $nreventom, "nreventoh" => $nreventoh, "nrorg" => array($nrorg, $nrorgpadrao)));
                if($obj->getDtmescompetenc()->format("d/m/y") == $preparedDateCompetenc->format("d/m/y")) {
                    $obj->setNrnaturubr($row['NRNATURUBR']);
                    $obj->setDtultatu(DateUtil::getDatadeString($this->hcmParameters->getDataAtual()));
                    $obj->setNrorgultatu($nrorg);
                    $obj->setCdoperultatu($this->hcmParameters->getCdOperador());
                    $this->entityManager->persist($obj);
                    $this->entityManager->flush();
                } else {
                    $newobj = clone $obj;
                    $codigo = \HCM\Util\NovoCodigo::geraCodigo($nrorg, 'FPA_EVENTOH', 1, 12, true);    
                    $newobj->setNreventoh($codigo);
                    $newobj->setNrnaturubr($row['NRNATURUBR']);
                    $newobj->setDtinclusao(DateUtil::getDataDeString($this->hcmParameters->getDataAtual()));
                    $newobj->setDtultatu(DateUtil::getDatadeString($this->hcmParameters->getDataAtual()));
                    $newobj->setNrorgultatu($nrorg);
                    $newobj->setNrorginclusao($nrorg);
                    $newobj->setCdoperinclusao($this->hcmParameters->getCdOperador());
                    $newobj->setCdoperultatu($this->hcmParameters->getCdOperador());
                    $newobj->setDtmescompetenc($preparedDateCompetenc);
                    $this->entityManager->persist($newobj);
                    $this->entityManager->flush();
                }

            }
            $this->entityManager->commit();
        } catch (\Exception $e) {            
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function getEventoh($nreventom, $nreventoh){
        return $this->entityManager->getRepository(Repositories::FPA_EVENTOH)->findOneBy(array('nreventom' => $nreventom, 'nreventoh' => $nreventoh, 'nrorg' => $this->hcmParameters->getNrorgTrabalho()));
    }
    
    public function getRegrasEvento($nreventom, $nrorg){
        return $this->entityManager->getRepository(Repositories::FPA_REGRAH)->findOneBy(array('nreventom' => $nreventom, 'nrorg' => $this->hcmParameters->getNrorgTrabalho()));
    }

    public function replicacaoEvent($dataSet) {
        try {
            $nreventoM         = $dataSet['NREVENTOM'];
            $nrorgRow          = $dataSet['NRORG'];
            $nrorg             = $this->hcmParameters->getNrorgTrabalho();
            $nrorgPadrao       = intval($this->hcmParameters->getNrorgPadrao());
            $dtmescompetenc    = $this->hcmParameters->getDtCompetencia();
            $dateCompetenc     = DateUtil::getDatadeString($dtmescompetenc, DateUtil::FORMATO_BRASILEIRO, true);
            $dateCompetencRow  = DateUtil::getDatadeString($dataSet['DTMESCOMPETENC'], DateUtil::FORMATO_BRASILEIRO, true);

            $eventoM = $this->entityManager->getRepository(Repositories::FPA_EVENTOM)->findOneBy(['nreventom' => $nreventoM,'nrorg' => [$nrorgRow,$nrorgPadrao]]);
            $eventoH = $this->entityManager->getRepository(Repositories::FPA_EVENTOH)->findOneBy(['nreventom' => $nreventoM,'dtmescompetenc' => $dateCompetencRow,'nrorg' => [$nrorgRow,$nrorgPadrao]]);
                        
            if(is_object($eventoM) && is_object($eventoH)) {
                $auditoria = $this->setAuditoria();
                $nmeventoH = $eventoH->getNmeventoh().' [REPLICADO]';
                
                $this->entityManager->beginTransaction();

                //Replica o evento.
                $newNreventoM = $this->novoEvento($auditoria,                       $nrorg,                          $eventoM->getDtinivigencia(),      $eventoM->getDtfimvigencia(),      $eventoM->getIdtipoevento(),       $eventoM->getDtesocial(),       //2º ao 6º parâmetro referente a FPA_EVENTOM
                                                  $dateCompetenc,                   $nmeventoH,                      $eventoH->getIddtocorrencia(),     $eventoH->getIdeventodemonst(),    $eventoH->getIdfaltas13resc(),     $eventoH->getIdimpressevento(), //7º adiante referente a FPA_EVENTOH
                                                  $eventoH->getIdmediaevenferi(),   $eventoH->getIdrepdecterc(),     $eventoH->getIdrepdsr(),           $eventoH->getIdrepferias(),        $eventoH->getIdreprecisao(),       $eventoH->getIdretrocedeprov(),
                                                  $eventoH->getIdrefatestado(),     $eventoH->getIdpagtoobrig(),     $eventoH->getIdrefadecterc(),      $eventoH->getIdrefaferias(),       $eventoH->getIdrefadiant(),        $eventoH->getIdincideperic(),
                                                  $eventoH->getIdincideinsalub(),   $eventoH->getIdincidepensalim(), $eventoH->getIdincidepensalimfe(), $eventoH->getIdincidedsrhoraext(), $eventoH->getIdrefhoraextra(),     $eventoH->getIdincidedsradicnot(),
                                                  $eventoH->getIdrefadicionoturn(), $eventoH->getIdrefadictserv(),   $eventoH->getIdincidecsind(),      $eventoH->getIdsalariofamilia(),   $eventoH->getIdrefsegurovida(),    $eventoH->getIddeducaoinss(),
                                                  $eventoH->getIdretrocedevent(),   $eventoH->getIdzeraevenfecha(),  $eventoH->getIdcompsalfer(),       $eventoH->getIdcompsalprov(),      $eventoH->getIdproporcevento(),    $eventoH->getCdintegraevento(),
                                                  $eventoH->getDsobservacao(),      $eventoH->getIdfaltasferias(),   $eventoH->getIdgeravrzero(),       $eventoH->getIdmediavalref(),      $eventoH->getIdprocdifmovant(),    $eventoH->getIdprocdifrescis(),
                                                  $eventoH->getIdtipoarredonda(),   $eventoH->getIdtipoocorreven(),  $eventoH->getIdunidrefereven(),    $eventoH->getNrdigarredonda(),     $eventoH->getNreventoestorno(),    $eventoH->getNreventoneg(),
                                                  $eventoH->getNreventorescis(),    $eventoH->getNreventotransf(),   $eventoH->getNrhomologrubrica(),   $eventoH->getNrincidcp(),          $eventoH->getNrincidfgts(),        $eventoH->getNrincidirrf(),
                                                  $eventoH->getNrincidsind(),       $eventoH->getNrnaturubr(),       $eventoH->getNrordimpreseven(),    $eventoH->getNrpriorestorno(),     $eventoH->getQtlimirefereven(),    $eventoH->getQtminocorconsec(),
                                                  $eventoH->getQtminocormedfer(),   $eventoH->getVrlimitearred(),    $eventoH->getVrlimiteevento(),     $eventoH->getVrpelimitevento(),    $eventoH->getVrpercentualevento(), $eventoH->getVrpisoevento(),
                                                  $eventoH->getVrtetoevento(),      $eventoH->getIdgerarateio(),     $eventoH->getIdativo());

                
                if(!empty($newNreventoM)){
                    //Replica as incidências.
                    $incidencias = $this->entityManager->getRepository(Repositories::FPA_INCIDEVENTO)->retornaIncidenciasEvento($nrorg, $dtmescompetenc, $nrorgPadrao, $nreventoM);
                    
                    if(!empty($incidencias)) {
                        foreach($incidencias as $incidencia) {
                            $this->novaIncidencia($auditoria, $nrorg, $newNreventoM, $dateCompetenc, $incidencia->getIdincidevento(), $incidencia->getNrtipoincide());
                        }
                    }

                    //Replica a Parametrização eSocial.
                    $paramEsocial = $this->entityManager->getRepository(Repositories::ESO_RUBRICA)->findBy(['nreventom' => $nreventoM, 'nrorg' => [$nrorg,$nrorgPadrao]]);

                    if(!empty($paramEsocial)) {
                        foreach($paramEsocial as $param) {
                            $this->novoParamEsocial($auditoria, $nrorg, $newNreventoM, $param->getNrtipomoviment(), $param->getNrtiporubrica(), $param->getCdincidecp(),
                                                    $param->getCdincidefgts(), $param->getCdincideirrf(), $param->getIdativo());
                        }
                    }
                    
                    //Replica a Associação Contábil.
                    $assocCtbl = $this->entityManager->getRepository(Repositories::FPA_EVENTOCTBL)->findBy(['nreventom' => $nreventoM, 'nrorg' => $nrorg]);

                    if(!empty($assocCtbl)) {
                        foreach($assocCtbl as $assoc) {
                            $this->novoAssocCtbl($auditoria,                  $nrorg,                      $newNreventoM,              $assoc->getNrestruturam(),  $assoc->getIdvincativo(),   $assoc->getCdcontctbldeb(),
                                                 $assoc->getCdhistpadrdeb(),  $assoc->getCdcontctblcre(),  $assoc->getCdhistpadrcre(), $assoc->getDtinivigencia(), $assoc->getDtfimvigencia(), $assoc->getNrtipomoviment(),
                                                 $assoc->getCddespadmfat(),   $assoc->getNrtpeventoctbl());
                        }
                    }
                }
                $this->entityManager->commit();
                return true;
            }
            return false;

        } catch (\Exception $e) {
            $connection = $this->entityManager->getConnection();

            if($connection->isTransactionActive())
                $this->entityManager->rollback();

            throw $e;
        }
    }

    private function novoEvento($auditoria,              $nrorg,                  $dtinivigencia,           $dtfimvigencia   = null, $idtipoevento,              $dtesocial,       //2º ao 6º parâmetro referente a FPA_EVENTOM
                                $dtmescompetenc,         $nmeventoh,              $iddtocorrencia,          $ideventodemonst,        $idfaltas13resc,            $idimpressevento, //7º adiante referente a FPA_EVENTOH
                                $idmediaevenferi,        $idrepdecterc,           $idrepdsr,                $idrepferias,            $idreprecisao,              $idretrocedeprov,
                                $idrefatestado,          $idpagtoobrig,           $idrefadecterc,           $idrefaferias,           $idrefadiant,               $idincideperic,
                                $idincideinsalub,        $idincidepensalim,       $idincidepensalimfe,      $idincidedsrhoraext,     $idrefhoraextra,            $idincidedsradicnot,
                                $idrefadicionoturn,      $idrefadictserv,         $idincidecsind,           $idsalariofamilia,       $idrefsegurovida,           $iddeducaoinss,
                                $idretrocedevent,        $idzeraevenfecha,        $idcompsalfer,            $idcompsalprov,          $idproporcevento,           $cdintegraevento = null,
                                $dsobservacao    = null, $idfaltasferias  = null, $idgeravrzero     = null, $idmediavalref   = null, $idprocdifmovant    = null, $idprocdifrescis = null,
                                $idtipoarredonda = null, $idtipoocorreven = null, $idunidrefereven  = null, $nrdigarredonda  = null, $nreventoestorno    = null, $nreventoneg     = null,
                                $nreventorescis  = null, $nreventotransf  = null, $nrhomologrubrica = null, $nrincidcp       = null, $nrincidfgts        = null, $nrincidirrf     = null,
                                $nrincidsind     = null, $nrnaturubr      = null, $nrordimpreseven  = null, $nrpriorestorno  = null, $qtlimirefereven    = null, $qtminocorconsec = null,
                                $qtminocormedfer = null, $vrlimitearred   = null, $vrlimiteevento   = null, $vrpelimitevento = null, $vrpercentualevento = null, $vrpisoevento    = null,
                                $vrtetoevento    = null, $idgerarateio    = null, $idativo = 'S'){

        
        $eventom = $this->eventoMestre($auditoria, $nrorg, $dtinivigencia, $dtfimvigencia, $idtipoevento, $dtesocial);
        
        $this->eventoHistorico($auditoria,         $nrorg,            $eventom->getNreventom(), 
                               $dtmescompetenc,    $nmeventoh,        $iddtocorrencia,     $ideventodemonst,    $idfaltas13resc,     $idimpressevento,
                               $idmediaevenferi,   $idrepdecterc,     $idrepdsr,           $idrepferias,        $idreprecisao,       $idretrocedeprov,
                               $idrefatestado,     $idpagtoobrig,     $idrefadecterc,      $idrefaferias,       $idrefadiant,        $idincideperic,
                               $idincideinsalub,   $idincidepensalim, $idincidepensalimfe, $idincidedsrhoraext, $idrefhoraextra,     $idincidedsradicnot,
                               $idrefadicionoturn, $idrefadictserv,   $idincidecsind,      $idsalariofamilia,   $idrefsegurovida,    $iddeducaoinss,
                               $idretrocedevent,   $idzeraevenfecha,  $idcompsalfer,       $idcompsalprov,      $idproporcevento,    $cdintegraevento,
                               $dsobservacao,      $idfaltasferias,   $idgeravrzero,       $idmediavalref,      $idprocdifmovant,    $idprocdifrescis,
                               $idtipoarredonda,   $idtipoocorreven,  $idunidrefereven,    $nrdigarredonda,     $nreventoestorno,    $nreventoneg,
                               $nreventorescis,    $nreventotransf,   $nrhomologrubrica,   $nrincidcp,          $nrincidfgts,        $nrincidirrf,
                               $nrincidsind,       $nrnaturubr,       $nrordimpreseven,    $nrpriorestorno,     $qtlimirefereven,    $qtminocorconsec,
                               $qtminocormedfer,   $vrlimitearred,    $vrlimiteevento,     $vrpelimitevento,    $vrpercentualevento, $vrpisoevento,
                               $vrtetoevento,      $idgerarateio,     $idativo);
        
        return $eventom->getNreventom();
    }
    
    private function eventoMestre($auditoria, $nrorg, $dtinivigencia, $dtfimvigencia, $idtipoevento, $dtesocial){
        try{
            $eventom = new $this->fpaeventom;
        
            $eventom->setNrorg($nrorg);
            $eventom->setDtinivigencia($dtinivigencia);
            $eventom->setDtfimvigencia($dtfimvigencia);
            $eventom->setIdtipoevento($idtipoevento);
            $eventom->setDtesocial($dtesocial);

            //Auditoria
            $eventom->setDtinclusao($auditoria['DTINCLUSAO']);
            $eventom->setDtultatu($auditoria['DTULTATU']);
            $eventom->setNrorginclusao($auditoria['NRORGINCLUSAO']);
            $eventom->setCdoperinclusao($auditoria['CDOPERINCLUSAO']);
            $eventom->setCdoperultatu($auditoria['CDOPERULTATU']);
            $eventom->setNrorgultatu($auditoria['NRORGULTATU']);

            $eventom->setNreventom(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'FPA_EVENTOM', 1, 12, true));
            
            $this->entityManager->persist($eventom);
            $this->entityManager->flush();
            
            return $eventom;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    private function eventoHistorico($auditoria,         $nrorg,            $nreventom,
                                     $dtmescompetenc,    $nmeventoh,        $iddtocorrencia,     $ideventodemonst,    $idfaltas13resc,     $idimpressevento,
                                     $idmediaevenferi,   $idrepdecterc,     $idrepdsr,           $idrepferias,        $idreprecisao,       $idretrocedeprov,
                                     $idrefatestado,     $idpagtoobrig,     $idrefadecterc,      $idrefaferias,       $idrefadiant,        $idincideperic,
                                     $idincideinsalub,   $idincidepensalim, $idincidepensalimfe, $idincidedsrhoraext, $idrefhoraextra,     $idincidedsradicnot,
                                     $idrefadicionoturn, $idrefadictserv,   $idincidecsind,      $idsalariofamilia,   $idrefsegurovida,    $iddeducaoinss,
                                     $idretrocedevent,   $idzeraevenfecha,  $idcompsalfer,       $idcompsalprov,      $idproporcevento,    $cdintegraevento,
                                     $dsobservacao,      $idfaltasferias,   $idgeravrzero,       $idmediavalref,      $idprocdifmovant,    $idprocdifrescis,
                                     $idtipoarredonda,   $idtipoocorreven,  $idunidrefereven,    $nrdigarredonda,     $nreventoestorno,    $nreventoneg,
                                     $nreventorescis,    $nreventotransf,   $nrhomologrubrica,   $nrincidcp,          $nrincidfgts,        $nrincidirrf,
                                     $nrincidsind,       $nrnaturubr,       $nrordimpreseven,    $nrpriorestorno,     $qtlimirefereven,    $qtminocorconsec,
                                     $qtminocormedfer,   $vrlimitearred,    $vrlimiteevento,     $vrpelimitevento,    $vrpercentualevento, $vrpisoevento,
                                     $vrtetoevento,      $idgerarateio,     $idativo) {

        try{
            $eventoh = new $this->fpaeventoh;

            $eventoh->setNrorg($nrorg);
            $eventoh->setNreventom($nreventom);
            $eventoh->setCdintegraevento($cdintegraevento);
            
            $eventoh->setDtmescompetenc($dtmescompetenc);
            $eventoh->setIdativo($idativo);
            $eventoh->setIddtocorrencia($iddtocorrencia);
            $eventoh->setIdeventodemonst($ideventodemonst);
            $eventoh->setDsobservacao($dsobservacao);
            $eventoh->setIdfaltasferias($idfaltasferias);
            $eventoh->setIdfaltas13resc($idfaltas13resc);
            $eventoh->setIdgeravrzero($idgeravrzero);
            $eventoh->setIdimpressevento($idimpressevento);
            $eventoh->setIdmediaevenferi($idmediaevenferi);
            $eventoh->setIdmediavalref($idmediavalref);
            $eventoh->setIdprocdifmovant($idprocdifmovant);
            $eventoh->setIdprocdifrescis($idprocdifrescis);
            $eventoh->setIdrepdecterc($idrepdecterc);
            $eventoh->setIdrepdsr($idrepdsr);
            $eventoh->setIdrepferias($idrepferias);
            $eventoh->setIdreprecisao($idreprecisao);
            $eventoh->setIdretrocedeprov($idretrocedeprov);
            $eventoh->setIdretrocedevent($idretrocedevent);
            $eventoh->setIdtipoarredonda($idtipoarredonda);
            $eventoh->setIdtipoocorreven($idtipoocorreven);
            $eventoh->setIdunidrefereven($idunidrefereven);
            $eventoh->setIdzeraevenfecha($idzeraevenfecha);
            $eventoh->setNrdigarredonda($nrdigarredonda);
            $eventoh->setNreventoestorno($nreventoestorno);
            $eventoh->setNreventoneg($nreventoneg);
            $eventoh->setNreventorescis($nreventorescis);
            $eventoh->setNreventotransf($nreventotransf);
            $eventoh->setNrhomologrubrica($nrhomologrubrica);
            $eventoh->setNrincidcp($nrincidcp);
            $eventoh->setNrincidfgts($nrincidfgts);
            $eventoh->setNrincidirrf($nrincidirrf);
            $eventoh->setNrincidsind($nrincidsind);
            $eventoh->setNrnaturubr($nrnaturubr);
            $eventoh->setNrordimpreseven($nrordimpreseven);
            $eventoh->setNrpriorestorno($nrpriorestorno);
            $eventoh->setQtlimirefereven($qtlimirefereven);
            $eventoh->setQtminocorconsec($qtminocorconsec);
            $eventoh->setQtminocormedfer($qtminocormedfer);
            $eventoh->setVrlimitearred($vrlimitearred);
            $eventoh->setVrlimiteevento($vrlimiteevento);
            $eventoh->setVrpelimitevento($vrpelimitevento);
            $eventoh->setVrpercentualevento($vrpercentualevento);
            $eventoh->setVrpisoevento($vrpisoevento);
            $eventoh->setVrtetoevento($vrtetoevento);
            $eventoh->setIdcompsalfer($idcompsalfer);
            $eventoh->setIdcompsalprov($idcompsalprov);
            $eventoh->setIdrefatestado($idrefatestado);
            $eventoh->setIdpagtoobrig($idpagtoobrig);
            $eventoh->setIdrefadecterc($idrefadecterc);
            $eventoh->setIdrefaferias($idrefaferias);
            $eventoh->setIdrefadiant($idrefadiant);
            $eventoh->setIdincideperic($idincideperic);
            $eventoh->setIdincideinsalub($idincideinsalub);
            $eventoh->setIdincidepensalim($idincidepensalim);
            $eventoh->setIdincidepensalimfe($idincidepensalimfe);
            $eventoh->setIdincidedsrhoraext($idincidedsrhoraext);
            $eventoh->setIdrefhoraextra($idrefhoraextra);
            $eventoh->setIdincidedsradicnot($idincidedsradicnot);
            $eventoh->setIdrefadicionoturn($idrefadicionoturn);
            $eventoh->setIdrefadictserv($idrefadictserv);
            $eventoh->setIdincidecsind($idincidecsind);
            $eventoh->setIdsalariofamilia($idsalariofamilia);
            $eventoh->setIdrefsegurovida($idrefsegurovida);
            $eventoh->setIddeducaoinss($iddeducaoinss);
            $eventoh->setIdproporcevento($idproporcevento);
            $eventoh->setIdgerarateio($idgerarateio);
        
            //Auditoria
            $eventoh->setDtinclusao($auditoria['DTINCLUSAO']);
            $eventoh->setDtultatu($auditoria['DTULTATU']);
            $eventoh->setNrorginclusao($auditoria['NRORGINCLUSAO']);
            $eventoh->setCdoperinclusao($auditoria['CDOPERINCLUSAO']);
            $eventoh->setCdoperultatu($auditoria['CDOPERULTATU']);
            $eventoh->setNrorgultatu($auditoria['NRORGULTATU']);

            $eventoh->setNreventoh(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'FPA_EVENTOH', 1, 12, true));
            if(empty($nmeventoh)){
                $nmeventoh = 'Evento replicado - '.$eventoh->getNreventoh();
            }
            $eventoh->setNmeventoh($nmeventoh);
            
            $this->entityManager->persist($eventoh);
            $this->entityManager->flush();
        } catch(\Exception $e) {
            throw $e;
        }
    }

    private function setAuditoria(){
        $dtinclusao     = $this->hcmParameters->getDataAtual();
        $cdoperinclusao = $this->hcmParameters->getCdoperador();
        $nrorginclusao  = $this->hcmParameters->getNrorgTrabalho();
        $nrorgultatu    = $this->hcmParameters->getNrorgTrabalho();
        $nrorg          = $this->hcmParameters->getNrorgTrabalho();

        $auditoria = ['DTINCLUSAO'     => DateUtil::getDataDeString($dtinclusao),
                      'DTULTATU'       => DateUtil::getDataDeString($dtinclusao),
                      'CDOPERINCLUSAO' => $cdoperinclusao,
                      'CDOPERULTATU'   => $cdoperinclusao,
                      'NRORGINCLUSAO'  => $nrorginclusao,
                      'NRORGULTATU'    => $nrorgultatu,
                      'NRORG'          => $nrorg];
        
        return $auditoria;
    }

    private function novaIncidencia($auditoria, $nrorg, $nreventoM, $dtmescompetenc, $idincidevento, $nrtipoincide){
        try{
            $obj = new $this->fpaincidevento;
            
            $codigo = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'FPA_INCIDEVENTO', 1, 12, true);
            $obj->setDtmescompetenc($dtmescompetenc);
            $obj->setNreventom($nreventoM);
            $obj->setIdincidevento($idincidevento);
            $obj->setNrtipoincide($nrtipoincide);
            $obj->setNrincidevento($codigo);
            $obj->setNrorg($nrorg);
            
            //Auditoria
            $obj->setDtinclusao($auditoria['DTINCLUSAO']);
            $obj->setDtultatu($auditoria['DTULTATU']);
            $obj->setNrorginclusao($auditoria['NRORGINCLUSAO']);
            $obj->setCdoperinclusao($auditoria['CDOPERINCLUSAO']);
            $obj->setCdoperultatu($auditoria['CDOPERULTATU']);
            $obj->setNrorgultatu($auditoria['NRORGULTATU']);

            $this->entityManager->persist($obj);
            $this->entityManager->flush();
        } catch(\Exception $e) {
            throw $e;
        }
    }

    private function novoParamEsocial($auditoria, $nrorg, $nreventoM, $nrtipomoviment, $nrtiporubrica, $cdincidecp, $cdincidefgts, $cdincideirrf, $idativo){
        try {
            $novo = new $this->esorubrica;

            $novo->setNrrubrica(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'ESO_RUBRICA', 1, 12, true));
            $novo->setNreventom($nreventoM);
            $novo->setNrtipomoviment($nrtipomoviment);
            $novo->setNrtiporubrica($nrtiporubrica);
            $novo->setCdincidecp($cdincidecp);
            $novo->setCdincidefgts($cdincidefgts);
            $novo->setCdincideirrf($cdincideirrf);
            $novo->setNrorg($nrorg);
            $novo->setIdativo($idativo);
            
            //Auditoria
            $novo->setDtinclusao($auditoria['DTINCLUSAO']);
            $novo->setDtultatu($auditoria['DTULTATU']);
            $novo->setNrorginclusao($auditoria['NRORGINCLUSAO']);
            $novo->setCdoperinclusao($auditoria['CDOPERINCLUSAO']);
            $novo->setCdoperultatu($auditoria['CDOPERULTATU']);
            $novo->setNrorgultatu($auditoria['NRORGULTATU']);
            
            $this->entityManager->persist($novo);
            $this->entityManager->flush();
        } catch(\Exception $e) {
            throw $e;
        }
    }

    private function novoAssocCtbl($auditoria,      $nrorg,          $nreventoM,     $nrestruturam,  $idvincativo,   $cdcontctbldeb,
                                   $cdhistpadrdeb,  $cdcontctblcre,  $cdhistpadrcre, $dtinivigencia, $dtfimvigencia, $nrtipomoviment,
                                   $cddespadmfat,   $nrtpeventoctbl){
        try {
            $eventoctbloper = new $this->associacao();

            $codigo = \HCM\Util\NovoCodigo::geraCodigo($nrorg, 'FPA_EVENTOCTBL', 1, 12, true);
            $eventoctbloper->setNreventoctbl($codigo);
            $eventoctbloper->setNrorg($nrorg);
            $eventoctbloper->setNreventom($nreventoM);
            $eventoctbloper->setNrestruturam($nrestruturam);
            $eventoctbloper->setIdvincativo($idvincativo);
            $eventoctbloper->setCdcontctbldeb($cdcontctbldeb);
            $eventoctbloper->setCdhistpadrdeb($cdhistpadrdeb);
            $eventoctbloper->setCdcontctblcre($cdcontctblcre);
            $eventoctbloper->setCdhistpadrcre($cdhistpadrcre);
            $eventoctbloper->setDtinivigencia($dtinivigencia);
            $eventoctbloper->setDtfimvigencia($dtfimvigencia);
            $eventoctbloper->setNrtipomoviment($nrtipomoviment);
            $eventoctbloper->setCddespadmfat($cddespadmfat);
            $eventoctbloper->setNrtpeventoctbl($nrtpeventoctbl);
            
            //Auditoria
            $eventoctbloper->setDtinclusao($auditoria['DTINCLUSAO']);
            $eventoctbloper->setDtultatu($auditoria['DTULTATU']);
            $eventoctbloper->setNrorginclusao($auditoria['NRORGINCLUSAO']);
            $eventoctbloper->setCdoperinclusao($auditoria['CDOPERINCLUSAO']);
            $eventoctbloper->setCdoperultatu($auditoria['CDOPERULTATU']);
            $eventoctbloper->setNrorgultatu($auditoria['NRORGULTATU']);
            
            $this->entityManager->persist($eventoctbloper);
            $this->entityManager->flush();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
}