<?php

namespace HCM\FPA\Services;

use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Valor;
use HCM\Util\DateUtil;
use HCM\FPA\Repository\ReajusteRepository;
use HCM\Geral\Entity\GpealtesalarioEntity;
use HCM\Geral\Entity\GpealtesitufuncEntity;
use HCM\Geral\Services\AlteSalarioService;
use Doctrine\DBAL\Connection;
use HCM\Util\Repositories;
use \HCM\Util\NovoCodigo;
use HCM\Geral\Entity\GpevinculomEntity;


class ReajusteService {
    
    protected $entityManager;
    protected $hcmParameters;
    protected $ReajusteRepository;

    public function __construct(EntityManager $entityManager, Connection $connection, HCMParameters $hcmParameters, AlteSalarioService $alteSalarioService, ReajusteRepository $ReajusteRepository) {
        $this->entityManager = $entityManager;
        $this->connection    = $connection;
        $this->hcmParameters = $hcmParameters;
        $this->alteSalarioService = $alteSalarioService;
        $this->ReajusteRepository = $ReajusteRepository;
        $this->gpe_Altesalario = Repositories::GPE_ALTESALARIO;
        $this->alteracaoSalario = new GpealtesalarioEntity($entityManager, $hcmParameters);
        $this->alteracaoSituacao = new GpealtesitufuncEntity($entityManager, $hcmParameters);
        $this->_vinculom = new GpevinculomEntity($entityManager, $hcmParameters);

    }
    public function reajustarSalario($dataSet, $response) {
        
        $message = array();
        
        $nrestrutSind = isset($dataSet['LISTA_NRESTRUTSIND']) ? $dataSet['LISTA_NRESTRUTSIND'] : null;
        $nrTpvinculo = isset($dataSet['NRTIPOVINC']) ? $dataSet['NRTIPOVINC'] : null;
        $nrVinculoEmpreg = isset($dataSet['NRVINCEMPREG']) ? $dataSet['NRVINCEMPREG'] : null;
        $ocupacao = isset($dataSet['NROCUPACAOM']) ? $dataSet['NROCUPACAOM'] : null;
        $demonstrativo = array();
        $grava = array();
        $vrfaixasalini;
        $vrfaixasalfim;
        $vrPercentual;
        $vrConstante;
        
        if($dataSet['DSORDEM'] == 'TIPO_HIERARQUIA'){
            $ds_inicio['DSINICIO']  = $dataSet['DSINICIO'];
            $ds_inicio['DSINICIO2'] = array_key_exists('DSINICIO2', $dataSet) ? $dataSet['DSINICIO2'] : null;
            $dataSet['DSINICIO'] = $ds_inicio;
            $ds_fim['DSFIM2'] = array_key_exists('DSFIM2', $dataSet) ? $dataSet['DSFIM2'] : null;
            $dataSet['DSFIM'] = $ds_fim;
        }
        $vinculos = $this->_vinculom->retornaVinculosAtivosMesCompetencia(
            $dataSet['NRORG'], $this->hcmParameters->getDtCompetencia(), $dataSet['DSINICIO'], $dataSet['DSFIM'], $dataSet['DSORDEM'], true,
            null, true,  false,  $nrTpvinculo,  $nrVinculoEmpreg, $nrestrutSind, null, null, null, $ocupacao);
       
       
        foreach($vinculos as $index => $vinc) {
            $carregou = $this->alteracaoSalario->carregaAlteracaoSalario(
                DateUtil::getDataDeString(substr($dataSet['DTALTSALARIO'],0,10)), $vinc->getNrvinculom(), $dataSet['NRTPMODSALFONTE']);
            if ($carregou === true) {
                $valor = $this->alteracaoSalario->getSalario();
                $tipoSalario = $this->alteracaoSalario->getTipoSalario();
            } else {
                $message[] = array("msg" => "Vinculo sem salário informado", "row" => $vinc->getNrvinculom(), "rowName" => $vinc->getNmvinculom(), "type" => 'Erro');
                continue;
            }
            if(!$valor){
                $message[] = array("msg" => "Vinculo sem salário informado (alteração de salário)", "row" => $vinc->getNrvinculom(), "rowName" => $vinc->getNmvinculom(), "type" => 'Erro');
                continue;
            }
                
            if(!$tipoSalario){
                $message[] = array("msg" => "Vinculo sem tipo de salário informado (alteração de salário)", "row" => $vinc->getNrvinculom(), "rowName" => $vinc->getNmvinculom(), "type" => 'Erro');
                continue;
            }
            
            if($dataSet['IDTIPOFAIXA'] == 'FAIXA') {
                $vrfaixasalini = empty($dataSet['VRFAIXASALINI']) ? $valor : $dataSet['VRFAIXASALINI'];
                $vrfaixasalfim = empty($dataSet['VRFAIXASALFIM']) ? $valor : $dataSet['VRFAIXASALFIM'];
                $vrPercentual = $dataSet['VRPERCALTERA'];
            } else if($dataSet['IDTIPOFAIXA'] == 'TABELA') {
                foreach ($this->ReajusteRepository->getFaixaTabela($dataSet['NRORG'],$dataSet['NRTABELAFOLHA']) as $faixa) {
                    
                    if(!$faixa['VRLIMITSUPFAIXA']) {
                        throw new \Exception("Faixa da tabela folha sem vr. mínimo", 10);
                        
                    }else if(!$faixa['VRMAXRESULTCALC']) {
                        throw new \Exception("Faixa da tabela folha sem vr. máximo", 10);
                        
                    }else if(!$faixa['VRPECALCULORESU'] && !$faixa['VRAPLICARESULT']) {
                        throw new \Exception("A faixa da tabela folha deve ter vr. constante ou percentagem de calculo", 10);
                        
                    }else if( $valor >= $faixa['VRLIMITSUPFAIXA'] && $valor <= $faixa['VRMAXRESULTCALC'] ) {
                        $vrfaixasalini = $faixa['VRLIMITSUPFAIXA'];
                        $vrfaixasalfim = $faixa['VRMAXRESULTCALC'];
                        $vrPercentual = array_key_exists('VRPECALCULORESU', $faixa) ? $faixa['VRPECALCULORESU'] : null;
                        $vrConstante = array_key_exists('VRAPLICARESULT', $faixa) ? $faixa['VRAPLICARESULT'] : null;
                    }
                }
                if(empty($vrfaixasalini)){
                    $vrfaixasalini = $valor+1;
                }
                if(empty($vrfaixasalfim)){
                    $vrfaixasalfim = $valor-1;
                }
            } else {
                $vrfaixasalini = $valor;
                $vrfaixasalfim = $valor;
            } 
            
            
            
            if( $valor >= $vrfaixasalini && $valor <= $vrfaixasalfim ) {
                
                if (!isset($vrConstante) || is_null($vrConstante)) {
                    if ($dataSet['IDPROPORCIONAL'] == 'N') { 
                        $valor_reajuste = $valor * $vrPercentual / 100;
                    } else {
                        if ((int)$dataSet['NRQDEDIASTRAB'] == 0) {
                            throw new \Exception("É Necessario informar o número de dias trabalhados", 10);
                            
                        }
                        
                        $dtVerificaMes = $dataSet['DTBASE'] ? substr($dataSet['DTBASE'], 0, 10) : $this->hcmParameters->getDtCompetencia();
                        $dtVerificaMes = DateUtil::subtraiIntervalo($dtVerificaMes, 1, DateUtil::MES)->format('d/m/Y');
                        
                        $qdeMesesSal = $this->calculaDiasTrabalhoMes($vinc, $dtVerificaMes, (int)$dataSet['NRQDEDIASTRAB']);

                        $valor_reajuste = (($vrPercentual / 100) / 12 * $qdeMesesSal) * $valor;
                    }
                } else {
                    $valor_reajuste = $vrConstante;
                }

                $salario_reajustado = $valor + $valor_reajuste;

                if (!empty($dataSet['VRPISOSALARIO'])) {
                    if ($salario_reajustado < $dataSet['VRPISOSALARIO']) {
                        $salario_reajustado = $dataSet['VRPISOSALARIO'];
                    }
                }

                if (!empty($dataSet['VRTETOSALARIO'])) {
                    if ($salario_reajustado > $dataSet['VRTETOSALARIO']) {
                        $salario_reajustado = $dataSet['VRTETOSALARIO'];
                        if ($valor > $salario_reajustado) {
                            $salario_reajustado = $valor;
                        }
                    }
                }

                $salario_reajustado = Valor::arredonda(
                    $salario_reajustado, $dataSet['IDTPARREDONDAME'], $dataSet['NRDIGARREDONDAM'], $dataSet['NRLIMARREDONDAM']
                );

                $vr_diferenca_real = $salario_reajustado - $valor;
                $vr_percentual_real = ($vr_diferenca_real * 100) / ($valor == 0?1:$valor);
                
                if ($dataSet['IDSIMULACAO']) {
                    array_push($demonstrativo, array(
                        "NMVINCULOM"=>($vinc->getNrvinculom().' - '.$vinc->getNmvinculom()),
                        "VRSALANT"=>$valor,
                        "VRSALREAJ"=>$salario_reajustado,
                        "VRPERCENT"=>"$vr_percentual_real",
                        "VRDIFER"=>$vr_diferenca_real
                    ));
                    if(count($demonstrativo) == 10 || (sizeof($vinculos)-1) == $index) {
                        if(!empty($message)){
                            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('msg', $message));
                        }
                        return $demonstrativo;
                    }
                } else {
                    
                    array_push($grava, array(
                        "NRVINCULOM"=>$vinc->getNrvinculom(),
                        "DTADMISSAOVINC"=>$vinc->getDtadmissaovinc(),
                        "DTALTSALARIO"=>$dataSet['DTALTSALARIO'],
                        "DTBASE"=>$dataSet['DTBASE'],
                        "NRTPMODSALDEST"=>$dataSet['NRTPMODSALDEST'],
                        "DTBASE"=>$dataSet['DTBASE'],
                        "VRPERCALTERA"=>$dataSet['VRPERCALTERA'],
                        "NRTIPOALTERA"=>$dataSet['NRTIPOALTERA'],
                        "NRORG"=>$dataSet['NRORG'],
                        "IDTPSALARIO"=>$tipoSalario,
                        "VRSALREAJ"=>$salario_reajustado,
                        "VRDIFER"=>$vr_diferenca_real,
                        "VRPERCENT"=>"$vr_percentual_real"
                    ));
                }
                
            } //Fim da verificação de escopo da faixa salarial
        } //Fim do percorre vínculos
        
        if(!empty($message)){
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('msg', $message));
        }
        
        if($grava) {
            foreach ($grava as $alt) {
                $obj = new $this->gpe_Altesalario;
                $obj->setNrorg($alt['NRORG']);
                $obj->setNrorginclusao($alt['NRORG']);
                $obj->setDtinclusao(DateUtil::getDataAtual());
                $obj->setCdoperinclusao($this->hcmParameters->getCdoperador());
                $obj->setNrorgultatu($alt['NRORG']);
                $obj->setDtultatu(DateUtil::getDataAtual());
                $obj->setCdoperultatu($this->hcmParameters->getCdoperador());
                $obj->setNrtipoaltera($alt['NRTIPOALTERA']);
                $obj->setVrpercaltera($alt['VRPERCALTERA']);
                $obj->setVrsalario($alt['VRSALREAJ']);
                $obj->setNrtpmodalidsal($alt['NRTPMODSALDEST']);
                $obj->setNraltesalario(Novocodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'GPE_ALTESALARIO', 1, 22, true, false));
                $obj->setVrdiferencareal($alt['VRDIFER']);
                $obj->setNrvinculom($alt['NRVINCULOM']);
                $obj->setVrpercreal($alt['VRPERCENT']);
                $obj->setDtaltesalario($this->validaDtAltSalario($alt));
                $obj->setDtbasedissidio(DateUtil::getDataDeString(substr($alt['DTBASE'],0,10),DateUtil::FORMATO_BRASILEIRO,true));
                $obj->setIdtpsalario($alt['IDTPSALARIO']);
                $this->entityManager->persist($obj);
                $this->entityManager->flush($obj);
                
                // atualiza histórico vínculo
                $this->alteSalarioService->afterInsert($alt['NRORG'], $alt['NRVINCULOM']);
                $this->alteSalarioService->afterSave($alt['NRORG'], $alt['NRVINCULOM']);
            }

            return($grava);
        } else if($demonstrativo) {
            return($demonstrativo);        
        } else {
            if(!$message){
                throw new \Exception("Não foi possível realizar o cálculo de Reajuste Salarial para nenhum vínculo.", 10);
            }
        }
    }
    
    protected function validaDtAltSalario($alt) {
        $dtaltsalario = DateUtil::getDataDeString(substr($alt['DTALTSALARIO'],0,10),DateUtil::FORMATO_BRASILEIRO,true);
        $dtadmissaovinc = $alt['DTADMISSAOVINC'];
        $dataRetornada = $dtaltsalario;
        
        if(DateUtil::comparaDatas($dtaltsalario, $dtadmissaovinc)){
            if(DateUtil::getMes($dtaltsalario) === DateUtil::getMes($dtadmissaovinc)){
               $dataRetornada = DateUtil::adicionaIntervalo($dtadmissaovinc, 1);
            }
        }
        
        return $dataRetornada;
    }
    
    public function retrocede($dataSet){
        try{
            if($dataSet['DSORDEM'] == 'TIPO_HIERARQUIA'){
                $ds_inicio['DSINICIO']  = $dataSet['DSINICIO'];
                $ds_inicio['DSINICIO2'] = array_key_exists('DSINICIO2', $dataSet) ? $dataSet['DSINICIO2'] : null;
                $dataSet['DSINICIO'] = $ds_inicio;
                $ds_fim['DSFIM2'] = array_key_exists('DSFIM2', $dataSet) ? $dataSet['DSFIM2'] : null;
                $dataSet['DSFIM'] = $ds_fim;
            }
            $nrestrutSind = isset($dataSet['NRESTRUTSIND']) ? $dataSet['NRESTRUTSIND'] : null;
            $nrTpvinculo = isset($dataSet['NRTIPOVINC']) ? $dataSet['NRTIPOVINC'] : null;
            $nrVinculoEmpreg = isset($dataSet['NRVINCEMPREG']) ? $dataSet['NRVINCEMPREG'] : null;
            
            $vinculos = $this->_vinculom->retornaVinculosAtivosMesCompetencia(
                $dataSet['NRORG'], $this->hcmParameters->getDtCompetencia(), $dataSet['DSINICIO'], $dataSet['DSFIM'], $dataSet['DSORDEM'], true,
                null, true,  false,  $nrTpvinculo,  $nrVinculoEmpreg, $nrestrutSind);
            
            foreach($vinculos as $vinculo){
                $obj = $this->entityManager->getRepository(Repositories::GPE_ALTESALARIO)->findBy(array("nrorg"=>$dataSet['NRORG'], "nrvinculom" => $vinculo->getNrvinculom(), "dtaltesalario" => (DateUtil::getDataDeString(substr($dataSet['DTALTSALARIO'],0,10),DateUtil::FORMATO_BRASILEIRO,true))));
                if($obj){
                    $this->entityManager->remove($obj[0]);
                }
            }
            $this->entityManager->flush();
            $this->entityManager->commit();
        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
            
    }
    
    public function calculaDiasTrabalhoMes( $vinculo,  $competencia ,$nrqdediastrab ){
        $nrorg     = $vinculo->getNrorg();
        $nrVinculo = $vinculo->getNrvinculom();
        $dtAdmissao = $vinculo->getDtadmissaovinc();
        $modalid   = $this->hcmParameters->getNrModalidadeCalculo();
        $qdeMes    = 0; 
        $comp = DateUtil::getDataDeString($competencia);
        
        $maior1ano = DateUtil::getQtdeDiasEntre($vinculo->getDtadmissaovinc(), $comp) > 365 ? true : false;
        
        if($maior1ano){
            return 12;
        }else{
            return DateUtil::getQtdeMesesEntre($vinculo->getDtadmissaovinc(), $comp);
        }
        
        /* --------------- Escopo relacionado à consideração de afastamento e faltas.
        for($i = 0; $i < 12; $i++){
            $dt_ini = $comp; 
            $dt_fim = DateUtil::getUltimoDiaDoMes($dt_ini);
            $situacao_funcional = $this->alteracaoSituacao->retornaAlteracaoSituacaoFuncional($nrorg, $nrVinculo, $dtAdmissao);
            $afastamento = $this->alteracaoSituacao->retornaDiasAfastamento( $situacao_funcional, $dt_ini, $dt_fim, false );
            $diasTrabalho = 0;
            foreach($afastamento as $situacao)  
                if($situacao == 1)
                    $diasTrabalho++;

            $dtComp = $dt_ini->format('d/m/Y');
            $sql = "
SELECT
  SUM( DECODE( EVH.IDFALTASFERIAS, 'SOMA',     ICF.VRREFFOLHA,
                                   'SUBTRAI', -ICF.VRREFFOLHA, 0 ) ) FALTAS_DIAS
FROM FPA_ITECALCFOLHA ICF
JOIN FPA_CALCULOFOLHA CF ON CF.NRORG            = ICF.NRORG
                        AND CF.NRCALCULOFOLHA   = ICF.NRCALCULOFOLHA
                        AND CF.NRTIPOMOVIMENT = 1
                        AND CF.NRTPMODALIDCAL = ".$modalid."
                        AND CF.DTOCORRENCIA = '".$dtComp."'
JOIN FPA_EVENTOH EVH ON ( EVH.NRORG = 0 OR EVH.NRORG = ICF.NRORG )
                    AND EVH.NREVENTOM = ICF.NREVENTOM
                    AND EVH.IDFALTASFERIAS = 'SOMA'
                    AND EVH.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM FPA_EVENTOH
                                               WHERE DTMESCOMPETENC <= '".$dtComp."'
                                                 AND ( NRORG = 0 OR NRORG = ICF.NRORG )
                                                 AND NREVENTOM = ICF.NREVENTOM )

WHERE ICF.NRORG      = ".$nrorg."
  AND ICF.NRVINCULOM = ".$nrVinculo."
";
            $sqlResult = $this->entityManager->getConnection()->prepare($sql);
            $sqlResult->execute();
            $sqlResult = $sqlResult->fetchAll();
            $faltasDias = (int)$sqlResult[0]['FALTAS_DIAS'];

            if(($diasTrabalho - $faltasDias) >= $nrqdediastrab){
                $qdeMes++;
            }

            $comp = DateUtil::subtraiIntervalo($comp,1);
            $comp = DateUtil::getPrimeiroDiaDoMes($comp);
        }
        
        
        return $qdeMes;
        --------------- */
    }
}