<?php

namespace HCM\FPA\Services;

use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Repositories;
use HCM\Geral\Services\AlteSituacaoFuncionalService;
use HCM\Geral\Services\MovimentacaoService;
use HCM\Geral\Services\VinculoServices;
use HCM\Util\DateUtil;
use HCM\Geral\Services\AlteEscalaService;

class RescisaoService {
    
    protected $entityManager;
    protected $hcmParameters;
    const INSERE_VINCULO = 'INSERE';
    const ALTERA_VINCULO = 'ALTERA';
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters, AlteSituacaoFuncionalService $AlteSituacaoFuncionalService,
    MovimentacaoService $MovimentacaoService,VinculoServices $VinculoServices, AlteEscalaService $AlteEscalaServices) {
        $this->entityManager      = $entityManager;
        $this->hcmParameters      = $hcmParameters;
        $this->gpe_Vinculom = Repositories::GPE_VINCULOM;
        $this->AlteSituacaoFuncionalService = $AlteSituacaoFuncionalService;
        $this->MovimentacaoService = $MovimentacaoService;
        $this->VinculoServices = $VinculoServices;
        $this->AlteEscalaService = $AlteEscalaServices;
        
    }
    
    public function executaRescisaoColetiva($dataset) {
        try {
            $count = 0;
            $this->entityManager->beginTransaction();
            $nrorg = $this->hcmParameters->getNrorgTrabalho();
            $dtmescompetencia = $this->hcmParameters->getDtCompetencia();
            $idoperacao = $dataset['IDOPERACAO'];
            $vinculosVerificados = [];
            
            if($dataset['DSORDEM'] == 'LISTA_VINCULO') {
                foreach($dataset['NRVINCULOM_LIST'] as $nrVinculo) {
                    $this->execRescisaoColetiva($count, $nrorg, $dtmescompetencia, $idoperacao, $dataset, $nrVinculo);
                }
            }
            else if($dataset['DSORDEM'] == 'LISTA_LOTE') {
                foreach($dataset['NRLOTEVINC_LIST'] as $nrlotevinc){
                    $vinculosLote = $this->entityManager->getRepository(Repositories::FPA_ITEMLOTEVINC)->findBy(['nrorg' => $nrorg, 'nrlotevinc' => $nrlotevinc]);
                    $vinculosLote = $vinculosLote ? $vinculosLote : [];

                    foreach($vinculosLote as $objVinc){
                        $nrvinculom = $objVinc->getNrvinculom();

                        if(!in_array($nrvinculom, $vinculosVerificados)) { //Impede executar a rescisão para o mesmo vinculo mais de uma vez, pois um mesmo vínculo pode estar inserido em lotes diferentes.
                            if($dataset['RECIBOPAGTO_NRESTRUTLEGAL']) { //Caso seja lote da tela de recibo de pagto só executa a rescisão se a estrutura legal posicionada na tela for a mesma dos vinculos que estão dentro do lote.
                                
                                $vinculoh = $this->entityManager->getRepository(Repositories::GPE_VINCULOH)->retornaUltimoHistoricoCompetencia($nrorg, $nrvinculom, $dtmescompetencia);
                                
                                if($dataset['RECIBOPAGTO_NRESTRUTLEGAL'] == $vinculoh->getNrestrutlegal()) {
                                    $this->execRescisaoColetiva($count, $nrorg, $dtmescompetencia, $idoperacao, $dataset, $nrvinculom);
                                    $vinculosVerificados[] = $nrvinculom;
                                }
                            } else { //Lote da tela Cálculo de Rescisão.
                                $this->execRescisaoColetiva($count, $nrorg, $dtmescompetencia, $idoperacao, $dataset, $nrvinculom);
                                $vinculosVerificados[] = $nrvinculom;
                            }
                        }
                    }
                }
            }
            $this->entityManager->flush();
            $this->entityManager->commit();
            return $count;
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }

    private function execRescisaoColetiva(&$count, $nrorg, $dtmescompetencia, $idoperacao, $dataset, $nrVinculo) {
        /** @var GpevinculomEntity $vinculo */
        if ($idoperacao == 'I') {
            // Ignora vínculos com deficiencia, estabilidade, dissidio ou afastados
            if (/*$this->verificaPessoaDeficiente($vinculo->getNrorg(), $vinculo->getNrpessoa(), $dtmescompetencia) ||*/
                $this->AlteSituacaoFuncionalService->verificaEstabilidade($nrorg, $dtmescompetencia, $nrVinculo, $dataset['DTRESCISAOVINC']) ||
                $this->VinculoServices->verificaDissidio($nrorg, $nrVinculo, $dtmescompetencia, $dataset['DTRESCISAOVINC'], $dataset['NRTPDEMISSAO']) ||
                $this->AlteSituacaoFuncionalService->verificaVinculoAfastado($nrorg, $nrVinculo, $dataset['DTRESCISAOVINC'])
            ) {
                return;
            }
        }
        
        $vinculo = $this->entityManager->getRepository(Repositories::GPE_VINCULOM)->findOneBy(array("nrvinculom" => $nrVinculo,"nrorg" => $nrorg));
        
        if (is_object($vinculo)) {
            // Seta dados da rescisão do vínculo
            if ($idoperacao == 'I') {
                $vinculo->setNrtpavipre($dataset['NRTPAVIPRE']);
                $vinculo->setNrtpdemissao($dataset['NRTPDEMISSAO']);
                $vinculo->setNrmotivoresc($dataset['NRMOTIVORESC']);
                if ($dataset['DTAVISOPREVIO']) {
                    $vinculo->setDtavisoprevio(\HCM\Util\DateUtil::getDataDeString($dataset['DTAVISOPREVIO'],\HCM\Util\DateUtil::FORMATO_BRASILEIRO,true));
                }
                $vinculo->setDtrescisaovinc(\HCM\Util\DateUtil::getDataDeString($dataset['DTRESCISAOVINC'],\HCM\Util\DateUtil::FORMATO_BRASILEIRO,true));
                $vinculo->setDsobsrescisao($dataset['DSOBSRESCISAO']);
                $this->AlteEscalaService->alteraDataFimUltimaAlteracao($nrorg, $nrVinculo, $dataset['DTRESCISAOVINC']);
            } else {
                $vinculo->setNrtpavipre(null);
                $vinculo->setNrtpdemissao(null);
                $vinculo->setNrmotivoresc(null);
                $vinculo->setDtavisoprevio(null);
                $vinculo->setDtrescisaovinc(null);
                $vinculo->setDsobsrescisao(null);
                $this->AlteEscalaService->alteraDataFimUltimaAlteracao($nrorg, $nrVinculo, null);
            }
            $vinculo->setNrorgultatu($nrorg);
            $vinculo->setDtinclusao(DateUtil::getDataAtual());
            $vinculo->setCdoperultatu($this->hcmParameters->getCdoperador());
            
            $this->entityManager->persist($vinculo);
            $count++;
            
            $this->AlteSituacaoFuncionalService->regraMudarDataRescisao($nrorg, $vinculo->getNrvinculom(), $dataset['DTRESCISAOVINC'], null);
            
            $this->MovimentacaoService->manipulaMovimentacao($nrorg, $vinculo->getNrvinculom(), null, null,
            $dataset['DTRESCISAOVINC'], $dtmescompetencia, self::INSERE_VINCULO, $vinculo->getNrtpdemissao());
        }
    }
}