<?php
namespace HCM\Geral\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;

class PreFechamentoDctfWebRepository {
    
    public function __construct(Connection $connection, EntityManager $entityManager) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;
        $this->contribuicaoPrevidenciariaSegurado = new ContribuicaoPrevidenciariaSegurado($entityManager);
        $this->informacoesSinteticas = new InformacoesSinteticas($entityManager);
        $this->informacoesSobreBasesCalculo = new InformacoesSobreBasesCalculo($entityManager);
    }
        
    public function getContribuicaoPrevidenciariaSegurado($parameters) {
        return $this->contribuicaoPrevidenciariaSegurado->getContribuicao($parameters);
    }
    
    public function getEventosApuradosContribuicao($parameters) {
        return $this->contribuicaoPrevidenciariaSegurado->getEventosApurados($parameters);
    }
        
    public function getInformacoesSinteticas($parameters) {
        return $this->informacoesSinteticas->getInformacoesSinteticas($parameters);
    }
    
    public function getInformacoesSobreBasesCalculo($parameters) {
        return $this->informacoesSobreBasesCalculo->getInformacoesSobreBasesCalculo($parameters);
    }
}

class ContribuicaoPrevidenciariaSegurado {
    
    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function getContribuicao($parameters) {
        $sql = $this->entityManager->getConnection()->prepare(Queries::$queryContribuicaoPrevidenciariaSegurado);
        $sql->execute(
            array(
                'P_NRORG'         => $parameters['NRORG'],
                'P_MODALIDADECAL' => 1,
                'P_NRESTRUTGEREN' => $parameters['NRESTRUTGEREN'],
                'P_COMPETENCIA'   => $parameters['DTMESCOMPETENC'],
                'P_NRESTRUTLEGAL' => is_array($parameters['NRESTRUTLEGAL']) ? implode(",",$parameters['NRESTRUTLEGAL']) : $parameters['NRESTRUTLEGAL'],
                'P_NRVINCULO'     => '',
                'P_NRTABELA'      => $parameters['NRTABELA'],
                'P_IDDIFERENCA'   => $parameters['IDDIFERENCA'],
            )
        );
        
        return $sql->fetchAll();
    }
    
    public function getEventosApurados($parameters) {
        $sql = $this->entityManager->getConnection()->prepare(Queries::$queryEventosApuradosContribuicao);
        $sql->execute(
            array( 
                'P_NRORG'             => $parameters['NRORG'],
                'P_COMPETENCIA'       => $parameters['COMPETENCIA'],
                'P_NRVINCULOM'        => $parameters['NRVINCULOM'],
                'P_MODALIDADECALCULO' => $parameters['MODALIDADECALCULO'],
                'P_NRTIPOMOVIMENT'    => $parameters['NRTIPOMOVIMENT']
            )
        );
        return $sql->fetchAll();
    }
}

class InformacoesSinteticas {
    
    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function getInformacoesSinteticas($parameters) {
        $sql = $this->entityManager->getConnection()->prepare(Queries::$queryInformacoesSinteticas);
        $sql->execute(
            array(
                'P_NRORG'         => $parameters['NRORG'],
                'P_MODALIDADECAL' => 1,
                'P_NRESTRUTGEREN' => $parameters['NRESTRUTGEREN'],
                'P_COMPETENCIA'   => $parameters['DTMESCOMPETENC'],
                'P_NRESTRUTLEGAL' => is_array($parameters['NRESTRUTLEGAL']) ? implode(",",$parameters['NRESTRUTLEGAL']) : $parameters['NRESTRUTLEGAL'],
                'P_NRVINCULO'     => '',
                'P_NRTABELA'      => $parameters['NRTABELA']
            )
        );
        return $sql->fetchAll();
    }
}

class InformacoesSobreBasesCalculo {
    
    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function getInformacoesSobreBasesCalculo($parameters) {
        $sql = $this->entityManager->getConnection()->prepare(Queries::$queryInformacoesSobreBasesCalculo);
        $sql->execute(
            array(
                'P_NRORG'         => $parameters['NRORG'],
                'P_COMPETENCIA'   => $parameters['DTMESCOMPETENC'],
                'P_NRESTRUTLEGAL' => is_array($parameters['NRESTRUTLEGAL']) ? implode(",",$parameters['NRESTRUTLEGAL']) : $parameters['NRESTRUTLEGAL'],
                'P_NRVINCULO'     => '',
                'P_NRTABELA'      => $parameters['NRTABELA']
            )
        );
        return $sql->fetchAll();
    }
}

class Queries {
    
    static $queryContribuicaoPrevidenciariaSegurado = "
SELECT * FROM (
    SELECT RES.VINCULO,
        RES.DTRESCISAOVINC,
        RES.MATRICULA,
        RES.REGISTRO,
        PE.NRCPFPESSOA,
        RES.NOME,
        RES.NRLEGAL,
        RES.NRGEREN,
        RES.RAZAOLEGAL,
        RES.CNPJLEGAL,
        RES.INTLEGAL,
        RES.RAZAOGEREN,
        RES.CNPJGEREN,
        RES.INTGEREN,
        SUM(NVL(ESONP.VRDESCONTADO,0) + NVL(ESOPE.VRDESCONTADO,0)) VRDESC_ESO,
        SUM(NVL(ESONP.VRCALCULADO,0) + NVL(ESOPE.VRCALCULADO,0)) VRCALCULADO_ESO,
        SUM(NVL(ESONP.VRBASE13,0) + NVL(ESOPE.VRBASE13,0) + NVL(ESONP.VRBASEMENSAL,0) + NVL(ESOPE.VRBASEMENSAL,0)) VRBASE_ESO,
        RES.BASE,
        RES.INSS,
        NVL(ESOPE.IDSTATUS, ESONP.IDSTATUS) IDSTATUS,
        NVL(ESOPE.NRTABELA, ESONP.NRTABELA) NRTABELA,
        NVL(ESOPE.NMEVENTO, ESONP.NMEVENTO) NMEVENTO,
        RES.BASE - SUM(NVL(ESOPE.VRBASE13,0) + NVL(ESONP.VRBASE13,0) + NVL(ESOPE.VRBASEMENSAL,0) + NVL(ESONP.VRBASEMENSAL,0)) DIFERENCA_BASE,
        RES.INSS - SUM(NVL(ESONP.VRCALCULADO,0) + NVL(ESOPE.VRCALCULADO,0)) DIFERENCA_DESCONTO,
        :P_COMPETENCIA PERIODO,
        SUBSTR(RES.CNPJLEGAL, 0,8) CNPJRAIZ,
        RES.CDESOCIAL CDCATEGESOC,
        (RES.CDESOCIAL || ' - '|| RES.DSCATEGESOC) DSCATEGESOC
      FROM (SELECT
                VM.NRORG, VM.NRPESSOA,
                VM.NRVINCULOM      VINCULO,
                VM.DTRESCISAOVINC,
                VM.CDMATRICULA     MATRICULA,
                VM.DSLIVROADMISSAO REGISTRO,
                VM.NMVINCULOM      NOME,
                VM.NRTIPOVINCULOM,
                /*ICF.NREVENTOM      EVENTO,*/
                SUM(CASE WHEN ICF.NREVENTOM IN (3070 ,3075 ,3130, 3190, 3211, 4010) THEN ICF.VREVENTOFOLHA ELSE 0 END) BASE,
                SUM(CASE WHEN ICF.NREVENTOM IN (1130, 1160, 1150, 1180, 1200, 4000/*, 1140, 1190*/) THEN ICF.VREVENTOFOLHA ELSE 0 END) INSS,
                CF.DTOCORRENCIA,
                VH.NRESTRUTLEGAL   NRLEGAL,
                VH.NRESTRUTGEREN   NRGEREN,
                EHL.NMRAZSOCESTRUT RAZAOLEGAL,
                EHL.CDCNPJESTRUT   CNPJLEGAL,
                EML.CDINTESTRUTURA INTLEGAL,
                EHG.NMRAZSOCESTRUT RAZAOGEREN,
                EHG.CDCNPJESTRUT   CNPJGEREN,
                EMG.CDINTESTRUTURA INTGEREN,
                CATEGTRAB.DSCATEGESOC,
                CATEGTRAB.CDESOCIAL,
                EP.NRTPAMBIENTE
              FROM GPE_VINCULOM VM
              JOIN GPE_VINCULOH VH ON VH.NRORG      = VM.NRORG
                                  AND VH.NRVINCULOM = VM.NRVINCULOM
                                  AND VH.DTMESCOMPETENC = ( SELECT *
                                                              FROM ( SELECT DTMESCOMPETENC
                                                                     FROM GPE_VINCULOH
                                                                     WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                       AND NRORG      = VH.NRORG
                                                                       AND NRVINCULOM = VH.NRVINCULOM
                                                                     ORDER BY DTMESCOMPETENC DESC )
                                                               WHERE ROWNUM = 1 )
              /*ESTRUTURA LEGAL*/
              JOIN ESTRUTURAM EML ON EML.NRORG        = VH.NRORG
                                      AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
              LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG        = VH.NRORG
                                      AND EHL.NRESTRUTURAM = EML.NRESTRUTURAM
                                      AND EHL.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                                WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                  AND NRORG        = VH.NRORG
                                                                  AND NRESTRUTURAM = EML.NRESTRUTURAM )
              /*ESTRUTURA GERENCIAL*/
              JOIN ESTRUTURAM EMG ON EMG.NRORG        = VH.NRORG
                                      AND EMG.NRESTRUTURAM = VH.NRESTRUTGEREN
              LEFT JOIN ESTRUTURAH EHG ON EHG.NRORG        = VH.NRORG
                                      AND EHG.NRESTRUTURAM = EMG.NRESTRUTURAM
                                      AND EHG.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                                WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                  AND NRORG        = VH.NRORG
                                                                  AND NRESTRUTURAM = EMG.NRESTRUTURAM )
              /*CÁLCULO DE FOLHA*/
              JOIN FPA_ITECALCFOLHA ICF ON ICF.NRORG       = VM.NRORG
                                      AND ICF.NRVINCULOM  = VM.NRVINCULOM
                                      AND ICF.NREVENTOM IN (1130, 1160, 1150, 1180, 1200, 4000, 3070 ,3075 ,3130, 3190, 3211, 4010)
                                      AND EXISTS (SELECT 1 FROM FPA_ITECALCFOLHA IC
                                                   WHERE IC.NRORG = ICF.NRORG
                                                     AND IC.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                                                     AND IC.NRVINCULOM = ICF.NRVINCULOM
                                                     AND IC.NREVENTOM IN (3030, 3050))
              JOIN FPA_CALCULOFOLHA CF ON CF.NRORG            = ICF.NRORG
                                      AND CF.NRCALCULOFOLHA   = ICF.NRCALCULOFOLHA
                                      AND ((CF.NRTIPOMOVIMENT IN (1,2,10,19) AND :P_NRTABELA = 1) OR
                                           (CF.NRTIPOMOVIMENT = 4 AND :P_NRTABELA = 4) OR
                                           (CF.NRTIPOMOVIMENT IN (1,2,4,10,19) AND :P_NRTABELA IS NULL))
                                      AND CF.NRTPMODALIDCAL = :P_MODALIDADECAL
                                      AND CF.DTOCORRENCIA   = :P_COMPETENCIA
              /*CATEGORIA*/
              JOIN GPE_VINCULOEMPREG VINCEMPREG ON VINCEMPREG.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
              JOIN GPE_CATEGTRABESOC CATEGTRAB ON CATEGTRAB.NRCATEGESOC = VINCEMPREG.NRCATEGESOC
              
              JOIN ESO_PARAMETRO EP ON EP.NRORG = EML.NRORG
                             AND EP.NRESTRUTURAM = EML.NRESTRUTURAM
              /**/
              WHERE VM.NRORG = :P_NRORG
                AND ( INSTR(','||:P_NRVINCULO||',', ','||VM.NRVINCULOM||',' ) > 0 OR :P_NRVINCULO IS NULL ) --[15-02-12][multisearch_vinculo_156497]
                AND ( VM.DTADMISSAOVINC <= LAST_DAY(:P_COMPETENCIA) )
                AND ( VM.DTRESCISAOVINC >= :P_COMPETENCIA OR VM.DTRESCISAOVINC IS NULL OR 1 = 1)
                AND ( INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',' ) > 0 OR :P_NRESTRUTLEGAL IS NULL )
                AND ( INSTR(','||:P_NRESTRUTGEREN||',', ','||VH.NRESTRUTGEREN||',' ) > 0 OR :P_NRESTRUTGEREN IS NULL )
              GROUP BY VM.NRORG, VM.NRPESSOA, VM.NRVINCULOM,
                VM.DTRESCISAOVINC,
                VM.CDMATRICULA,
                VM.DSLIVROADMISSAO,
                VM.NMVINCULOM,
                VM.NRTIPOVINCULOM,
                /*ICF.NREVENTOM,*/
                CF.DTOCORRENCIA,
                VH.NRESTRUTLEGAL,
                VH.NRESTRUTGEREN,
                EHL.NMRAZSOCESTRUT,
                EHL.CDCNPJESTRUT,
                EML.CDINTESTRUTURA,
                EHG.NMRAZSOCESTRUT,
                EHG.CDCNPJESTRUT,
                EMG.CDINTESTRUTURA,
                CATEGTRAB.DSCATEGESOC,
                CATEGTRAB.CDESOCIAL,
                EP.NRTPAMBIENTE
            ) RES
      LEFT JOIN (SELECT ESONP.DTMESCOMPETENC,
                    ESONP.NRTPAMBIENTE,
                    ESONP.NRVINCULOM,
                    ESONP.NRORG,
                    ESONP.NRESTRUTURAM,
                    ESONP.IDSTATUS,
                    ESONP.NRTABELA,
                    ESONP.NMEVENTO,
                    SUM(NVL(NVL(NPCP.VRDESCONTADO,ESONP.VRDESCONTADO),0)) AS VRDESCONTADO,
                    SUM(NVL(NVL(NPCP.VRCALCULADO,ESONP.VRCALCULADO),0)) AS VRCALCULADO,
                    SUM(NVL(NVL(NPCP.VRBASE13,ESONP.VRBASE13),0)) AS VRBASE13,
                    SUM(NVL(NVL(NPCP.VRBASEMENSAL,ESONP.VRBASEMENSAL),0)) AS VRBASEMENSAL,
                    ESONP.NRENVIO,
                    EHPN.CDCNPJESTRUT
                FROM ESO_NAOPERIODICO ESONP 
                JOIN ESTRUTURAH EHPN ON EHPN.NRORG   = ESONP.NRORG
                                          AND EHPN.NRESTRUTURAM = ESONP.NRESTRUTURAM
                                          AND EHPN.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                                      WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                      AND NRORG        = ESONP.NRORG
                                                                      AND NRESTRUTURAM = EHPN.NRESTRUTURAM )
                JOIN ESO_NAOPERRETCP NPCP ON NPCP.NRORG = ESONP.NRORG
                                        AND NPCP.NRENVIO = ESONP.NRENVIO
                WHERE ESONP.NRORG = :P_NRORG
                AND ESONP.IDATIVO = 'S' AND ESONP.NRENVIOEXCL IS NULL
                AND ESONP.IDSTATUS IN('C','A')
                AND (ESONP.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESONP.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                AND ESONP.NMEVENTO IN ('S-2299','S-2399')
                GROUP BY ESONP.DTMESCOMPETENC, ESONP.NRTPAMBIENTE, ESONP.NRVINCULOM,ESONP.NRENVIO, EHPN.CDCNPJESTRUT , ESONP.NRORG, ESONP.NRESTRUTURAM, ESONP.IDSTATUS, ESONP.NRTABELA, ESONP.NMEVENTO
            )ESONP ON TRUNC(ESONP.DTMESCOMPETENC, 'MM') = RES.DTOCORRENCIA
                   AND ESONP.NRTPAMBIENTE = RES.NRTPAMBIENTE
                   AND ESONP.NRVINCULOM = RES.VINCULO
                   AND SUBSTR(ESONP.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
                                  
     LEFT JOIN (SELECT ESOPE.DTMESCOMPETENC,
                ESOPE.NRTPAMBIENTE,
                ESOPE.NRCHAVE,
                ESOPE.NRORG,
                ESOPE.NRESTRUTURAM,
                ESOPE.IDSTATUS,
                ESOPE.NRTABELA,
                ESOPE.NMEVENTO,
                SUM(NVL(NVL(PECP.VRDESCONTADO,ESOPE.VRDESCONTADO),0)) AS VRDESCONTADO,
                SUM(NVL(NVL(PECP.VRCALCULADO,ESOPE.VRCALCULADO),0)) AS VRCALCULADO,
                SUM(NVL(NVL(PECP.VRBASE13,ESOPE.VRBASE13),0)) AS VRBASE13,
                SUM(NVL(NVL(PECP.VRBASEMENSAL,ESOPE.VRBASEMENSAL),0)) AS VRBASEMENSAL,
                ESOPE.NRENVIO,
                EHPE.CDCNPJESTRUT 
                FROM ESO_PERIODICO ESOPE   
                JOIN ESTRUTURAH EHPE ON EHPE.NRORG   = ESOPE.NRORG
                                          AND EHPE.NRESTRUTURAM = ESOPE.NRESTRUTURAM
                                          AND EHPE.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                                      WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                      AND NRORG        = ESOPE.NRORG
                                                                      AND NRESTRUTURAM = EHPE.NRESTRUTURAM )
                JOIN ESO_PERIODRETCP PECP ON PECP.NRORG = ESOPE.NRORG
                                        AND PECP.NRENVIO = ESOPE.NRENVIO
                WHERE ESOPE.NRORG = :P_NRORG
                AND ESOPE.IDATIVO = 'S' AND ESOPE.NRENVIOEXCL IS NULL
                AND ESOPE.IDSTATUS IN('C','A')
                AND (ESOPE.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESOPE.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                AND ESOPE.NMEVENTO = 'S-1200'
                GROUP BY ESOPE.DTMESCOMPETENC,ESOPE.NRTPAMBIENTE,ESOPE.NRCHAVE,ESOPE.NRENVIO, EHPE.CDCNPJESTRUT ,ESOPE.NRORG ,ESOPE.NRESTRUTURAM ,ESOPE.IDSTATUS , ESOPE.NRTABELA, ESOPE.NMEVENTO
            )ESOPE ON TRUNC(ESOPE.DTMESCOMPETENC, 'MM') = RES.DTOCORRENCIA
                   AND ESOPE.NRTPAMBIENTE = RES.NRTPAMBIENTE
                   AND ESOPE.NRCHAVE = RES.NRPESSOA
                   AND SUBSTR(ESOPE.CDCNPJESTRUT,1,8) = SUBSTR(RES.CNPJLEGAL,1,8)
      JOIN GPE_PESSOAH PE
              ON PE.NRPESSOA = RES.NRPESSOA 
              AND PE.NRORG = RES.NRORG 
              AND PE.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH 
                                        WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                          AND NRORG = PE.NRORG
                                          AND NRPESSOA = PE.NRPESSOA)
      GROUP BY RES.VINCULO,
        RES.DTRESCISAOVINC,
        RES.MATRICULA,
        RES.REGISTRO,
        PE.NRCPFPESSOA,
        RES.NOME,
        RES.NRLEGAL,
        RES.NRGEREN,
        RES.RAZAOLEGAL,
        RES.CNPJLEGAL,
        RES.INTLEGAL,
        RES.RAZAOGEREN,
        RES.CNPJGEREN,
        RES.INTGEREN,
        RES.BASE,
        RES.INSS,
        NVL(ESOPE.IDSTATUS,ESONP.IDSTATUS),
        NVL(ESOPE.NRTABELA,ESONP.NRTABELA),
        NVL(ESOPE.NMEVENTO,ESONP.NMEVENTO),
        RES.DSCATEGESOC,
        RES.CDESOCIAL
    )
WHERE ( :P_IDDIFERENCA IS NULL OR
        ( :P_IDDIFERENCA = 'B' AND ( ABS(DIFERENCA_BASE) > 0.05 ) ) OR
        ( :P_IDDIFERENCA = 'V' AND ( ABS(DIFERENCA_DESCONTO) > 0.05 ) ) OR
        ( :P_IDDIFERENCA = 'A' AND ( ABS(DIFERENCA_BASE) > 0.05 OR ABS(DIFERENCA_DESCONTO) > 0.05 ) )
      )
ORDER BY CNPJRAIZ, CNPJLEGAL, NOME, DSCATEGESOC";
    
    static $queryEventosApuradosContribuicao = "
        SELECT
               ICF.VREVENTOFOLHA VALOR,
               CF.NROCORRECAL,
               SUBSTR(ICF.DTOCORRENCIA, 4, 7) PERIODO,
               DECODE(
                 CF.NRTIPOMOVIMENT, 1, 'Mensal',
                                    4, '13º'
               ) PROCESSO,
               EH.NREVENTOM NREVENTOM,
               EH.NMEVENTOH EVENTO,
               DECODE(EH.NRNATURUBR, NULL, 'Sem parametrização',
                                     DECODE(
                                       CP.CDESOCIAL,  00, 'Não Incide',
                                                      11, 'Incide',
                                                      NULL, 'Não Incide',
                                                      'Base, Imposto ou Encargo'
                                     )
               ) INCIDEINSS
          FROM FPA_ITECALCFOLHA ICF
          JOIN FPA_CALCULOFOLHA CF 
            ON CF.NRORG = ICF.NRORG
           AND CF.NRCALCULOFOLHA  = ICF.NRCALCULOFOLHA
           AND (CF.NRTIPOMOVIMENT = :P_NRTIPOMOVIMENT OR ((:P_NRTIPOMOVIMENT IS NULL) AND CF.NRTIPOMOVIMENT IN (1,4)))
           AND CF.NRTPMODALIDCAL  = :P_MODALIDADECALCULO
           AND CF.DTOCORRENCIA    = :P_COMPETENCIA
          JOIN FPA_EVENTOM EM ON (EM.NREVENTOM = ICF.NREVENTOM)
          JOIN FPA_EVENTOH EH ON (EH.NREVENTOM = EM.NREVENTOM)
          JOIN (SELECT MAX(DTMESCOMPETENC) DTMESCOMPETENC, NREVENTOM
                  FROM FPA_EVENTOH 
                 WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                 GROUP BY NREVENTOM) EHATUAL 
                    ON ( EHATUAL.NREVENTOM = EH.NREVENTOM
                   AND EHATUAL.DTMESCOMPETENC = EH.DTMESCOMPETENC)
          LEFT JOIN (SELECT IE.NREVENTOM, TI.DSNRTIPOMOVIMENT, MAX(INC.CDESOCIAL) AS CDESOCIAL
                   FROM FPA_INCIDEVENTO IE
                   JOIN FPA_TIPOINCIDE TI ON TI.NRTIPOINCIDE = IE.NRTIPOINCIDE
                   JOIN INCIDENCIACP INC ON INSTR(','||INC.DSNRTIPOINCIDE||',',','||TI.NRTIPOINCIDE||',') > 0
                  WHERE (IE.NRORG = :P_NRORG OR IE.NRORG = 0)
                    AND (IE.NRTIPOINCIDE IN (SELECT NRTIPOINCIDE 
                                          FROM FPA_GRPITEM 
                                         WHERE NRGRPINCIDE = 46) OR TI.DSNRTIPOMOVIMENT IS NOT NULL)
                  GROUP BY IE.NREVENTOM, TI.DSNRTIPOMOVIMENT
                 ) CP ON CP.NREVENTOM = EM.NREVENTOM
                     AND INSTR(','||CP.DSNRTIPOMOVIMENT||',',','||CF.NRTIPOMOVIMENT||',') > 0
         WHERE ICF.NRORG      = :P_NRORG
           AND ICF.NRVINCULOM = :P_NRVINCULOM
    ";
    
    static $queryInformacoesSinteticas = "
SELECT * FROM (
      SELECT 
        NRLEGAL,
        RAZAOLEGAL,
        ('('||NRLEGAL||') '||RAZAOLEGAL) ESTABELECIMENTO,
        CNPJLEGAL,
        INTLEGAL,
        CNPJRAIZ,
        TAB.CODIGO, TAB.DESCRICAO,
        SUM(CASE
            WHEN TAB.CODIGO = '01' THEN BASE
            WHEN TAB.CODIGO = '02' THEN INSS
            WHEN TAB.CODIGO = '03' THEN FAMILIA
            WHEN TAB.CODIGO = '04' THEN MATERNIDADE
            END
        ) VR_SISTEMA,
        SUM(CASE
            WHEN TAB.CODIGO = '01' THEN VRBASE_ESO
            WHEN TAB.CODIGO = '02' THEN VRCALCULADO_ESO
            WHEN TAB.CODIGO = '03' THEN VRFAMILIA_ESO
            WHEN TAB.CODIGO = '04' THEN VRMATERNIDADE_ESO
            END
        ) VR_ESOCIAL,
        SUM(CASE
            WHEN TAB.CODIGO = '01' THEN DIFERENCA_BASE
            WHEN TAB.CODIGO = '02' THEN DIFERENCA_DESCONTO
            WHEN TAB.CODIGO = '03' THEN DIFERENCA_FAMILIA
            WHEN TAB.CODIGO = '04' THEN DIFERENCA_MATERNIDADE
            END
        ) VR_DIFERENCA
      FROM (SELECT RES.NRLEGAL,
                  RES.RAZAOLEGAL,
                  RES.CNPJLEGAL,
                  RES.INTLEGAL,
                  SUM(NVL(ESONP.VRDESCONTADO,0) + NVL(ESOPE.VRDESCONTADO,0)) VRDESC_ESO,
                  SUM(NVL(ESONP.VRCALCULADO,0) + NVL(ESOPE.VRCALCULADO,0))  VRCALCULADO_ESO,
                  SUM(NVL(ESONP.VRBASE13,0) + NVL(ESOPE.VRBASE13,0) + NVL(ESONP.VRBASEMENSAL,0) + NVL(ESOPE.VRBASEMENSAL,0)) VRBASE_ESO,
                  SUM(NVL(ESONP.VRVALORMATER13,0) + NVL(ESONP.VRVALORMATERMENSAL,0) + NVL(ESOPE.VRVALORMATER13,0) + NVL(ESOPE.VRVALORMATERMENSAL,0)) VRMATERNIDADE_ESO,
                  SUM(NVL(ESONP.VRSALFAMILIA13,0) + NVL(ESONP.VRSALFAMILIA,0) + NVL(ESOPE.VRSALFAMILIA13,0) + NVL(ESOPE.VRSALFAMILIA,0)) VRFAMILIA_ESO,
                  SUM(RES.BASE - RES.MATERNIDADE) BASE,
                  RES.INSS,
                  RES.MATERNIDADE,
                  RES.FAMILIA,
                  SUM(RES.BASE - RES.MATERNIDADE) - SUM(NVL(ESONP.VRBASE13,0) + NVL(ESOPE.VRBASE13,0) + NVL(ESONP.VRBASEMENSAL,0) + NVL(ESOPE.VRBASEMENSAL,0)) DIFERENCA_BASE,
                  RES.INSS - SUM(NVL(ESONP.VRCALCULADO,0) + NVL(ESOPE.VRCALCULADO,0)) DIFERENCA_DESCONTO,
                  RES.MATERNIDADE - SUM(NVL(ESONP.VRVALORMATER13,0) + NVL(ESONP.VRVALORMATERMENSAL,0) + NVL(ESOPE.VRVALORMATER13,0) + NVL(ESOPE.VRVALORMATERMENSAL,0)) DIFERENCA_MATERNIDADE,
                  RES.FAMILIA - SUM(NVL(ESONP.VRSALFAMILIA13,0) + NVL(ESONP.VRSALFAMILIA,0) + NVL(ESOPE.VRSALFAMILIA13,0) + NVL(ESOPE.VRSALFAMILIA,0)) DIFERENCA_FAMILIA,
                  :P_COMPETENCIA PERIODO,
                  SUBSTR(RES.CNPJLEGAL, 0,8) CNPJRAIZ
             FROM (SELECT
                      VM.NRORG, VM.NRPESSOA,
                      VM.NRVINCULOM VINCULO,
                      SUM(CASE WHEN ICF.NREVENTOM IN (3070 ,3075 ,3130, 3190, 3211, 4010) THEN ICF.VREVENTOFOLHA ELSE 0 END) BASE,
                      SUM(CASE WHEN ICF.NREVENTOM IN (1130, 1160, 1150, 1180, 1200, 4000/*, 1140, 1190*/) THEN ICF.VREVENTOFOLHA ELSE 0 END) INSS,
                      SUM(CASE WHEN ICF.NREVENTOM IN (330, 331) THEN ICF.VREVENTOFOLHA ELSE 0 END) MATERNIDADE,
                      SUM(CASE WHEN ICF.NREVENTOM IN (300) THEN ICF.VREVENTOFOLHA ELSE 0 END) FAMILIA,
                      CF.DTOCORRENCIA,
                      VH.NRESTRUTLEGAL   NRLEGAL,
                      EHL.NMRAZSOCESTRUT RAZAOLEGAL,
                      EHL.CDCNPJESTRUT   CNPJLEGAL,
                      EML.CDINTESTRUTURA INTLEGAL,
                      EP.NRTPAMBIENTE
                    FROM GPE_VINCULOM VM
                    JOIN GPE_VINCULOH VH ON VH.NRORG      = VM.NRORG
                                        AND VH.NRVINCULOM = VM.NRVINCULOM
                                        AND VH.DTMESCOMPETENC = ( SELECT *
                                              FROM ( SELECT DTMESCOMPETENC
                                                     FROM GPE_VINCULOH
                                                     WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                       AND NRORG      = VH.NRORG
                                                       AND NRVINCULOM = VH.NRVINCULOM
                                                     ORDER BY DTMESCOMPETENC DESC )
                                               WHERE ROWNUM = 1 )
                    /*ESTRUTURA LEGAL*/
                    JOIN ESTRUTURAM EML ON EML.NRORG        = VH.NRORG
                                            AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG        = VH.NRORG
                                            AND EHL.NRESTRUTURAM = EML.NRESTRUTURAM
                                            AND EHL.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                                       WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                         AND NRORG        = VH.NRORG
                                                                         AND NRESTRUTURAM = EML.NRESTRUTURAM )
                                                                         
                   JOIN ESO_PARAMETRO EP ON EP.NRORG = EML.NRORG
                                        AND EP.NRESTRUTURAM = EML.NRESTRUTURAM
                    /*CÁLCULO DE FOLHA*/
                    JOIN FPA_ITECALCFOLHA ICF ON ICF.NRORG       = VM.NRORG
                                             AND ICF.NRVINCULOM  = VM.NRVINCULOM
                                             AND ICF.NREVENTOM IN (1130, 1160, 1150, 1180, 1200, 4000, 3070 ,3075 ,3130, 3190, 3211, 4010/*1140,1190*/, 300, 330, 331)
                                             AND EXISTS (SELECT 1 FROM FPA_ITECALCFOLHA IC
                                                          WHERE IC.NRORG = ICF.NRORG
                                                            AND IC.NRCALCULOFOLHA = ICF.NRCALCULOFOLHA
                                                            AND IC.NRVINCULOM = ICF.NRVINCULOM
                                                            AND IC.NREVENTOM IN (3030, 3050))
                    JOIN FPA_CALCULOFOLHA CF ON CF.NRORG            = ICF.NRORG
                                            AND CF.NRCALCULOFOLHA   = ICF.NRCALCULOFOLHA
                                            AND ((CF.NRTIPOMOVIMENT IN (1,2,10,19) AND :P_NRTABELA = 1) OR
                                                 (CF.NRTIPOMOVIMENT = 4 AND :P_NRTABELA = 4) OR
                                                 (CF.NRTIPOMOVIMENT IN (1,2,4,10,19) AND :P_NRTABELA IS NULL))
                                            AND CF.NRTPMODALIDCAL = :P_MODALIDADECAL
                                            AND CF.DTOCORRENCIA   = :P_COMPETENCIA
                    /**/
                    WHERE VM.NRORG = :P_NRORG
                      AND ( INSTR(','||:P_NRVINCULO||',', ','||VM.NRVINCULOM||',' ) > 0 OR :P_NRVINCULO IS NULL ) --[15-02-12][multisearch_vinculo_156497]
                      AND ( VM.DTADMISSAOVINC <= LAST_DAY(:P_COMPETENCIA) )
                      AND ( VM.DTRESCISAOVINC >= :P_COMPETENCIA OR VM.DTRESCISAOVINC IS NULL OR 1 = 1)
                      AND ( INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',' ) > 0 OR :P_NRESTRUTLEGAL IS NULL )
                      AND ( INSTR(','||:P_NRESTRUTGEREN||',', ','||VH.NRESTRUTGEREN||',' ) > 0 OR :P_NRESTRUTGEREN IS NULL )
                    GROUP BY VM.NRORG, VM.NRPESSOA, VM.NRVINCULOM, VM.NMVINCULOM, VM.DTADMISSAOVINC, VM.DTRESCISAOVINC, VM.NRTIPOVINCULOM,
                      CF.DTOCORRENCIA,
                      VH.NRESTRUTLEGAL,
                      EHL.NMRAZSOCESTRUT,
                      EHL.CDCNPJESTRUT,
                      EML.CDINTESTRUTURA,
                      EP.NRTPAMBIENTE
                      ) RES
                LEFT JOIN (SELECT ESONP.DTMESCOMPETENC,
                                  ESONP.NRTPAMBIENTE,
                                  ESONP.NRVINCULOM,
                                  ESONP.NRESTRUTURAM,
                                  ESONP.NRTABELA,
                                  SUM(NVL(NVL(NPCP.VRDESCONTADO,ESONP.VRDESCONTADO),0)) AS VRDESCONTADO,
                                  SUM(NVL(NVL(NPCP.VRCALCULADO,ESONP.VRCALCULADO),0)) AS VRCALCULADO,
                                  SUM(NVL(NVL(NPCP.VRBASE13,ESONP.VRBASE13),0)) AS VRBASE13,
                                  SUM(NVL(NVL(NPCP.VRBASEMENSAL,ESONP.VRBASEMENSAL),0)) AS VRBASEMENSAL,
                                  SUM(NVL(NVL(NPCP.VRSALFAMILIA,ESONP.VRSALFAMILIA),0)) AS VRSALFAMILIA,
                                  SUM(NVL(NVL(NPCP.VRSALFAMILIA13,ESONP.VRSALFAMILIA13),0)) AS VRSALFAMILIA13,
                                  SUM(NVL(NVL(NPCP.VRVALORMATERMENSAL,ESONP.VRVALORMATERMENSAL),0)) AS VRVALORMATERMENSAL,
                                  SUM(NVL(NVL(NPCP.VRVALORMATER13,ESONP.VRVALORMATER13),0)) AS VRVALORMATER13
                              FROM ESO_NAOPERIODICO ESONP
                              JOIN ESO_NAOPERRETCP NPCP ON NPCP.NRORG = ESONP.NRORG
                                                      AND NPCP.NRENVIO = ESONP.NRENVIO
                              WHERE ESONP.NRORG = :P_NRORG
                              AND ESONP.IDATIVO = 'S' AND ESONP.NRENVIOEXCL IS NULL
                              AND (ESONP.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESONP.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                              AND ESONP.IDSTATUS IN('C','A', 'M')
                              AND ESONP.NMEVENTO IN ('S-2299','S-2399')
                              GROUP BY ESONP.DTMESCOMPETENC, ESONP.NRTPAMBIENTE, ESONP.NRVINCULOM, ESONP.NRESTRUTURAM, ESONP.NRTABELA
                            )ESONP ON TRUNC(ESONP.DTMESCOMPETENC, 'MM') = RES.DTOCORRENCIA
                                  AND ESONP.NRTPAMBIENTE = RES.NRTPAMBIENTE
                                  AND ESONP.NRVINCULOM = RES.VINCULO
                LEFT JOIN (SELECT ESOPE.DTMESCOMPETENC,
                                  ESOPE.NRTPAMBIENTE,
                                  ESOPE.NRCHAVE,
                                  ESOPE.NRESTRUTURAM,
                                  ESOPE.NRTABELA,
                                  SUM(NVL(NVL(PECP.VRDESCONTADO,ESOPE.VRDESCONTADO),0)) AS VRDESCONTADO,
                                  SUM(NVL(NVL(PECP.VRCALCULADO,ESOPE.VRCALCULADO),0)) AS VRCALCULADO,
                                  SUM(NVL(NVL(PECP.VRBASE13,ESOPE.VRBASE13),0)) AS VRBASE13,
                                  SUM(NVL(NVL(PECP.VRBASEMENSAL,ESOPE.VRBASEMENSAL),0)) AS VRBASEMENSAL,
                                  SUM(NVL(NVL(PECP.VRSALFAMILIA,ESOPE.VRSALFAMILIA),0)) AS VRSALFAMILIA,
                                  SUM(NVL(NVL(PECP.VRSALFAMILIA13,ESOPE.VRSALFAMILIA13),0)) AS VRSALFAMILIA13,
                                  SUM(NVL(NVL(PECP.VRVALORMATERMENSAL,ESOPE.VRVALORMATERMENSAL),0)) AS VRVALORMATERMENSAL,
                                  SUM(NVL(NVL(PECP.VRVALORMATER13,ESOPE.VRVALORMATER13),0)) AS VRVALORMATER13
                              FROM ESO_PERIODICO ESOPE
                              JOIN ESO_PERIODRETCP PECP ON PECP.NRORG = ESOPE.NRORG
                                                      AND PECP.NRENVIO = ESOPE.NRENVIO
                              WHERE ESOPE.NRORG = :P_NRORG
                              AND ESOPE.IDATIVO = 'S' AND ESOPE.NRENVIOEXCL IS NULL
                              AND (ESOPE.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESOPE.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
                              AND ESOPE.IDSTATUS IN('C','A','M')
                              AND ESOPE.NMEVENTO = 'S-1200'
                              GROUP BY ESOPE.DTMESCOMPETENC,ESOPE.NRTPAMBIENTE,ESOPE.NRESTRUTURAM, ESOPE.NRCHAVE, ESOPE.NRTABELA
                            )ESOPE ON TRUNC(ESOPE.DTMESCOMPETENC, 'MM') = RES.DTOCORRENCIA
                                  AND ESOPE.NRTPAMBIENTE = RES.NRTPAMBIENTE
                                  AND ESOPE.NRESTRUTURAM = RES.NRLEGAL
                                  AND ESOPE.NRCHAVE = RES.NRPESSOA
                GROUP BY 
                  RES.NRLEGAL,
                  RES.RAZAOLEGAL,
                  RES.CNPJLEGAL,
                  RES.INTLEGAL,
                  RES.BASE,
                  RES.INSS,
                  RES.MATERNIDADE,
                  RES.FAMILIA
                  ) PRI
        JOIN (SELECT '01' CODIGO, 'Base de Cálculo da Contribuição Previdenciária Normal' DESCRICAO FROM DUAL
              UNION ALL
              SELECT '02' CODIGO, 'Valor Total da Contribuição Previdenciária dos Segurados' DESCRICAO FROM DUAL
              UNION ALL
              SELECT '03' CODIGO, 'Valor Total do Salário Família' DESCRICAO FROM DUAL
              UNION ALL
              SELECT '04' CODIGO, 'Valor Total do Salário Maternidade' DESCRICAO FROM DUAL) TAB ON 1=1
      GROUP BY NRLEGAL, RAZAOLEGAL, CNPJLEGAL, INTLEGAL, CNPJRAIZ, TAB.CODIGO, TAB.DESCRICAO)
ORDER BY CNPJRAIZ, CNPJLEGAL, CODIGO
    ";
    
    static $queryInformacoesSobreBasesCalculo = "
 SELECT * FROM ( SELECT NOME, NRCPFPESSOA,
      NRLEGAL,
      RAZAOLEGAL,
      ('('||NRLEGAL||') '||RAZAOLEGAL||' '||CNPJLEGAL) ESTABELECIMENTO,
      CNPJLEGAL,
      PRI.CDFPAS,
      PRI.CDTERCEIRO,
      CNPJRAIZ,
      PRI.VRBASE_ESO BASE, 
      PRI.VRCALCULADO_ESO INSS, 
      PRI.VRMATERNIDADE_ESO MATERNIDADE,
      PRI.VRFAMILIA_ESO FAMILIA,
      PRI.NRESTRUTLOTACAO,
      (PRI.VRBASE_ESO * PRI.VRPERCEMPRESA / 100) VRFPAS,
      (PRI.VRBASE_ESO * PRI.VRFAP * PRI.VRALIQRAT / 100) VRRAT,
      (PRI.VRBASE_ESO * PRI.VRPERCTERCEIROS / 100) VRTERCEIROS,
      ( '('||PRI.NRESTRUTLOTACAO||') '||'FPAS '||PRI.CDFPAS||' '||'Terceiros '||PRI.CDTERCEIRO ) LOTACAO,
      PRI.CDESOCIAL CDCATEGESOC,
      (PRI.CDESOCIAL || ' - '|| PRI.DSCATEGESOC) DSCATEGESOC
    FROM (SELECT VM.NRVINCULOM VINCULO,
                PE.NRCPFPESSOA,
                VM.NMVINCULOM NOME,
                VH.NRESTRUTLEGAL NRLEGAL,
                EHL.NMRAZSOCESTRUT RAZAOLEGAL,
                EHL.CDCNPJESTRUT   CNPJLEGAL,
                SUM(NVL(NPCP.VRDESCONTADO,NVL(ESONP.VRDESCONTADO,0)) + NVL(PECP.VRDESCONTADO,NVL(ESOPE.VRDESCONTADO,0))) VRDESC_ESO,
                SUM(NVL(NPCP.VRCALCULADO,NVL(ESONP.VRCALCULADO,0)) + NVL(PECP.VRCALCULADO,NVL(ESOPE.VRCALCULADO,0))) VRCALCULADO_ESO,
                SUM(NVL(NPCP.VRBASE13,NVL(ESONP.VRBASE13,0)) + NVL(PECP.VRBASE13,NVL(ESOPE.VRBASE13,0)) + NVL(NPCP.VRBASEMENSAL,NVL(ESONP.VRBASEMENSAL,0)) + NVL(PECP.VRBASEMENSAL,NVL(ESOPE.VRBASEMENSAL,0))) VRBASE_ESO,
                SUM(NVL(NPCP.VRVALORMATER13,NVL(ESONP.VRVALORMATER13,0)) + NVL(PECP.VRVALORMATER13,NVL(ESOPE.VRVALORMATER13,0)) + NVL(NPCP.VRVALORMATERMENSAL,NVL(ESONP.VRVALORMATERMENSAL,0)) + NVL(PECP.VRVALORMATERMENSAL,NVL(ESOPE.VRVALORMATERMENSAL,0))) VRMATERNIDADE_ESO,
                SUM(NVL(NPCP.VRSALFAMILIA13,NVL(ESONP.VRSALFAMILIA13,0)) + NVL(PECP.VRSALFAMILIA13,NVL(ESOPE.VRSALFAMILIA13,0)) + NVL(NPCP.VRSALFAMILIA,NVL(ESONP.VRSALFAMILIA,0)) + NVL(PECP.VRSALFAMILIA,NVL(ESOPE.VRSALFAMILIA,0))) VRFAMILIA_ESO,
                NVL(ESOPE.DTMESCOMPETENC, ESONP.DTMESCOMPETENC) PERIODO,
                SUBSTR(EHL.CDCNPJESTRUT, 0,8) CNPJRAIZ,
                NVL(ESOPE.NRENVIO,ESONP.NRENVIO) NRENVIO,
                NVL(ESOPE.NRESTRUTLOTACAO,ESONP.NRESTRUTLOTACAO) NRESTRUTLOTACAO,
                NVL(LOT.CDFPAS,EHL.CDFPAS) CDFPAS,
                NVL(LOT.CDTERCEIRO,EHL.CDTERCEIRO) CDTERCEIRO,
                NVL(LOT.VRFAP,EHL.VRFAP) VRFAP,
                NVL(LOT.CDCNAE,EHL.CDCNAE) CDCNAE,
                CF.VRALIQRAT,
                PER.VRPERCEMPRESA,
                PER.VRPERCTERCEIROS,
                CATEGTRAB.DSCATEGESOC,
                CATEGTRAB.CDESOCIAL
            FROM GPE_VINCULOM VM
            JOIN GPE_VINCULOH VH ON VH.NRORG      = VM.NRORG
                                AND VH.NRVINCULOM = VM.NRVINCULOM
                                AND VH.DTMESCOMPETENC = ( SELECT *
                                                          FROM ( SELECT DTMESCOMPETENC
                                                                 FROM GPE_VINCULOH
                                                                 WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                   AND NRORG      = VH.NRORG
                                                                   AND NRVINCULOM = VH.NRVINCULOM
                                                                 ORDER BY DTMESCOMPETENC DESC )
                                                           WHERE ROWNUM = 1 )
            JOIN GPE_PESSOAH PE ON PE.NRPESSOA = VM.NRPESSOA 
                              AND PE.NRORG = VM.NRORG 
                              AND PE.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH 
                                                        WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                          AND NRORG = PE.NRORG
                                                          AND NRPESSOA = PE.NRPESSOA)
            /*ESTRUTURA LEGAL*/
            JOIN ESTRUTURAM EML ON EML.NRORG        = VH.NRORG
                                    AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
            LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG        = VH.NRORG
                                    AND EHL.NRESTRUTURAM = EML.NRESTRUTURAM
                                    AND EHL.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                              WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                AND NRORG        = VH.NRORG
                                                                AND NRESTRUTURAM = EML.NRESTRUTURAM )
                                                                   
            JOIN ESO_PARAMETRO EP ON EP.NRORG = EML.NRORG
                                  AND EP.NRESTRUTURAM = EML.NRESTRUTURAM
            LEFT JOIN ESO_NAOPERIODICO ESONP ON ESONP.NRORG = VM.NRORG
                                            AND TRUNC(ESONP.DTMESCOMPETENC, 'MM') = :P_COMPETENCIA
                                            AND ESONP.NRTPAMBIENTE = EP.NRTPAMBIENTE
                                            AND ESONP.IDATIVO = 'S' AND ESONP.NRENVIOEXCL IS NULL
                                            AND ESONP.IDSTATUS IN('C','A','M')
                                            AND ESONP.NMEVENTO IN ('S-2299','S-2399')
                                            AND ESONP.NRVINCULOM = VM.NRVINCULOM
                                            AND (ESONP.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESONP.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
            LEFT JOIN ESO_NAOPERRETCP NPCP ON NPCP.NRORG = ESONP.NRORG
                                            AND NPCP.NRENVIO = ESONP.NRENVIO                                   
            LEFT JOIN ESO_PERIODICO ESOPE ON ESOPE.NRORG = VM.NRORG
                                         AND TRUNC(ESOPE.DTMESCOMPETENC, 'MM') = :P_COMPETENCIA
                                         AND ESOPE.NRTPAMBIENTE = EP.NRTPAMBIENTE
                                         AND ESOPE.IDATIVO = 'S' AND ESOPE.NRENVIOEXCL IS NULL
                                         AND ESOPE.IDSTATUS IN('C','A','M')
                                         AND ESOPE.NMEVENTO IN ('S-1200')
                                         AND ESOPE.NRCHAVE = VM.NRPESSOA
                                         AND (ESOPE.NRTABELA = :P_NRTABELA OR (:P_NRTABELA = 1 AND ESOPE.NRTABELA IS NULL) OR :P_NRTABELA IS NULL)
            LEFT JOIN ESO_PERIODRETCP PECP ON PECP.NRORG = ESOPE.NRORG
                                         AND PECP.NRENVIO = ESOPE.NRENVIO
                                
            LEFT JOIN ESTRUTURAH LOT ON LOT.NRORG        = NVL(ESOPE.NRORG, ESONP.NRORG)
                                    AND LOT.NRESTRUTURAM = NVL(ESOPE.NRESTRUTLOTACAO, ESONP.NRESTRUTLOTACAO)
                                    AND LOT.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                              WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                AND NRORG        = LOT.NRORG
                                                                AND NRESTRUTURAM = LOT.NRESTRUTURAM )
            LEFT JOIN CNAEFISCAL CF ON CF.CDCNAE = NVL(LOT.CDCNAE,EHL.CDCNAE)
            LEFT JOIN (SELECT PEM.NRORG, PEM.NRESTRUTURAM, MAX(DECODE(ITG.NREVENTOM,3590,ITG.VRPERCENT,0)) VRPERCEMPRESA, MAX(DECODE(ITG.NREVENTOM,3870,ITG.VRPERCENT,0)) VRPERCTERCEIROS
                        FROM GPE_PARAMESTRUTM PEM
                        JOIN GPE_PARAMESTRUTH PEH ON PEH.NRORG = PEM.NRORG
                                                  AND PEH.NRPARAMESTRUTM = PEM.NRPARAMESTRUTM
                                                  AND PEH.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM GPE_PARAMESTRUTH H1
                                                                              WHERE H1.DTMESCOMPETENC <= :P_COMPETENCIA
                                                                                AND H1.NRORG = PEH.NRORG
                                                                                AND H1.NRPARAMESTRUTM = PEH.NRPARAMESTRUTM )
                        JOIN FPA_PARAMFOLHAM PFM ON PFM.NRORG = PEH.NRORG
                                                AND PFM.NRPARAMFOLHAM = PEH.NRPARAMFOLHAM
                        JOIN FPA_PARAMFOLHAH PFH ON PFH.NRORG = PFM.NRORG
                                                AND PFH.NRPARAMFOLHAM = PFM.NRPARAMFOLHAM
                                                AND PFH.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM FPA_PARAMFOLHAH H1
                                                                            WHERE H1.DTMESCOMPETENC <= :P_COMPETENCIA
                                                                              AND H1.NRORG = PFH.NRORG
                                                                              AND H1.NRPARAMFOLHAM = PFH.NRPARAMFOLHAM )
                        JOIN FPA_GRPINCIDE GRI ON GRI.NRORG = PFH.NRORG
                                              AND GRI.NRGRPINCIDE = PFH.NRGRPINCIDE
                        JOIN FPA_GRPITEM ITG ON ITG.NRORG = GRI.NRORG
                                            AND ITG.NRGRPINCIDE = GRI.NRGRPINCIDE
                        WHERE PEM.NRORG = :P_NRORG
                        GROUP BY PEM.NRORG, PEM.NRESTRUTURAM) PER ON PER.NRORG = NVL(LOT.NRORG, EHL.NRORG)
                                                                AND PER.NRESTRUTURAM = NVL(LOT.NRESTRUTURAM, EHL.NRESTRUTURAM)
            /*CATEGORIA*/
            JOIN GPE_VINCULOEMPREG VINCEMPREG ON VINCEMPREG.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
            JOIN GPE_CATEGTRABESOC CATEGTRAB ON CATEGTRAB.NRCATEGESOC = VINCEMPREG.NRCATEGESOC
            /**/
            WHERE VM.NRORG = :P_NRORG
              AND ( INSTR(','||:P_NRVINCULO||',', ','||VM.NRVINCULOM||',' ) > 0 OR :P_NRVINCULO IS NULL ) --[15-02-12][multisearch_vinculo_156497]
              AND ( VM.DTADMISSAOVINC <= LAST_DAY(:P_COMPETENCIA) )
              AND ( VM.DTRESCISAOVINC >= :P_COMPETENCIA OR VM.DTRESCISAOVINC IS NULL )
              AND ( INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',' ) > 0 OR :P_NRESTRUTLEGAL IS NULL )
            GROUP BY VM.NRVINCULOM,
                PE.NRCPFPESSOA,
                VM.NMVINCULOM,
                VH.NRESTRUTLEGAL,
                EHL.NMRAZSOCESTRUT,
                EHL.CDCNPJESTRUT,
                NVL(ESOPE.DTMESCOMPETENC,ESONP.DTMESCOMPETENC),
                SUBSTR(EHL.CDCNPJESTRUT, 0,8),
                NVL(ESOPE.NRENVIO,ESONP.NRENVIO),
                NVL(ESOPE.NRESTRUTLOTACAO,ESONP.NRESTRUTLOTACAO),
                NVL(LOT.CDFPAS,EHL.CDFPAS),
                NVL(LOT.CDTERCEIRO,EHL.CDTERCEIRO),
                NVL(LOT.VRFAP,EHL.VRFAP),
                NVL(LOT.CDCNAE,EHL.CDCNAE),
                CF.VRALIQRAT,
                PER.VRPERCEMPRESA,
                PER.VRPERCTERCEIROS,
                CATEGTRAB.DSCATEGESOC,
                CATEGTRAB.CDESOCIAL
              ) PRI
    GROUP BY NOME, NRCPFPESSOA, NRLEGAL, RAZAOLEGAL, CNPJLEGAL, PRI.CDFPAS, PRI.CDTERCEIRO, CNPJRAIZ, PRI.VRBASE_ESO, PRI.VRCALCULADO_ESO, PRI.VRMATERNIDADE_ESO, PRI.VRFAMILIA_ESO,
            PRI.NRESTRUTLOTACAO, PRI.VRFAP, PRI.VRALIQRAT, PRI.VRPERCEMPRESA, PRI.VRPERCTERCEIROS, PRI.DSCATEGESOC, PRI.CDESOCIAL)
  ORDER BY CNPJRAIZ, CNPJLEGAL, NOME, DSCATEGESOC";
}
