<?php

namespace HCM\Geral\Services;

use Doctrine\ORM\EntityManager;
use HCM\FPA\Services\CCTService;
use HCM\FPA\Services\EventoEstruturaService;
use HCM\FPA\Services\ParametroSindicatoService;
use HCM\FPA\Services\TpItemCCTService;
use HCM\Geral\Services\EstruturasService;
use HCM\Geral\Services\ParcnegocioService;
use HCM\Util\DateUtil;
use HCM\Util\HCMParameters;
use HCM\Util\Repositories;
use HCM\VAB\Services\BeneficioService;
use HCM\VAB\Services\TipoBeneficioService;

class ParametrizacaoSindicatoService {

    public function __construct (EntityManager $entityManager, HCMParameters $hcmParameters, ParcnegocioService $parcnegocioService, EstruturasService $estruturasService, 
                                 ParametroSindicatoService $parametroSindicatoService, CCTService $cctService, TpItemCCTService $tpItemCCTService, EventoEstruturaService $eventoEstruturaService, BeneficioService $beneficioService,
                                 TipoBeneficioService $tipoBeneficioService){
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->parcnegocioService = $parcnegocioService;
        $this->estruturasService = $estruturasService;
        $this->parametroSindicatoService = $parametroSindicatoService;
        $this->cctService = $cctService;
        $this->tpItemCCTService = $tpItemCCTService;
        $this->eventoEstruturaService = $eventoEstruturaService;
        $this->beneficioService = $beneficioService;
        $this->tipoBeneficioService = $tipoBeneficioService;
    }
    
    public function importarSindicatoPadrao($sindicato) {
        try {
            //O array $commits recebe cada objeto criado na forma de pilha para fazer o persist
            $commits = array();
            
            $this->entityManager->beginTransaction();
            
            $cdcnpjestrut = str_replace(array('.','/','-'),'',$sindicato['CDCNPJESTRUT']);
            
            if (strlen($cdcnpjestrut) == 14) {
                $cdtipoinscricao = 'CNPJ';
            } else if (strlen($cdcnpjestrut) == 11) {
                $cdtipoinscricao = 'CPF';
            } else {
                $cdtipoinscricao = 'LIVRE';
            }
            
            //Cria Parceiro de Negócio
            $parceiro = $this->novoParcnegocio(
                $this->hcmParameters->getNrorgTrabalho(), $sindicato['NMESTRUTURAH'], $sindicato['NMESTRUTURAH'], 'ESTRUTURA', 'N', 'N',
                $cdtipoinscricao, $cdcnpjestrut, DateUtil::getDataDeString($sindicato['DTINIVIGENCIA'], DateUtil::FORMATO_BRASILEIRO_DATAHORA, true)
            );
            array_unshift($commits,$parceiro);
            
            //Cria Endereço do Parceiro
            $enderecos = $this->entityManager->getRepository(Repositories::ENDERECOPARC)->findBy(array('nrorg' => $sindicato['NRORG'], 'nrparcnegocio' => $sindicato['NRPARCNEGOCIO']));
            foreach($enderecos as $endereco) {
                $novoendereco = $this->novoEndereco(
                    $parceiro->getNrparcnegocio(), $endereco->getCdpais(), $endereco->getSgestado(), $endereco->getCdmunicipio(), $endereco->getCdlogradouro(), $endereco->getNmbairroendereco(),
                    $endereco->getCdtipoendereco(), $endereco->getNrcependereco(), $endereco->getDscompleendereco(), $endereco->getNrimovelendereco(), $endereco->getDsendereco(),
                    $endereco->getDsreferenciaende()
                );
                array_unshift($commits,$novoendereco);
            }
            
            //Cria Comunicação do Parceiro
            $comunicacoes = $this->entityManager->getRepository(Repositories::COMUNICAPARC)->findBy(array('nrorg' => $sindicato['NRORG'], 'nrparcnegocio' => $sindicato['NRPARCNEGOCIO']));
            foreach($comunicacoes as $comunicacao) {
                $novaformacomu = $this->novaFormacomu(
                    $parceiro->getNrparcnegocio(), $comunicacao->getCdformacomu(), $comunicacao->getCdprefixcomuparc(), $comunicacao->getCdcomunicaparc(), $comunicacao->getCdcomplecomuparc(), $comunicacao->getNrenderecoparc()
                );
                array_unshift($commits,$novaformacomu);
            }
            
            //Cria estruturas mestre e histórico
            $estruturas = $this->novaEstrutura(
                $sindicato['NRTIPOESTRUTURA'], $sindicato['DTINIVIGENCIA'], $sindicato['IDATIVO'], $sindicato['IDOPTSIMPLES'], $parceiro->getNrparcnegocio(), $sindicato['NMESTRUTURAM'], $cdcnpjestrut, $sindicato['DTFIMVIGENCIA'], $sindicato['CDINTESTRUTURA'], null, null, $sindicato['CDINTESTRUTEXP'],
                $sindicato['CDINTESTRUTEXPFIL'], null, null, $sindicato['NRTPEVENTOCTBL'], $sindicato['NRREGIMEAPUR'], $sindicato['DTESOCIAL'], $sindicato['NRGRUPOESOCIAL'], $sindicato['DTEXTINCAO'], $sindicato['NRCALENDARIO'], $sindicato['CDCEIESTRUT'], $sindicato['NMRAZSOCESTRUT'],
                $sindicato['CDNATUJURI'], $sindicato['CDCNAE'], $sindicato['NRCAGED'], $sindicato['CDEMPRCAIXA'], $sindicato['IDTIPOEMPR'], $sindicato['IDPARTICIPAT'], $sindicato['NRPROPRIEMPR'], $sindicato['NRPARCRESPINF'], $sindicato['NRPARCENTISIN'], $sindicato['CDFPAS'], $sindicato['CDREDUCONT'], $sindicato['NMFANTASIA'], 
                $sindicato['NMESTRUTURAH'], $sindicato['CDCPFESTRUTURA'], DateUtil::getDataDeString($sindicato['DTBASESINDICAL'], DateUtil::FORMATO_BRASILEIRO_DATAHORA, true), $sindicato['CDSINDICAL'], $sindicato['CDTERCEIRO'], $sindicato['NRCLASSTRIBUT'], $sindicato['VRFAP'], $sindicato['NRTIPOTRIBUT'], $sindicato['VRALIQDESON'], $sindicato['CDFEDERALESTRUT'], $sindicato['NRPARCREGAMB'], 
                $sindicato['NRPARCMONBIO'], $sindicato['DTINIRESAMB'], $sindicato['DTFIMRESAMB'], $sindicato['NRTPOBRIGAPRENDIZ'], $sindicato['NRTPOBRIGAPCD'], $sindicato['CDCAEPFESTRUT'], $sindicato['CODCONVENIO']
            );
            array_unshift($commits,$estruturas[0]);
            array_unshift($commits,$estruturas[1]);
            
            //Cria Parametro de Sindicato
            $parametros = $this->entityManager->getRepository(Repositories::FPA_PARAMSINDICATO)->findBy(array('nrorg' => $sindicato['NRORG'], 'nrestruturam' => $sindicato['NRESTRUTURAM']));
            foreach($parametros as $parametro) {
                $paramsindicato = $this->setParametroSindicato(
                    $this->hcmParameters->getNrorgTrabalho(), $estruturas[0]->getNrestruturam(), 'S', $parametro->getIdultrperantfer(), $parametro->getDtiniciovigencia(), $parametro->getDtfimvigencia(), $parametro->getIdultranoant13(), 
                    $parametro->getNrmesesmedia1(), $parametro->getNrmesesmedia2(), $parametro->getNrmesesmedia3(), $parametro->getCdsindical(), $parametro->getDtbasesindical(), $parametro->getNrdiv13antecip(), $parametro->getNrdiasapurvales(), $parametro->getVrperdescvale()
                );
                array_unshift($commits,$paramsindicato);
            }
            
            //Cria CCT
            //Cria CCT - Item
            //Cria CCT - Benefício
            $ccts = $this->entityManager->getRepository(Repositories::FPA_CADASTROCCT)->findBy(array('nrorg' => $sindicato['NRORG'], 'nrestruturam' => $sindicato['NRESTRUTURAM']));
            foreach($ccts as $cct) {
                $novoCCT = $this->novoCCT($estruturas[0]->getNrestruturam(), $cct->getDtanobasecct(), $cct->getDtinivigenciacct(), $cct->getDtfinvigenciacct());
                array_unshift($commits,$novoCCT);
                
                $itensCCT = $this->entityManager->getRepository(Repositories::FPA_ITCADASTROCCT)->findBy(array('nrorg' => $cct->getNrorg(), 'nrcadastrocct' => $cct->getNrcadastrocct()));
                foreach($itensCCT as $itemCCT) {
                
                    $tipoitemcctPadrao = $this->entityManager->getRepository(Repositories::GPE_TIPOITEMCCT)->findOneBy(array('nrorg' => $itemCCT->getNrorg(), 'nrtipoitemcct' => $itemCCT->getNrtipoitemcct()));
                    
                    $tipoitemcct = $this->entityManager->getRepository(Repositories::GPE_TIPOITEMCCT)->findOneBy(array('nrorg' => $this->hcmParameters->getNrorgTrabalho(), 'nmtipoitemcct' => $tipoitemcctPadrao->getNmtipoitemcct()));
                    if (!is_object($tipoitemcct)) {
                        $tipoitemcct = $this->novoTipoitemcct($tipoitemcctPadrao->getNmtipoitemcct());
                        array_unshift($commits,$tipoitemcct);
                    }
                    
                    $novoitemcct = $this->novoItemCCT(
                        $novoCCT->getNrcadastrocct(), $tipoitemcct->getNrtipoitemcct(), $itemCCT->getDsitemcct(), $itemCCT->getDslegislacaoitcct(), $itemCCT->getNrocupacaom(), $itemCCT->getNrescalatrabm(), $itemCCT->getNrsitufuncm(), $itemCCT->getNrtpdemissao(), $itemCCT->getNreventom(), $itemCCT->getNrfaixatabfolha(), $itemCCT->getNrvalorreferenciam(),
                        $itemCCT->getVrpisoitcct(), $itemCCT->getVrtetoitcct(), $itemCCT->getDtiniitemcct(), $itemCCT->getDtfinitemcct(), $itemCCT->getVrpercentualitcct(), $itemCCT->getVritemcct(), $itemCCT->getDsiniintervalocct(), $itemCCT->getDsfinintervalocct(), $itemCCT->getVridademinimacct(), $itemCCT->getVridademaximacct(),
                        $itemCCT->getQtdemesesitcct(), $itemCCT->getQtdeanomincct(), $itemCCT->getQtdeanomaxcct(), $itemCCT->getQtdiasestabitcct()
                    );
                    array_unshift($commits,$novoitemcct);
                }
                
                $beneficiosCCT = $this->entityManager->getRepository(Repositories::VAB_BENEFICIOCCT)->findBy(array('nrorg' => $cct->getNrorg(), 'nrcadastrocct' => $cct->getNrcadastrocct()));
                foreach($beneficiosCCT as $beneficioCCT) {
                
                    $tpbeneficioPadrao = $this->entityManager->getRepository(Repositories::TPBENEFICIO)->findOneBy(array('nrorg' => $beneficioCCT->getNrorg(), 'nrtpbeneficio' => $beneficioCCT->getNrtpbeneficio()));
                    
                    $tpbeneficio = $this->entityManager->getRepository(Repositories::TPBENEFICIO)->findOneBy(array('nrorg' => $this->hcmParameters->getNrorgTrabalho(), 'dstpbeneficio' => $tpbeneficioPadrao->getDstpbeneficio()));
                    if (!is_object($tpbeneficio)) {
                        $tpbeneficio = $this->novoTpbeneficio($tpbeneficioPadrao->getDstpbeneficio());
                        array_unshift($commits,$tpbeneficio);
                    }
                    
                    $novobeneficiocct = $this->novoBeneficioCCT(
                        $novoCCT->getNrcadastrocct(), $tpbeneficio->getNrtpbeneficio(), $beneficioCCT->getNridademaxsubfilhos(), $beneficioCCT->getSexosubsidiofilho(), $beneficioCCT->getNridademaxsubdep(), $beneficioCCT->getSexosubsidiodep(), $beneficioCCT->getNrevetitularvinc(), $beneficioCCT->getNrtipoparticipatitular(), $beneficioCCT->getNrtabfaixasaltit(), $beneficioCCT->getVrtitularsind(), $beneficioCCT->getVrtetotitularsind(),
                        $beneficioCCT->getVrpisotitularsind(), $beneficioCCT->getNrevedepevinc(), $beneficioCCT->getNrtipoparticipadep(), $beneficioCCT->getNrtabfaixasaldep(), $beneficioCCT->getVrdepsind(), $beneficioCCT->getVrpisodepsind(), $beneficioCCT->getVrtetodepsind(), $beneficioCCT->getIdativo(), $beneficioCCT->getNreventomensa(), $beneficioCCT->getNreventomensadep(), $beneficioCCT->getVrtetotitularmens(), $beneficioCCT->getVrpisotitularmens(), 
                        $beneficioCCT->getVrlinearbeneficio(), $beneficioCCT->getVrlinearbeneficiodep(), $beneficioCCT->getIdpropadmis(), $beneficioCCT->getIdpropresc(), $beneficioCCT->getQtdiasminmes(), $beneficioCCT->getQtdiasmaxfaltas(), $beneficioCCT->getQtdiasmaxatest(), $beneficioCCT->getQtmesmaxafast(), $beneficioCCT->getVrmultiplicador(), $beneficioCCT->getDsvinculoempreg(), $beneficioCCT->getDsincidevento(), $beneficioCCT->getVrfixacresdesc(), 
                        $beneficioCCT->getVrperacrescdesc(), $beneficioCCT->getIdnaogerbenvincexp(), $beneficioCCT->getIdnaogerabenperexp(), $beneficioCCT->getIdnaogerabenresc(), $beneficioCCT->getVrparticipatitular(), $beneficioCCT->getVrpisotitular(), $beneficioCCT->getVrtetotitular(), $beneficioCCT->getVrparticipadepe(), $beneficioCCT->getVrpisodep(), $beneficioCCT->getVrtetodep(), $beneficioCCT->getQtmaxhsreduzida(), $beneficioCCT->getVrhsreduzida(), 
                        $beneficioCCT->getDsincidevenperder(), $beneficioCCT->getQtmesretrocmult(), $beneficioCCT->getQtmesretrocsemben(), $beneficioCCT->getDsafastamento1(), $beneficioCCT->getIdgeradescafast1(), $beneficioCCT->getDsafastamento2(), $beneficioCCT->getQtmesmaxafast2(), $beneficioCCT->getIdgeradescafast2(), $beneficioCCT->getDsafastamento3(), $beneficioCCT->getQtmesretrocdiastrab()
                    );
                    array_unshift($commits,$novobeneficiocct);
                }
            }
            
            //Cria Evento Relacionado
            $eventos = $this->entityManager->getRepository(Repositories::FPA_ESTRUTEVENTO)->findBy(array('nrorg' => $sindicato['NRORG'], 'nrestruturam' => $sindicato['NRESTRUTURAM']));
            foreach($eventos as $evento) {
                $eventoEstrut = $this->novoEstrutevento(
                    $estruturas[0]->getNrestruturam(), $evento->getNreventom(), $evento->getDtinivigencia(), $evento->getDtfimvigencia(), $evento->getPeriodicidademes(), $evento->getNrvalorreferenciam(),
                    $evento->getVrpercent(), $evento->getVrmultiplic(), $evento->getVrdivide(), $evento->getVreventofixo(), $evento->getIdrefgerar(), $evento->getIdretreferencia(), $evento->getVrreffixo(), 
                    $evento->getIdtipomovimento(), $evento->getVrpisoevento(), $evento->getVrtetoevento(), $evento->getDsobservacao(), $evento->getNrtpagrupacalc(), $evento->getIdgeraafastado()
                );
                array_unshift($commits,$eventoEstrut);
            }
            
            //Cria Benefício
            $beneficios = $this->entityManager->getRepository(Repositories::VAB_BENEFICIOM)->retornaBeneficiosSindicato($sindicato['NRORG'], $this->hcmParameters->getDtCompetencia(), $sindicato['NRESTRUTURAM']);
            foreach($beneficios as $beneficio) {
                
                $tpbeneficioPadrao = $this->entityManager->getRepository(Repositories::TPBENEFICIO)->findOneBy(array('nrorg' => $beneficio->getNrorg(), 'nrtpbeneficio' => $beneficio->historico->getNrtpbeneficio()));
                
                $tpbeneficio = $this->entityManager->getRepository(Repositories::TPBENEFICIO)->findOneBy(array('nrorg' => $this->hcmParameters->getNrorgTrabalho(), 'dstpbeneficio' => $tpbeneficioPadrao->getDstpbeneficio()));
                if (!is_object($tpbeneficio)) {
                    $tpbeneficio = $this->novoTpbeneficio($tpbeneficioPadrao->getDstpbeneficio());
                    array_unshift($commits,$tpbeneficio);
                }
                
                $estrutPadrao = $this->entityManager->getRepository(Repositories::ESTRUTURAM)->getEstrutura($beneficio->getNrorg(), $beneficio->historico->getNrestruturam(), $this->hcmParameters->getDtCompetencia());
                
                $estrutBeneficio = $this->entityManager->getRepository(Repositories::ESTRUTURAM)->getEstruturaPorCnpj($this->hcmParameters->getNrorgTrabalho(), $estrutPadrao->historico->getCdcnpjestrut(), $this->hcmParameters->getDtCompetencia());
                if (!is_object($estrutBeneficio)) {
                    
                    $parcnegocio = $this->entityManager->getRepository(Repositories::PARCNEGOCIO)->findOneBy(array('nrorg' => $estrutPadrao->getNrorg(), 'nrparcnegocio' => $estrutPadrao->historico->getNrparcnegocio()));
                    
                    try {
                        $this->entityManager->beginTransaction();
                        
                        //Cria Parceiro de Negócio
                        $parceiro = $this->novoParcnegocio(
                            $this->hcmParameters->getNrorgTrabalho(), $parcnegocio->getNmprincipalparc(), $parcnegocio->getNmsecundariparc(), $parcnegocio->getCdtipoparcprincipal(), $parcnegocio->getIdpessoafisica(), 
                            $parcnegocio->getIdinstituicao(), $parcnegocio->getCdtipoinscricao(), $parcnegocio->getNrinscricaoparc(), $parcnegocio->getDtnascifundparc()
                        );
                        array_unshift($commits,$parceiro);
                        
                        //Cria estruturas mestre e histórico
                        $estruturas = $this->novaEstrutura(
                            $estrutPadrao->getNrtipoestrutura(), $estrutPadrao->getDtinivigencia(), $estrutPadrao->historico->getIdativo(), $estrutPadrao->historico->getIdoptsimples(), $parceiro->getNrparcnegocio(), $estrutPadrao->getNmestruturam(), $estrutPadrao->historico->getCdcnpjestrut(), $estrutPadrao->getDtfimvigencia(), $estrutPadrao->getCdintestrutura(), $estrutPadrao->getNrestruturamold(), $estrutPadrao->historico->getNmestruturah(), $estrutPadrao->getCdintestrutexp(),
                            $estrutPadrao->getCdintestrutexpfil(), null, null, $estrutPadrao->getNrtpeventoctbl(), null, null, null, $estrutPadrao->historico->getDtextincao(), $estrutPadrao->historico->getNrcalendario(), $estrutPadrao->historico->getCdceiestrut(), $estrutPadrao->historico->getNmrazsocestrut(),
                            $estrutPadrao->historico->getCdnatujuri(), $estrutPadrao->historico->getCdcnae(), $estrutPadrao->historico->getNrcaged(), $estrutPadrao->historico->getCdemprcaixa(), $estrutPadrao->historico->getIdtipoempr(), $estrutPadrao->historico->getIdparticipat(), $estrutPadrao->historico->getNrpropriempr(), $estrutPadrao->historico->getNrparcrespinf(), $estrutPadrao->historico->getNrparcentisin(), $estrutPadrao->historico->getCdfpas(), $estrutPadrao->historico->getCdreducont(), $estrutPadrao->historico->getNmfantasia(), 
                            $estrutPadrao->historico->getNmestruturah(), $estrutPadrao->historico->getCdcpfestrutura(), $estrutPadrao->historico->getDtbasesindical(), $estrutPadrao->historico->getCdsindical(), $estrutPadrao->historico->getCdterceiro(), $estrutPadrao->historico->getNrclasstribut(), $estrutPadrao->historico->getVrfap(), $estrutPadrao->historico->getNrtipotribut(), $estrutPadrao->historico->getVraliqdeson(), $estrutPadrao->historico->getCdfederalestrut(), $estrutPadrao->historico->getNrparcregamb(), 
                            $estrutPadrao->historico->getNrparcmonbio(), $estrutPadrao->historico->getDtiniresamb(), $estrutPadrao->historico->getDtfimresamb(), null, null, $estrutPadrao->historico->getCdcaepfestrut(), null
                        );
                        array_unshift($commits,$estruturas[0]);
                        array_unshift($commits,$estruturas[1]);
                        
                        $this->entityManager->commit();
                        
                        $estrutBeneficio = $estruturas[0];
                        $estrutBeneficio->historico = $estruturas[1];
                    } catch(\Exception $e) {
                        $this->entityManager->rollback();
                        throw $e;
                    }
                }
                
                $beneficiom = $this->novoBeneficioMestre($beneficio->getDtiniciovigencia(), $beneficio->getDtfinalvigencia(), $beneficio->getIdativo());
                
                $beneficioh = $this->novoBeneficioHistorico(
                    $beneficiom->getNrbeneficiom(), $tpbeneficio->getNrtpbeneficio(), $beneficio->historico->getNrformabeneficio(), $estrutBeneficio->getNrestruturam(), $beneficio->historico->getDtmescompetenc(), $beneficio->historico->getDtreferencia(), $beneficio->historico->getDsbeneficio(), $beneficio->historico->getTpperiodobenef(), $beneficio->historico->getDsobsbeneficio(), $beneficio->historico->getNrtabelafolhapri(), $beneficio->historico->getNrtabelafolhasec(), $beneficio->historico->getIdativo(), $beneficio->historico->getNreventomensa(), 
                    $beneficio->historico->getNrevetitularemp(), $beneficio->historico->getNrevedepempresa(), $beneficio->historico->getNrevetitularvinc(), $beneficio->historico->getNrevedepevinc(), $beneficio->historico->getNrtabfaixasaltit(), $beneficio->historico->getNrtabfaixasaldep(), $beneficio->historico->getNrmesaniversario(), $beneficio->historico->getNrdiavencboleto(), $beneficio->historico->getVrlinearbeneficio(), $beneficio->historico->getNridademaxsubfilhos(), $beneficio->historico->getNridademaxsubdep(), 
                    $beneficio->historico->getNrtipoparticipatitular(), $beneficio->historico->getVrparticipatitular(), $beneficio->historico->getNrtipoparticipadep(), $beneficio->historico->getVrparticipadepe(), $beneficio->historico->getVrlinearbeneficiodep(), $beneficio->historico->getNreventomensadep(), $beneficio->historico->getVrpisotitular(), $beneficio->historico->getVrpisodep(), $beneficio->historico->getVrtetodep(), $beneficio->historico->getVrtetotitular(), $beneficio->historico->getSexosubsidiofilho(), 
                    $beneficio->historico->getSexosubsidiodep(), $beneficio->historico->getIdconsfaltabenef(), $beneficio->historico->getQtmesesfaltabenef(), $beneficio->historico->getIdconsatestbenef(), $beneficio->historico->getQtmesesatestbenef(), $beneficio->historico->getIdconsafastbenef(), $beneficio->historico->getQtmesesafastbenef(), $beneficio->historico->getIdconsferiasbenef(), $beneficio->historico->getQtmesesferiasbenef(), $beneficio->historico->getIdconsferiadobenef(), 
                    $beneficio->historico->getQtmesesferiadobenef(), $beneficio->historico->getIdconsdsrbenef(), $beneficio->historico->getQtmesesdsrbenef(), $beneficio->historico->getIdgerabeneffalta(), $beneficio->historico->getIdgerabenefatest(), $beneficio->historico->getIdgerabenefafast(), $beneficio->historico->getIdgerabenefferias(), $beneficio->historico->getConsvincresmesant(), $estruturas[0]->getNrestruturam(), $beneficio->historico->getDtdisponib(), $beneficio->historico->getIdpropadmis(), 
                    $beneficio->historico->getIdpropresc(), $beneficio->historico->getNreventocopart(), $beneficio->historico->getNreventocopartdep(), $beneficio->historico->getPercoparticipatitu(), $beneficio->historico->getPercoparticipadepe(), $beneficio->historico->getVrdepsind(), $beneficio->historico->getVrtitularsind(), $beneficio->historico->getIdpropdtinscr(), $beneficio->historico->getIdpropdtcanc(), $beneficio->historico->getIdduplicmens(), $beneficio->historico->getNrdiarescisao(), $beneficio->historico->getNreventotaxa(), 
                    $beneficio->historico->getVreventotaxa(), $beneficio->historico->getVrtetotitularsind(), $beneficio->historico->getVrpisotitularsind(), $beneficio->historico->getVrpisodepsind(), $beneficio->historico->getVrtetodepsind(), $beneficio->historico->getVrtetotitularmens(), $beneficio->historico->getVrpisotitularmens(), $beneficio->historico->getIdgeradescafast(), $beneficio->historico->getPeriodicidademes(), $beneficio->historico->getIdgerbenefadmissao(), $beneficio->historico->getIdgerbenefrescisao()
                );
                array_unshift($commits,$beneficiom);
                array_unshift($commits,$beneficioh);
            }
            
            //Executa o persiste para cada objeto empilhado e faz o flush e commit para executar na ordem inversa, pois na ordem de execução do código estava inserindo o benefício antes da sua estrutura
            foreach($commits as $entity){
                $this->entityManager->persist($entity);
            }
            $this->entityManager->flush();
            $this->entityManager->commit();
        } catch(\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function novoParcnegocio($nrorg, $nmprincipalparc, $nmsecundariparc, $cdtipoparceiro, $idpessoafisica, $idinstituicao,
                         $cdtipoinscricao, $nrinscricaoparc, $dtnascifundparc)
    {
        $parcnegocio = Repositories::PARCNEGOCIO;
        
        $idativo = 'S';
        $parceiro = new $parcnegocio;
        $parceiro->setNrorg($nrorg);
        $parceiro->setIdativo($idativo);
        $parceiro->setNmprincipalparc($nmprincipalparc);
        $parceiro->setNmsecundariparc($nmsecundariparc);
        $parceiro->setCdtipoparcprincipal($cdtipoparceiro);
        $parceiro->setIdpessoafisica($idpessoafisica);
        $parceiro->setIdinstituicao($idinstituicao);
        $parceiro->setCdtipoinscricao($cdtipoinscricao);
        $parceiro->setNrinscricaoparc($nrinscricaoparc);
        $parceiro->setDtnascifundparc($dtnascifundparc);

        $parceiro->setDtinclusao(DateUtil::getDataAtual());
        $parceiro->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $parceiro->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $parceiro->setDtultatu(DateUtil::getDataAtual());
        $parceiro->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        $parceiro->setCdoperultatu($this->hcmParameters->getCdoperador());

        $parceiro->setNrparcnegocio(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'PARCNEGOCIO', 1, 12, true));

        //$this->entityManager->persist($parceiro);

        return $parceiro;
    }
    
    public function novoEndereco($nrparcnegocio, $cdpais, $sgestado, $cdmunicipio, $cdlogradouro, $nmbairroendereco,
                         $cdtipoendereco, $nrcependereco, $dscompleendereco, $nrimovelendereco, $dsendereco,
                         $dsreferenciaende)
    {
        $enderecoParc = Repositories::ENDERECOPARC;
        
        $endereco = new $enderecoParc;

        $endereco->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $endereco->setDtinclusao(DateUtil::getDataAtual());
        $endereco->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $endereco->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $endereco->setDtultatu(DateUtil::getDataAtual());
        $endereco->setCdoperultatu($this->hcmParameters->getCdoperador());
        $endereco->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        $endereco->setNrparcnegocio($nrparcnegocio);
        $endereco->setCdpais($cdpais);
        $endereco->setIdativo('S');
        $endereco->setSgestado($sgestado);
        $endereco->setCdmunicipio($cdmunicipio);
        $endereco->setCdlogradouro($cdlogradouro);
        $endereco->setNmbairroendereco($nmbairroendereco);
        $endereco->setCdtipoendereco($cdtipoendereco);
        $endereco->setNrcependereco($nrcependereco);
        $endereco->setDscompleendereco($dscompleendereco);
        $endereco->setNrimovelendereco($nrimovelendereco);
        $endereco->setDsendereco($dsendereco);
        $endereco->setDsreferenciaende($dsreferenciaende);
        $endereco->setNrenderecoparc(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'ENDERECOPARC', 1, 10, true));
        
        //$this->entityManager->persist($endereco);
        
        return $endereco;
    }
    
    public function novaFormacomu($nrparcnegocio, $cdformacomu, $cdprefixcomuparc, $cdcomunicaparc, $cdcomplecomuparc, $nrenderecoparc) {
        $comunicaParc = Repositories::COMUNICAPARC;
        
        $obj = new $comunicaParc;
        $obj->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $obj->setDtinclusao(DateUtil::getDataAtual());
        $obj->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $obj->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $obj->setDtultatu(DateUtil::getDataAtual());
        $obj->setCdoperultatu($this->hcmParameters->getCdoperador());
        $obj->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        $obj->setIdativo('S');
        $obj->setNrparcnegocio($nrparcnegocio);
        $obj->setCdformacomu($cdformacomu);
        $obj->setCdprefixcomuparc($cdprefixcomuparc);
        $obj->setCdcomunicaparc($cdcomunicaparc);
        $obj->setCdcomplecomuparc($cdcomplecomuparc);
        $obj->setNrenderecoparc($nrenderecoparc);
        $nrcomunicaparc = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'COMUNICAPARC', 1, 12, true);
        $obj->setNrcomunicaparc($nrcomunicaparc);
        
        //$this->entityManager->persist($obj);
        
        return $obj;
    }
    
    public function novaEstrutura($nrtipoestrutura, $dtinivigencia, $idativo, $idoptsimples, $nrparcnegocio, $nmestruturam = null, $cdcnpjestrut = null, $dtfimvigencia = null, $cdintestrutura = null, $nrestruturamold = null, $dsestrutura = null, $cdintestrutexp = null,
                         $cdintestrutexpfil = null, $cdcentcust = null, $dsurllogoestrutura = null, $nrtpeventoctbl = null, $nrregimeapur = null, $dtesocial = null, $nrgrupoesocial = null, $dtextincao = null, $nrcalendario = null, $cdceiestrut = null, $nmrazsocestrut = null,
                         $cdnatujuri = null, $cdcnae = null, $nrcaged = null, $cdemprcaixa = null, $idtipoempr = null, $idparticipat = null, $nrpropriempr = null, $nrparcrespinf = null, $nrparcentisin = null, $cdfpas = null, $cdreducont = null, $nmfantasia = null, 
                         $nmestruturah = null, $cdcpfestrutura = null, $dtbasesindical = null, $cdsindical = null, $cdterceiro = null, $nrclasstribut = null, $vrfap = null, $nrtipotribut = null, $vraliqdeson = null, $cdfederalestrut = null, $nrparcregamb = null, 
                         $nrparcmonbio = null, $dtiniresamb = null, $dtfimresamb = null, $nrtpobrigaprendiz = null, $nrtpobrigapcd = null, $cdcaepfestrut = null, $codconvenio = null){
        
        $nrorg = $this->hcmParameters->getNrorgTrabalho();
        $mesCompetencia = $this->hcmParameters->getDtCompetencia();
        
        $estruturam = $this->novaEstruturaMestre($nrorg, $idativo, $nrtipoestrutura, $dtinivigencia, $nrparcnegocio, $nmestruturam, $dtfimvigencia, $cdintestrutura, $nrestruturamold, $dsestrutura, $cdintestrutexp,
                                        $cdintestrutexpfil, $cdcentcust, $dsurllogoestrutura, $nrtpeventoctbl, $nrregimeapur, $dtesocial, $nrgrupoesocial);
        $estruturah = $this->novaEstruturaHistorico($nrorg, $idativo, $estruturam->getNrestruturam(), $mesCompetencia, $idoptsimples, $nrparcnegocio, $cdcnpjestrut, $dtextincao, $nrcalendario, $cdceiestrut, $nmrazsocestrut,
                                           $cdnatujuri, $cdcnae, $nrcaged, $cdemprcaixa, $idtipoempr, $idparticipat, $nrpropriempr, $nrparcrespinf, $nrparcentisin, $cdfpas, $cdreducont, $nmfantasia, 
                                           $nmestruturah, $cdcpfestrutura, $dtbasesindical, $cdsindical, $cdterceiro, $nrclasstribut, $vrfap, $nrtipotribut, $vraliqdeson, $cdfederalestrut, $nrparcregamb, 
                                           $nrparcmonbio, $dtiniresamb, $dtfimresamb, $nrtpobrigaprendiz, $nrtpobrigapcd, $cdcaepfestrut, $codconvenio);
        
        return array($estruturam, $estruturah);
    }
    
    public function novaEstruturaMestre($nrorg, $idativo, $nrtipoestrutura, $dtinivigencia, $nrparcnegocio, $nmestruturam, $dtfimvigencia = null, $cdintestrutura = null, $nrestruturamold = null, $dsestrutura = null, $cdintestrutexp = null,
                                $cdintestrutexpfil = null, $cdcentcust = null, $dsurllogoestrutura = null, $nrtpeventoctbl = null, $nrregimeapur = null, $dtesocial = null, $nrgrupoesocial = null){
        $estruturam = Repositories::ESTRUTURAM;
        
        $estruturam = new $estruturam;
        
        $estruturam->setNrorg($nrorg);
        $estruturam->setNrtipoestrutura($nrtipoestrutura);
        $estruturam->setDtinivigencia(DateUtil::getDataDeString($dtinivigencia, DateUtil::FORMATO_BRASILEIRO, true));
        $estruturam->setNrparcnegocio($nrparcnegocio);
        $estruturam->setNmestruturam($nmestruturam);
        $estruturam->setIdativo($idativo);
        
        $estruturam->setDtfimvigencia(DateUtil::getDataDeString($dtfimvigencia, DateUtil::FORMATO_BRASILEIRO, true));
        $estruturam->setCdintestrutura($cdintestrutura);
        $estruturam->setNrestruturamold($nrestruturamold);
        // $estruturam->setDsestrutura($dsestrutura);
        // $estruturam->setCdintestrutexp($cdintestrutexp);
        // $estruturam->setCdintestrutexpfil($cdintestrutexpfil);
        // $estruturam->setCdcentcust($cdcentcust);
        // $estruturam->setDsurllogoestrutura($dsurllogoestrutura);
        $estruturam->setNrtpeventoctbl($nrtpeventoctbl);
        // $estruturam->setNrregimeapur($nrregimeapur);
        // $estruturam->setDtesocial($dtesocial);
        // $estruturam->setNrgrupoesocial($nrgrupoesocial);       
        

        $estruturam->setDtinclusao(DateUtil::getDataAtual());
        $estruturam->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $estruturam->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $estruturam->setDtultatu(DateUtil::getDataAtual());
        $estruturam->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        $estruturam->setCdoperultatu($this->hcmParameters->getCdoperador());

        $estruturam->setNrestruturam(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'ESTRUTURAM', 1, 12, true));

        //$this->entityManager->persist($estruturam);
    
        return $estruturam;
    }
    
    public function novaEstruturaHistorico($nrorg, $idativo, $nrestruturam, $mesCompetencia, $idoptsimples, $nrparcnegocio, $cdcnpjestrut = null, $dtextincao = null, $nrcalendario = null, $cdceiestrut = null, $nmrazsocestrut = null,
                                  $cdnatujuri = null, $cdcnae = null, $nrcaged = null, $cdemprcaixa = null, $idtipoempr = null, $idparticipat = null, $nrpropriempr = null, $nrparcrespinf = null, $nrparcentisin = null, $cdfpas = null, $cdreducont = null, $nmfantasia = null, 
                                  $nmestruturah = null, $cdcpfestrutura = null, $dtbasesindical = null, $cdsindical = null, $cdterceiro = null, $nrclasstribut = null, $vrfap = null, $nrtipotribut = null, $vraliqdeson = null, $cdfederalestrut = null, $nrparcregamb = null, 
                                  $nrparcmonbio = null, $dtiniresamb = null, $dtfimresamb = null, $nrtpobrigaprendiz = null, $nrtpobrigapcd = null, $cdcaepfestrut = null, $codconvenio = null){
        $estruturah = Repositories::ESTRUTURAH;
        
        $estruturah = new $estruturah;
        
        $estruturah->setNrorg($nrorg);
        $estruturah->setNrestruturam($nrestruturam);
        $estruturah->setDtmescompetenc(DateUtil::getDataDeString($mesCompetencia, DateUtil::FORMATO_BRASILEIRO, true));
        $estruturah->setCdcnpjestrut($cdcnpjestrut);
        $estruturah->setIdoptsimples($idoptsimples);
        
        $estruturah->setDtextincao(DateUtil::getDataDeString($dtextincao));
        $estruturah->setNrcalendario($nrcalendario);
        $estruturah->setCdceiestrut($cdceiestrut);
        $estruturah->setNmrazsocestrut($nmrazsocestrut);
        $estruturah->setCdnatujuri($cdnatujuri);
        $estruturah->setCdcnae($cdcnae);
        $estruturah->setNrcaged($nrcaged);
        $estruturah->setCdemprcaixa($cdemprcaixa);
        $estruturah->setIdtipoempr($idtipoempr);
        $estruturah->setIdparticipat($idparticipat);
        $estruturah->setNrparcnegocio($nrparcnegocio);
        $estruturah->setNrpropriempr($nrpropriempr);
        $estruturah->setNrparcrespinf($nrparcrespinf);
        $estruturah->setNrparcentisin($nrparcentisin);
        $estruturah->setCdfpas($cdfpas);
        $estruturah->setCdreducont($cdreducont);
        $estruturah->setNmfantasia($nmfantasia);
        $estruturah->setNmestruturah($nmestruturah);
        $estruturah->setCdcpfestrutura($cdcpfestrutura);
        $estruturah->setDtbasesindical($dtbasesindical);
        $estruturah->setCdsindical($cdsindical);
        $estruturah->setCdterceiro($cdterceiro);
        $estruturah->setNrclasstribut($nrclasstribut);
        $estruturah->setVrfap($vrfap);
        $estruturah->setNrtipotribut($nrtipotribut);
        $estruturah->setVraliqdeson($vraliqdeson);
        $estruturah->setCdfederalestrut($cdfederalestrut);
        $estruturah->setIdativo($idativo);
        $estruturah->setNrparcregamb($nrparcregamb);
        $estruturah->setNrparcmonbio($nrparcmonbio);
        $estruturah->setDtiniresamb($dtiniresamb);
        $estruturah->setDtfimresamb($dtfimresamb);
        // $estruturah->setNrtpobrigaprendiz($nrtpobrigaprendiz);
        // $estruturah->setNrtpobrigapcd($nrtpobrigapcd);
        // $estruturah->setCdcaepfestrut($cdcaepfestrut);
        // $estruturah->setCodconvenio($codconvenio);
        
        $estruturah->setDtinclusao(DateUtil::getDataAtual());
        $estruturah->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $estruturah->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $estruturah->setDtultatu(DateUtil::getDataAtual());
        $estruturah->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        $estruturah->setCdoperultatu($this->hcmParameters->getCdoperador());

        $estruturah->setNrestruturah(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'ESTRUTURAH', 1, 12, true));

        //$this->entityManager->persist($estruturah);
        
        return $estruturah;
    }
    
    public function setParametroSindicato($nrorg, $nrestruturam, $idativo, $idultrperantfer, $dtiniciovigencia, $dtfimvigencia, $idultranoant13, 
                                         $nrmesesmedia1, $nrmesesmedia2, $nrmesesmedia3, $cdsindical, $dtbasesindical, $nrdiv13antecip, $nrdiasapurvales, $vrperdescvale){
        $fpa_paramsidicato = Repositories::FPA_PARAMSINDICATO;
        
        $parametroSindicato = new $fpa_paramsidicato;
        $parametroSindicato->setNrorg($nrorg);
        $parametroSindicato->setNrestruturam($nrestruturam);
        $parametroSindicato->setIdativo($idativo);
        $parametroSindicato->setIdultrperantfer($idultrperantfer);
        $parametroSindicato->setDtiniciovigencia($dtiniciovigencia);
        $parametroSindicato->setDtfimvigencia($dtfimvigencia);
        $parametroSindicato->setIdultranoant13($idultranoant13);
        $parametroSindicato->setNrmesesmedia1($nrmesesmedia1);
        $parametroSindicato->setNrmesesmedia2($nrmesesmedia2);
        $parametroSindicato->setNrmesesmedia3($nrmesesmedia3);
        $parametroSindicato->setCdsindical($cdsindical);
        $parametroSindicato->setDtbasesindical($dtbasesindical);
        $parametroSindicato->setNrdiv13antecip($nrdiv13antecip);
        $parametroSindicato->setNrdiasapurvales($nrdiasapurvales);
        $parametroSindicato->setVrperdescvale($vrperdescvale);
        $parametroSindicato->setNrsindicato(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'FPA_PARAMSINDICATO', 1, 12, true));
        
        //$this->entityManager->persist($parametroSindicato);
        
        return $parametroSindicato;
    }
    
    public function novoCCT($nrestruturam, $dtanobasecct, $dtinivigenciacct, $dtfinvigenciacct){
        $cadastrocct = Repositories::FPA_CADASTROCCT;
        
        $novo = new $cadastrocct;
        $novo->setNrestruturam($nrestruturam);
        $novo->setDtanobasecct($dtanobasecct);
        $novo->setDtinivigenciacct($dtinivigenciacct);
        $novo->setDtfinvigenciacct($dtfinvigenciacct);
        $novo->setIdativo('S');
        $novo->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtinclusao(DateUtil::getDataAtual());
        $novo->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $novo->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtultatu(DateUtil::getDataAtual());
        $novo->setCdoperultatu($this->hcmParameters->getCdoperador());
        $novo->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        $novo->setNrcadastrocct(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'FPA_CADASTROCCT', 1, 12, true));
        
        //$this->entityManager->persist($novo);
        
        return $novo;
    }
    
    public function novoTipoitemcct($nmtipoitemcct)
    {
        $tipoitemcct = Repositories::GPE_TIPOITEMCCT;
        
        $novo = new $tipoitemcct;
        $novo->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $novo->setNmtipoitemcct($nmtipoitemcct);
        $novo->setIdativo('S');  
        $novo->setDtinclusao(DateUtil::getDataAtual()); 
        $novo->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $novo->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtultatu(DateUtil::getDataAtual());
        $novo->setCdoperultatu($this->hcmParameters->getCdoperador());
        $novo->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        
        $novo->setNrtipoitemcct(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'GPE_TIPOITEMCCT', 1, 12, true));
        
        //$this->entityManager->persist($novo);
        
        return $novo;
    }
    
    public function novoItemCCT($nrcadastrocct, $nrtipoitemcct, $dsitemcct, $dslegislacaoitcct, $nrocupacaom, $nrescalatrabm, $nrsitufuncm, $nrtpdemissao, $nreventom, $nrfaixatabfolha, $nrvalorreferenciam,
                                $vrpisoitcct, $vrtetoitcct, $dtiniitemcct, $dtfinitemcct, $vrpercentualitcct, $vritemcct, $dsiniintervalocct, $dsfinintervalocct, $vridademinimacct, $vridademaximacct,
                                $qtdemesesitcct, $qtdeanomincct, $qtdeanomaxcct, $qtdiasestabitcct){
        $itcadastrocct = Repositories::FPA_ITCADASTROCCT;
        
        $novo = new $itcadastrocct;
        $novo->setNrcadastrocct($nrcadastrocct);
        $novo->setNrtipoitemcct($nrtipoitemcct);
        $novo->setDsitemcct($dsitemcct);
        $novo->setDslegislacaoitcct($dslegislacaoitcct);
        $novo->setNrocupacaom($nrocupacaom);
        $novo->setNrescalatrabm($nrescalatrabm);
        $novo->setNrsitufuncm($nrsitufuncm);
        $novo->setNrtpdemissao($nrtpdemissao);
        $novo->setNreventom($nreventom);
        $novo->setNrfaixatabfolha($nrfaixatabfolha);
        $novo->setNrvalorreferenciam($nrvalorreferenciam);
        $novo->setVrpisoitcct($vrpisoitcct);
        $novo->setVrtetoitcct($vrtetoitcct);
        $novo->setDtiniitemcct($dtiniitemcct);
        $novo->setDtfinitemcct($dtfinitemcct);
        $novo->setVrpercentualitcct($vrpercentualitcct);
        $novo->setVritemcct($vritemcct);
        $novo->setDsiniintervalocct($dsiniintervalocct);
        $novo->setDsfinintervalocct($dsfinintervalocct);
        $novo->setVridademinimacct($vridademinimacct);
        $novo->setVridademaximacct($vridademaximacct);
        $novo->setQtdemesesitcct($qtdemesesitcct);
        $novo->setQtdeanomincct($qtdeanomincct);
        $novo->setQtdeanomaxcct($qtdeanomaxcct);
        $novo->setQtdiasestabitcct($qtdiasestabitcct);
        $novo->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtinclusao(DateUtil::getDataAtual());
        $novo->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $novo->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtultatu(DateUtil::getDataAtual());
        $novo->setCdoperultatu($this->hcmParameters->getCdoperador());
        $novo->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        $novo->setNritcadastrocct(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'FPA_ITCADASTROCCT', 1, 12, true));
        
        //$this->entityManager->persist($novo);
        
        return $novo;
    }
    
    public function novoBeneficioCCT(
        $nrcadastrocct, $nrtpbeneficio, $nridademaxsubfilhos, $sexosubsidiofilho, $nridademaxsubdep, $sexosubsidiodep, $nrevetitularvinc, $nrtipoparticipatitular, $nrtabfaixasaltit, $vrtitularsind, $vrtetotitularsind,
        $vrpisotitularsind, $nrevedepevinc, $nrtipoparticipadep, $nrtabfaixasaldep, $vrdepsind, $vrpisodepsind, $vrtetodepsind, $idativo, $nreventomensa, $nreventomensadep, $vrtetotitularmens, $vrpisotitularmens, 
        $vrlinearbeneficio, $vrlinearbeneficiodep, $idpropadmis, $idpropresc, $qtdiasminmes, $qtdiasmaxfaltas, $qtdiasmaxatest, $qtmesmaxafast, $vrmultiplicador, $dsvinculoempreg, $dsincidevento, $vrfixacresdesc, 
        $vrperacrescdesc, $idnaogerbenvincexp, $idnaogerabenperexp, $idnaogerabenresc, $vrparticipatitular, $vrpisotitular, $vrtetotitular, $vrparticipadepe, $vrpisodep, $vrtetodep, $qtmaxhsreduzida, $vrhsreduzida, 
        $dsincidevenperder, $qtmesretrocmult, $qtmesretrocsemben, $dsafastamento1, $idgeradescafast1, $dsafastamento2, $qtmesmaxafast2, $idgeradescafast2, $dsafastamento3, $qtmesretrocdiastrab
    ){
        $beneficiocct = Repositories::VAB_BENEFICIOCCT;
        
        $novo = new $beneficiocct;
        $novo->setNrcadastrocct($nrcadastrocct);
        $novo->setNrtpbeneficio($nrtpbeneficio);
        $novo->setNridademaxsubfilhos($nridademaxsubfilhos);
        $novo->setSexosubsidiofilho($sexosubsidiofilho);
        $novo->setNridademaxsubdep($nridademaxsubdep);
        $novo->setSexosubsidiodep($sexosubsidiodep);
        $novo->setNrevetitularvinc($nrevetitularvinc);
        $novo->setNrtipoparticipatitular($nrtipoparticipatitular);
        $novo->setNrtabfaixasaltit($nrtabfaixasaltit);
        $novo->setVrtitularsind($vrtitularsind);
        $novo->setVrtetotitularsind($vrtetotitularsind);
        $novo->setVrpisotitularsind($vrpisotitularsind);
        $novo->setNrevedepevinc($nrevedepevinc);
        $novo->setNrtipoparticipadep($nrtipoparticipadep);
        $novo->setNrtabfaixasaldep($nrtabfaixasaldep);
        $novo->setVrdepsind($vrdepsind);
        $novo->setVrpisodepsind($vrpisodepsind);
        $novo->setVrtetodepsind($vrtetodepsind);
        $novo->setIdativo($idativo);

        $novo->setNreventomensa($nreventomensa);
        $novo->setNreventomensadep($nreventomensadep);
        $novo->setVrtetotitularmens($vrtetotitularmens);
        $novo->setVrpisotitularmens($vrpisotitularmens);
        $novo->setVrlinearbeneficio($vrlinearbeneficio);
        $novo->setVrlinearbeneficiodep($vrlinearbeneficiodep);
        $novo->setIdpropadmis($idpropadmis);
        $novo->setIdpropresc($idpropresc);
        $novo->setQtdiasminmes($qtdiasminmes);
        $novo->setQtdiasmaxfaltas($qtdiasmaxfaltas);
        $novo->setQtdiasmaxatest($qtdiasmaxatest);
        $novo->setQtmesmaxafast($qtmesmaxafast);
        $novo->setVrmultiplicador($vrmultiplicador);
        $novo->setDsvinculoempreg($dsvinculoempreg);
        $novo->setDsincidevento($dsincidevento);
        $novo->setVrfixacresdesc($vrfixacresdesc);
        $novo->setVrperacrescdesc($vrperacrescdesc);
        $novo->setIdnaogerbenvincexp($idnaogerbenvincexp);
        $novo->setIdnaogerabenperexp($idnaogerabenperexp);
        $novo->setIdnaogerabenresc($idnaogerabenresc);
        
        $novo->setVrparticipatitular($vrparticipatitular);
        $novo->setVrpisotitular($vrpisotitular);
        $novo->setVrtetotitular($vrtetotitular);
        $novo->setVrparticipadepe($vrparticipadepe);
        $novo->setVrpisodep($vrpisodep);
        $novo->setVrtetodep($vrtetodep);
        $novo->setQtmaxhsreduzida($qtmaxhsreduzida);
        $novo->setVrhsreduzida($vrhsreduzida);
        $novo->setDsincidevenperder($dsincidevenperder);
        $novo->setQtmesretrocmult($qtmesretrocmult);
        $novo->setQtmesretrocsemben($qtmesretrocsemben);
        $novo->setDsafastamento1($dsafastamento1);
        $novo->setIdgeradescafast1($idgeradescafast1);
        $novo->setDsafastamento2($dsafastamento2);
        $novo->setQtmesmaxafast2($qtmesmaxafast2);
        $novo->setIdgeradescafast2($idgeradescafast2);
        $novo->setDsafastamento3($dsafastamento3);
        $novo->setQtmesretrocdiastrab($qtmesretrocdiastrab);
        
        $novo->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtinclusao(DateUtil::getDataAtual());
        $novo->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $novo->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtultatu(DateUtil::getDataAtual());
        $novo->setCdoperultatu($this->hcmParameters->getCdoperador());
        $novo->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        
        $novo->setNrbeneficiocct(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'VAB_BENEFICIOCCT', 1, 12, true));
        
        //$this->entityManager->persist($novo);
        
        return $novo;
    }
    
    public function novoEstrutevento($nrestruturam, $nreventom, $dtinivigencia, $dtfimvigencia, $periodicidademes, $nrvalorreferenciam, $vrpercent, $vrmultiplic, $vrdivide, $vreventofixo, $idrefgerar, $idretreferencia, 
                         $vrreffixo, $idtipomovimento, $vrpisoevento, $vrtetoevento, $dsobservacao, $nrtpagrupacalc, $idgeraafastado)
    {
        $fpa_Estrutevento = Repositories::FPA_ESTRUTEVENTO;
        
        $evento = new $fpa_Estrutevento;
        $evento->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $evento->setNrestruturam($nrestruturam);
        $evento->setNreventom($nreventom);
        $evento->setDtinivigencia($dtinivigencia);
        $evento->setDtfimvigencia($dtfimvigencia);
        $evento->setPeriodicidademes($periodicidademes);
        $evento->setNrvalorreferenciam($nrvalorreferenciam);
        $evento->setVrpercent($vrpercent);
        $evento->setVrmultiplic($vrmultiplic);
        $evento->setVrdivide($vrdivide);
        $evento->setVreventofixo($vreventofixo);
        $evento->setIdrefgerar($idrefgerar);
        $evento->setIdretreferencia($idretreferencia);
        $evento->setVrreffixo($vrreffixo);
        $evento->setIdtipomovimento($idtipomovimento);
        $evento->setVrpisoevento($vrpisoevento);
        $evento->setVrtetoevento($vrtetoevento);
        $evento->setDsobservacao($dsobservacao);
        $evento->setNrtpagrupacalc($nrtpagrupacalc);
        $evento->setIdgeraafastado($idgeraafastado);
        $evento->setDtinclusao(DateUtil::getDataAtual()); 
        $evento->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $evento->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $evento->setDtultatu(DateUtil::getDataAtual());
        $evento->setCdoperultatu($this->hcmParameters->getCdoperador());
        $evento->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        
        $evento->setNrestrutevento(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'FPA_ESTRUTEVENTO', 1, 12, true));
        
        //$this->entityManager->persist($evento);
        
        return $evento;
    }
    
    public function novoTpbeneficio($dstpbeneficio)
    {
        $tpbeneficio = Repositories::TPBENEFICIO;
        
        $novo = new $tpbeneficio;
        $novo->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $novo->setDstpbeneficio($dstpbeneficio);
        $novo->setIdativo('S');  
        $novo->setDtinclusao(DateUtil::getDataAtual()); 
        $novo->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $novo->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtultatu(DateUtil::getDataAtual());
        $novo->setCdoperultatu($this->hcmParameters->getCdoperador());
        $novo->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        
        $novo->setNrtpbeneficio(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'TPBENEFICIO', 1, 12, true));
        
        //$this->entityManager->persist($novo);
        
        return $novo;
    }
    
    public function novoBeneficioMestre($dtiniciovigencia, $dtfinalvigencia, $idativo)
    {
        $vab_beneficiom = Repositories::VAB_BENEFICIOM;
        
        $novo = new $vab_beneficiom;
        $novo->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtiniciovigencia($dtiniciovigencia);
        $novo->setDtfinalvigencia($dtfinalvigencia);
        $novo->setIdativo($idativo);  
        $novo->setDtinclusao(DateUtil::getDataAtual()); 
        $novo->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $novo->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtultatu(DateUtil::getDataAtual());
        $novo->setCdoperultatu($this->hcmParameters->getCdoperador());
        $novo->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        
        $novo->setNrbeneficiom(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'VAB_BENEFICIOM', 1, 12, true));
        
        //$this->entityManager->persist($novo);
        
        return $novo;
    }
    
    public function novoBeneficioHistorico(
        $nrbeneficiom, $nrtpbeneficio, $nrformabeneficio, $nrestruturam, $dtmescompetenc, $dtreferencia, $dsbeneficio, $tpperiodobenef, $dsobsbeneficio, $nrtabelafolhapri, $nrtabelafolhasec, $idativo, $nreventomensa, 
        $nrevetitularemp, $nrevedepempresa, $nrevetitularvinc, $nrevedepevinc, $nrtabfaixasaltit, $nrtabfaixasaldep, $nrmesaniversario, $nrdiavencboleto, $vrlinearbeneficio, $nridademaxsubfilhos, $nridademaxsubdep, 
        $nrtipoparticipatitular, $vrparticipatitular, $nrtipoparticipadep, $vrparticipadepe, $vrlinearbeneficiodep, $nreventomensadep, $vrpisotitular, $vrpisodep, $vrtetodep, $vrtetotitular, $sexosubsidiofilho, 
        $sexosubsidiodep, $idconsfaltabenef, $qtmesesfaltabenef, $idconsatestbenef, $qtmesesatestbenef, $idconsafastbenef, $qtmesesafastbenef, $idconsferiasbenef, $qtmesesferiasbenef, $idconsferiadobenef, 
        $qtmesesferiadobenef, $idconsdsrbenef, $qtmesesdsrbenef, $idgerabeneffalta, $idgerabenefatest, $idgerabenefafast, $idgerabenefferias, $consvincresmesant, $nrestrutsind, $dtdisponib, $idpropadmis, 
        $idpropresc, $nreventocopart, $nreventocopartdep, $percoparticipatitu, $percoparticipadepe, $vrdepsind, $vrtitularsind, $idpropdtinscr, $idpropdtcanc, $idduplicmens, $nrdiarescisao, $nreventotaxa, 
        $vreventotaxa, $vrtetotitularsind, $vrpisotitularsind, $vrpisodepsind, $vrtetodepsind, $vrtetotitularmens, $vrpisotitularmens, $idgeradescafast, $periodicidademes, $idgerbenefadmissao, $idgerbenefrescisao)
    {
        $vab_beneficioh = Repositories::VAB_BENEFICIOH;
        
        $novo = new $vab_beneficioh;
        $novo->setNrorg($this->hcmParameters->getNrorgTrabalho());
        $novo->setNrbeneficiom($nrbeneficiom);
        $novo->setNrtpbeneficio($nrtpbeneficio);
        $novo->setNrformabeneficio($nrformabeneficio);
        $novo->setNrestruturam($nrestruturam);
        $novo->setDtmescompetenc($dtmescompetenc);
        $novo->setDtreferencia($dtreferencia);
        $novo->setDsbeneficio($dsbeneficio);
        $novo->setTpperiodobenef($tpperiodobenef);
        $novo->setDsobsbeneficio($dsobsbeneficio);
        $novo->setNrtabelafolhapri($nrtabelafolhapri);
        $novo->setNrtabelafolhasec($nrtabelafolhasec);
        $novo->setIdativo($idativo);
        $novo->setNreventomensa($nreventomensa);
        $novo->setNrevetitularemp($nrevetitularemp);
        $novo->setNrevedepempresa($nrevedepempresa);
        $novo->setNrevetitularvinc($nrevetitularvinc);
        $novo->setNrevedepevinc($nrevedepevinc);
        $novo->setNrtabfaixasaltit($nrtabfaixasaltit);
        $novo->setNrtabfaixasaldep($nrtabfaixasaldep);
        $novo->setNrmesaniversario($nrmesaniversario);
        $novo->setNrdiavencboleto($nrdiavencboleto);
        $novo->setVrlinearbeneficio($vrlinearbeneficio);
        $novo->setNridademaxsubfilhos($nridademaxsubfilhos);
        $novo->setNridademaxsubdep($nridademaxsubdep);
        $novo->setNrtipoparticipatitular($nrtipoparticipatitular);
        $novo->setVrparticipatitular($vrparticipatitular);
        $novo->setNrtipoparticipadep($nrtipoparticipadep);
        $novo->setVrparticipadepe($vrparticipadepe);
        $novo->setVrlinearbeneficiodep($vrlinearbeneficiodep);
        $novo->setNreventomensadep($nreventomensadep);
        $novo->setVrpisotitular($vrpisotitular);
        $novo->setVrpisodep($vrpisodep);
        $novo->setVrtetodep($vrtetodep);
        $novo->setVrtetotitular($vrtetotitular);
        $novo->setSexosubsidiofilho($sexosubsidiofilho);
        $novo->setSexosubsidiodep($sexosubsidiodep);
        $novo->setIdconsfaltabenef($idconsfaltabenef);
        $novo->setQtmesesfaltabenef($qtmesesfaltabenef);
        $novo->setIdconsatestbenef($idconsatestbenef);
        $novo->setQtmesesatestbenef($qtmesesatestbenef);
        $novo->setIdconsafastbenef($idconsafastbenef);
        $novo->setQtmesesafastbenef($qtmesesafastbenef);
        $novo->setIdconsferiasbenef($idconsferiasbenef);
        $novo->setQtmesesferiasbenef($qtmesesferiasbenef);
        $novo->setIdconsferiadobenef($idconsferiadobenef);
        $novo->setQtmesesferiadobenef($qtmesesferiadobenef);
        $novo->setIdconsdsrbenef($idconsdsrbenef);
        $novo->setQtmesesdsrbenef($qtmesesdsrbenef);
        $novo->setIdgerabeneffalta($idgerabeneffalta);
        $novo->setIdgerabenefatest($idgerabenefatest);
        $novo->setIdgerabenefafast($idgerabenefafast);
        $novo->setIdgerabenefferias($idgerabenefferias);
        $novo->setConsvincresmesant($consvincresmesant);
        $novo->setNrestrutsind($nrestrutsind);
        $novo->setDtdisponib($dtdisponib);
        $novo->setIdpropadmis($idpropadmis);
        $novo->setIdpropresc($idpropresc);
        $novo->setNreventocopart($nreventocopart);
        $novo->setNreventocopartdep($nreventocopartdep);
        $novo->setPercoparticipatitu($percoparticipatitu);
        $novo->setPercoparticipadepe($percoparticipadepe);
        $novo->setVrdepsind($vrdepsind);
        $novo->setVrtitularsind($vrtitularsind);
        $novo->setIdpropdtinscr($idpropdtinscr);
        $novo->setIdpropdtcanc($idpropdtcanc);
        $novo->setIdduplicmens($idduplicmens);
        $novo->setNrdiarescisao($nrdiarescisao);
        $novo->setNreventotaxa($nreventotaxa);
        $novo->setVreventotaxa($vreventotaxa);
        $novo->setVrtetotitularsind($vrtetotitularsind);
        $novo->setVrpisotitularsind($vrpisotitularsind);
        $novo->setVrpisodepsind($vrpisodepsind);
        $novo->setVrtetodepsind($vrtetodepsind);
        $novo->setVrtetotitularmens($vrtetotitularmens);
        $novo->setVrpisotitularmens($vrpisotitularmens);
        $novo->setIdgeradescafast($idgeradescafast);
        $novo->setPeriodicidademes($periodicidademes);
        $novo->setIdgerbenefadmissao($idgerbenefadmissao);
        $novo->setIdgerbenefrescisao($idgerbenefrescisao);
        $novo->setDtinclusao(DateUtil::getDataAtual()); 
        $novo->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $novo->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $novo->setDtultatu(DateUtil::getDataAtual());
        $novo->setCdoperultatu($this->hcmParameters->getCdoperador());
        $novo->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        
        $novo->setNrbeneficioh(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'VAB_BENEFICIOH', 1, 12, true));
        
        //$this->entityManager->persist($novo);
        
        return $novo;
    }
    
}