<?php

namespace HCM\SST\Services;

use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;
use HCM\FPA\Services\ExportacaoExcelService;
use Zeedhi\Framework\HTTP\Kernel;
use HCM\Util\FPA;
use HCM\Util\Repositories;
use HCM\Util\DateUtil;

class CnaeXcidService {
    
    protected $entityManager;
    protected $hcmParameters;
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters, ExportacaoExcelService $exportacaoExcelService, Kernel $httpKernel) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->httpKernel = $httpKernel;
        $this->exportacaoExcelService = $exportacaoExcelService;
        $this->itemloteCnaeXcid = Repositories::SST_CNAE_CID;
        
    }
    public function getDadosPlanilhaCnaeXcid($path)
    {
        
        $head = array(
            'CDCNAE',
            'CDCID'
        );
      
        $file = $this->httpKernel->factoryFromFileData($path, FPA::getTempDirectory()."/");
        $caminhoNovo = DIRECTORY_SEPARATOR . $file->getPathname();
        
        $file = \PHPExcel_IOFactory::load($caminhoNovo);
        $file->setActiveSheetIndex(0);
        
        return $this->exportacaoExcelService->preparaInfoLoteCnaeXcid($file);
    }
    
    public function validaCnaeXcid($cdcnae, $cdcid){
        $nrorgPadrao = $this->hcmParameters->getNrorgPadrao();
        $cnae = $this->entityManager->getRepository(Repositories::CNAEFISCAL)->findOneBy(array('cdcnae' => $cdcnae, 'nrorg' => $nrorgPadrao));
        $cid = $this->entityManager->getRepository(Repositories::SST_CID)->findOneBy(array('cdcid' => $cdcid));
        $existeCnaeXCid = $this->entityManager->getRepository(Repositories::SST_CNAE_CID)->findOneBy(array('cdcnae' => $cnae->getCdcnae(), 'nrcid' => $cid->getNrcid()));
        
        if($existeCnaeXCid){
            return true;
        }
        else{
            return false;
        }
    }
    
    private function insereCnaeXcid($cnae, $cid)
    {  
        $obj = new $this->itemloteCnaeXcid;
        $obj->setDtinclusao(DateUtil::getDataAtual());
        $obj->setCdoperinclusao($this->hcmParameters->getCdoperador());
        $obj->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
        $obj->setDtultatu(DateUtil::getDataAtual());
        $obj->setCdoperultatu($this->hcmParameters->getCdoperador());
        $obj->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
        $obj->setIdativo('S');
        $obj->setCdcnae($cnae->getCdcnae());
        $obj->setNrcid($cid->getNrcid());
        $obj->setNrcnaecid(\HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'SST_CNAE_CID', 1, 12, true));
        $this->entityManager->persist($obj);
        $this->entityManager->flush();
    }

    
    public function importarPlanilhaCnaeXCid($row)
    {   
        //Dados básicos
        $nrorgPadrao = $this->hcmParameters->getNrorgPadrao();
        $msgRetorno   = array(); //Mensages de erro, se estiver vazio não houve erros
        $dados = $this->getDadosPlanilhaCnaeXcid($row['DSPATH'][0]);
        
        foreach($dados as $dado) {
            $cnae = $this->entityManager->getRepository(Repositories::CNAEFISCAL)->findOneBy(array('cdcnae' => $dado['CDCNAE'], 'nrorg' => $nrorgPadrao));
            $cid = $this->entityManager->getRepository(Repositories::SST_CID)->findOneBy(array('cdcid' => $dado['CDCID']));
          
            
            if(!empty($cnae) && !empty($cid)) {
                $cnaeEcidExistente = $this->validaCnaeXcid($dado['CDCNAE'], $dado['CDCID']);
                if($cnaeEcidExistente) {
                    $msgRetorno[] = [
                        'CDCNAE'  => $cnae->getCdcnae(),
                        'CDCID' => $cid->getCdcid(),
                        'DSDESCRICAO'  => 'CnaeXcid já esta cadastrado',
                        'IDTIPOMSG' =>  'ATENÇÃO'
                    ];
                    continue;
                }
                
                $this->insereCnaeXcid($cnae, $cid);
                
            } else {
                if(!$cnae){
                    $msgRetorno[] = [
                        'CDCNAE'  => $dado['CDCNAE'],
                        'DSDESCRICAO'  => 'Codigo CNAE não encontrado no sistema',
                        'IDTIPOMSG' =>  'ATENÇÃO'
                    ];
                }
                if(!$cid){
                    $msgRetorno[] = [
                        'CDCID'  => $dado['CDCID'],
                        'DSDESCRICAO'  => 'Codigo CID não encontrado no sistema',
                        'IDTIPOMSG' =>  'ATENÇÃO'
                    ];
                    
                }
                continue;
            }    
        }
        return $msgRetorno;
    }

    
    
    public function baixarPlanilhaCnaeXcid($nrorg, $nmarquivo) {
        $cabecalho = array(
            "CID",
            "CNAE"
            
        );
        $dadosExemplo[0] = array(
            "A00",
            "9609201"
        );
        
        return $this->exportacaoExcelService->gravarTemplate_1($nrorg, $cabecalho, $nmarquivo, $dadosExemplo);
    }
    
}