<?php

namespace HCM\Util;

abstract class TkEntity
{

    const MODE_SINGLE = 1;
    const MODE_LIST = 2;
    
    private $_dao;

    protected $mode = self::MODE_SINGLE;

    protected $daoAttributes = array();

    protected $items = array();

    protected $removedItems = array();
    private $_pointer = 0;

    public function __construct($id = null, $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function setMode($mode)
    {
        $this->mode = $mode;
        return $this;
    }

    public function getMode()
    {
        return $this->mode;
    }

    public function addItem($item, $key = null)
    {
        if ($key === null) {
            $key = $this->_pointer++;
        }

        $this->setMode(self::MODE_LIST);

        $this->items[$key] = $item;
        return $this;
    }

    public function getItems()
    {
        return $this->items;
    }

    public function getItem($key)
    {   
        if(isset($this->items[$key])){
            return $this->items[$key];
        }
    }

    public function removeItem($object)
    {
        $items = $this->items;
        foreach ($items as $key => $item) {
            if ($item == $object) {
                unset($this->items[$key]);
                $this->removedItems[$key] = $object;
            }
        }
    }

    public function resetItems()
    {
        $this->setMode(self::MODE_SINGLE);

        $this->items = array();
        $this->removedItems = array();
    }

    public function persist()
    {
        try {
            switch ($this->getMode()) {
            case self::MODE_LIST:
                $this->persistList();
                break;
            default:
                $item = $this->getItems();
                $this->entityManager->persist($item);
                $this->entityManager->flush($item);
        }
            
        } catch (TkValidationException $e) {
            throw $e;
        } catch (Exception $e) {
            throw $e;
        }
        return true;
    }
    
    public function excluiItem($item, $indice){
        unset($this->items[$indice]);
        $this->removedItems[$indice] = $item;
        $this->entityManager->remove($item);
        $this->entityManager->flush($item);
    }
    
    public function removeAllItens(){
        
        $items = $this->getItems();
        
        foreach ($items as $key => $item) {
            $this->entityManager->remove($item);
            $this->entityManager->flush($item);
        }
        $this->resetItems();
    }
    
    public function persistList()
    {
        foreach ($this->removedItems as $item) {
            $this->entityManager->remove($item);
        }
        $this->entityManager->flush();
        $items = $this->getItems();
        if (count($items)) {
            foreach ($items as $item) {
                $this->entityManager->persist($item);
            }
            $this->entityManager->flush();
        }
    }

    public function get($attr)
    {
        $property = SetformsInflector::methodfy($attr);
        $attr = SetformsInflector::classify($attr);
        $getter = 'get'.$attr;
        $value = null;
        if (method_exists($this, $getter)) {
            $value = $this->{
            $getter
            }();
        } else if (property_exists($this, $property)) {
            $value = $this->{$property};
        }

        return $value;
    }

    public function set($attr, $value) {
        static $methods = array();
        static $properties = array();
        $class = get_class($this);
        if  (!isset($methods[$class]) || !isset($methods[$class][$attr])) {
            $setter = 'set'.SetformsInflector::classify($attr);
            $methods[$class][$attr] = method_exists($this, $setter) ? $setter : false;
        }

        if ($methods[$class][$attr]) {
            $this->{$methods[$class][$attr]}($value);
        } else {
            if  (!isset($properties[$class]) || !isset($properties[$class][$attr])) {
                $property = SetformsInflector::methodfy($attr);
                $properties[$class][$attr] = property_exists($this, $property) ? $property : false;
            }

            if ($properties[$class][$attr]) {
                $this->{$properties[$class][$attr]} = $value;
            }
        }
    }

    public function fromArray(array $data)
    {
        foreach ($data as $key => $value) {
            try {
                $this->set($key, $value);
            } catch (Exception $e) {
                MsgCalculo::getInstance()->adicionaMensagem("Attribute $key does not exists");
            }
        }
    }

    public function validateAnnotations()
    {
        $parent_class = get_parent_class($this);
        $p = new ReflectionAnnotatedClass($parent_class);
        $exception = new TkValidationException('Validation failed');
        foreach ($p->getProperties(ReflectionProperty::IS_PRIVATE) as $property) {
            foreach ($property->getAllAnnotations() as $validation) {
                if (($validation instanceof TkValidationInterface) === false) {
                    continue;
                }
                $property->setAccessible(true);
                if ($validation->isValid($property->getValue($this)) === false) {
                    $error = new TkValidationException($validation->getMessage());
                    $error->setAttribute($property->getName());
                    $exception->addError($error);
                }
            }
        }

        if ($exception->hasErrors()) {
            throw $exception;
        }

        return true;
    }

    public function applyDefaultValues()
    {
        $parent_class = get_parent_class($this);
        $p = new ReflectionAnnotatedClass($parent_class);
        foreach ($p->getProperties(ReflectionProperty::IS_PRIVATE) as $property) {
            if ($property->hasAnnotation('DefaultValue')) {
                $annotation = $property->getAnnotation('DefaultValue');
                $annotation->apply($this);
            }
        }
    }

    public function __get($name)
    {
        throw new \Exception("Property {$name} not defined ");
    }

    public function toArray()
    {
        $callback = function($matches)
        {
            return '_'.$matches[0];
        };

        $class_name = get_class($this);
        $refClass = new Zend_Reflection_Class($class_name);

        if ($refClass->getParentClass()->getName() !== 'TkEntity') {
            $refClass = $refClass->getParentClass();
        }

        $properties = $refClass->getProperties();

        $entityRefClass = new Zend_Reflection_Class('TkEntity');

        foreach ($entityRefClass->getProperties() as $p) {
            $propertiesToRemove[] = $p->getName();
        }

        foreach ($properties as $key => $property) {
            $is_to_remove = in_array($property->getName(), $propertiesToRemove);
            if ($is_to_remove === false) {
                $pname = $property->getName();
                $pname = preg_replace_callback('/[A-Z]/', $callback, $pname);
                $return[strtoupper($pname)] = $this->{'get'.ucfirst($property->getName())}();
            }
        }

        return $return;
    }

    public static function getEntitiesByWhere($where, $params = array(), $order_by = null) {
        $called_class = get_called_class();
        $dao_class_name = str_replace("Entity", "", $called_class );

        if(is_array($params) === false && $params) {
            $params = array($params);
        }

        $dao_objects = $dao_class_name::getObjectsByWhere($where, $params, $order_by);
        return $dao_objects;
    }


    public static function getEntityByWhere($where, $params = array(), $order_by = null) {
        return reset(self::getEntitiesByWhere($where, $params, $order_by));
    }
    
    public function copyEntity(TkEntity $from){
        $columns = $from->getDao()->getTable()->getColumns();
        foreach ($columns as $column => $value){
            $get = 'get'.(ucfirst(strtolower($column)));
            $set = 'set'.(ucfirst(strtolower($column)));
            if (method_exists($this, $set) === true) {
                $this->$set($from->$get());
            }
        }
    }
    
    public function countItems() {
        $num_items = count($this->getItems()) - count($this->removedItems);
        return $num_items;
    }

}
