-- SCRIPT SOLICITACOES --

-- ============================================================
-- Table: GPE_TIPOSOLICITACAO
-- ============================================================
create table GPE_TIPOSOLICITACAO
(
	NRORG NUMBER not null,
	NRTIPOSOLICITACAO NUMBER not null,
	NMTIPOSOLICITACAO VARCHAR2(100) not null,
	IDATIVO VARCHAR2(1) default 'S' not null
		constraint CKC_1523 check (IDATIVO in ('N','S')),
	DTINCLUSAO DATE null,
	DTULTATU DATE null ,
	NRORGINCLUSAO NUMBER(22) default 1 null ,
	CDOPERINCLUSAO VARCHAR2(12) default '1' null ,
	NRORGULTATU NUMBER(22) default 1 null ,
	CDOPERULTATU VARCHAR2(12) default '1' null ,
	constraint PK_GPE_TIPOSOLICITA primary key (NRTIPOSOLICITACAO)
)
/

-- ============================================================
-- Table: GPE_PERFACESTIPOSOLI
-- ============================================================
create table GPE_PERFACESTIPOSOLI
(
	NRORG NUMBER not null,
	NRPERFACESTIPOSOLI NUMBER not null,
	NRTIPOSOLICITACAO NUMBER not null,
	NRNIVELAPROVASOLI NUMBER not null,
	NRPERFACESAPROVPRI NUMBER null,
	NRPERFACESAPROVSEC NUMBER not null,
	DTINCLUSAO DATE null,
	DTULTATU DATE null ,
	NRORGINCLUSAO NUMBER(22) default 1 null ,
	CDOPERINCLUSAO VARCHAR2(12) default '1' null ,
	NRORGULTATU NUMBER(22) default 1 null ,
	CDOPERULTATU VARCHAR2(12) default '1' null ,
	constraint PK_GPE_PERFACESTPSO primary key (NRORG, NRPERFACESTIPOSOLI)
)
/

-- ============================================================
-- Index: FK_308934_FK
-- ============================================================
create index FK_308934_FK on GPE_PERFACESTIPOSOLI (NRTIPOSOLICITACAO asc)
/

-- ============================================================
-- Index: FK_308935_FK
-- ============================================================
create index FK_308935_FK on GPE_PERFACESTIPOSOLI (NRPERFACESAPROVPRI asc)
/

-- ============================================================
-- Index: FK_308936_FK
-- ============================================================
create index FK_308936_FK on GPE_PERFACESTIPOSOLI (NRPERFACESAPROVSEC asc)
/

-- ============================================================
-- Table: GPE_SOLICITACAO
-- ============================================================
create table GPE_SOLICITACAO
(
	NRORG NUMBER not null,
	NRSOLICITACAO NUMBER not null,
	NRTIPOSOLICITACAO NUMBER not null,
	NRVINCULOM NUMBER not null,
	DTSOLICITACAO DATE not null,
	IDAPROVACAOPRI VARCHAR2(1) default 'P' not null
		constraint CKC_1521 check (IDAPROVACAOPRI in ('P','A','R')),
	DTAPROVACAOPRI DATE null ,
	CDOPERAPROVPRI VARCHAR2(12) null ,
	IDAPROVACAOSEC VARCHAR2(1) default 'P' not null
		constraint CKC_1522 check (IDAPROVACAOSEC in ('P','A','R')),
	DTAPROVACAOSEC DATE null ,
	CDOPERAPROVSEC VARCHAR2(12) null ,
	DSOBSSOLICITACAO VARCHAR2(4000) null ,
	DSOBSAPROVAPRI VARCHAR2(4000) null ,
	DSOBSAPROVASEC VARCHAR2(4000) null ,
	DTINCLUSAO DATE null,
	DTULTATU DATE null ,
	NRORGINCLUSAO NUMBER(22) default 1 null ,
	CDOPERINCLUSAO VARCHAR2(12) default '1' null ,
	NRORGULTATU NUMBER(22) default 1 null ,
	CDOPERULTATU VARCHAR2(12) default '1' null ,
	constraint PK_GPE_SOLICITACAO primary key (NRORG, NRSOLICITACAO)
)
/

-- ============================================================
-- Index: FK_308911_FK
-- ============================================================
create index FK_308911_FK on GPE_SOLICITACAO (NRTIPOSOLICITACAO asc)
/

-- ============================================================
-- Index: FK_308923_FK
-- ============================================================
create index FK_308923_FK on GPE_SOLICITACAO (NRORG asc, NRVINCULOM asc)
/

-- ============================================================
-- Table: GPE_ITEMSOLICITACAO
-- ============================================================
create table GPE_ITEMSOLICITACAO
(
	NRORG NUMBER default 1 not null,
	NRITEMSOLICITACAO NUMBER not null,
	NRSOLICITACAO NUMBER not null,
	DSCHAVEITEMSOLI VARCHAR2(100) not null,
	DSLABELITEMSOLI VARCHAR2(100) not null,
	DSVALORITEMSOLI VARCHAR2(4000) not null,
	DTINCLUSAO DATE null,
	DTULTATU DATE null ,
	NRORGINCLUSAO NUMBER(22) default 1 null ,
	CDOPERINCLUSAO VARCHAR2(12) default '1' null ,
	NRORGULTATU NUMBER(22) default 1 null ,
	CDOPERULTATU VARCHAR2(12) default '1' null ,
	constraint PK_GPE_ITEMSOLICIT primary key (NRORG, NRITEMSOLICITACAO)
)
/

-- ============================================================
-- Index: FK_308933_FK
-- ============================================================
create index FK_308933_FK on GPE_ITEMSOLICITACAO (NRORG asc, NRSOLICITACAO asc)
/

-- ============================================================
-- Foreign Keys
-- ============================================================
alter table GPE_PERFACESTIPOSOLI
	add constraint FK_30894GPE_PERF foreign key (NRTIPOSOLICITACAO)
		references GPE_TIPOSOLICITACAO (NRTIPOSOLICITACAO)
/

alter table GPE_PERFACESTIPOSOLI
	add constraint FK_30895GPE_PERF foreign key (NRPERFACESAPROVPRI)
		references PERFILACESSO (NRPERFILACESSO)
/

alter table GPE_PERFACESTIPOSOLI
	add constraint FK_30896GPE_PERF foreign key (NRPERFACESAPROVSEC)
		references PERFILACESSO (NRPERFILACESSO)
/

alter table GPE_SOLICITACAO
	add constraint FK_30891GPE_TIPO foreign key (NRTIPOSOLICITACAO)
		references GPE_TIPOSOLICITACAO (NRTIPOSOLICITACAO)
/

alter table GPE_SOLICITACAO
	add constraint FKFK_30892GPE_VINC foreign key (NRORG, NRVINCULOM)
		references GPE_VINCULOM (NRORG, NRVINCULOM)
/

alter table GPE_ITEMSOLICITACAO
	add constraint FKFK_30893GPE_SOLI foreign key (NRORG, NRSOLICITACAO)
		references GPE_SOLICITACAO (NRORG, NRSOLICITACAO)
/

-- ============================================================
-- Inserção de Dados: GPE_TIPOSOLICITACAO
-- ============================================================
insert into GPE_TIPOSOLICITACAO (NRORG, NRTIPOSOLICITACAO, NMTIPOSOLICITACAO, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
	values (0, 1, 'Solicitação de Férias', 'S', sysdate, 1, '1')
/
insert into GPE_TIPOSOLICITACAO (NRORG, NRTIPOSOLICITACAO, NMTIPOSOLICITACAO, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
	values (0, 2, 'Solicitação de Remanejamento/Transferência', 'N', sysdate, 1, '1')
/
insert into GPE_TIPOSOLICITACAO (NRORG, NRTIPOSOLICITACAO, NMTIPOSOLICITACAO, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
	values (0, 3, 'Solicitação de Alteração Salarial', 'S', sysdate, 1, '1')
/
insert into GPE_TIPOSOLICITACAO (NRORG, NRTIPOSOLICITACAO, NMTIPOSOLICITACAO, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
	values (0, 4, 'Solicitação de Treinamento', 'N', sysdate, 1, '1')
/
insert into GPE_TIPOSOLICITACAO (NRORG, NRTIPOSOLICITACAO, NMTIPOSOLICITACAO, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
	values (0, 5, 'Solicitação de Desligamento', 'N', sysdate, 1, '1')
/
insert into GPE_TIPOSOLICITACAO (NRORG, NRTIPOSOLICITACAO, NMTIPOSOLICITACAO, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
	values (0, 6, 'Solicitação de Novas Contratações, postos de trabalho, Substituições e/ou aumento de quadro', 'N', sysdate, 1, '1')
/
insert into GPE_TIPOSOLICITACAO (NRORG, NRTIPOSOLICITACAO, NMTIPOSOLICITACAO, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
	values (0, 7, 'Solicitação de Alteração de Dados de Admissão', 'N', sysdate, 1, '1')
/
insert into GPE_TIPOSOLICITACAO (NRORG, NRTIPOSOLICITACAO, NMTIPOSOLICITACAO, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
	values (0, 8, 'Solicitação de Alteração de Endereço', 'N', sysdate, 1, '1')
/